/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_X86_ENUMS_H
#define LLVM_IR_INTRINSIC_X86_ENUMS_H
namespace llvm::Intrinsic {
enum X86Intrinsics : unsigned {
// Enum values for intrinsics.
    x86_aadd32 = 14384,                                // llvm.x86.aadd32 (IntrinsicsX86.td:5830)
    x86_aadd64,                                // llvm.x86.aadd64 (IntrinsicsX86.td:5833)
    x86_aand32,                                // llvm.x86.aand32 (IntrinsicsX86.td:5836)
    x86_aand64,                                // llvm.x86.aand64 (IntrinsicsX86.td:5839)
    x86_addcarry_32,                           // llvm.x86.addcarry.32 (IntrinsicsX86.td:2738)
    x86_addcarry_64,                           // llvm.x86.addcarry.64 (IntrinsicsX86.td:2742)
    x86_aesdec128kl,                           // llvm.x86.aesdec128kl (IntrinsicsX86.td:5394)
    x86_aesdec256kl,                           // llvm.x86.aesdec256kl (IntrinsicsX86.td:5398)
    x86_aesdecwide128kl,                       // llvm.x86.aesdecwide128kl (IntrinsicsX86.td:5407)
    x86_aesdecwide256kl,                       // llvm.x86.aesdecwide256kl (IntrinsicsX86.td:5421)
    x86_aesenc128kl,                           // llvm.x86.aesenc128kl (IntrinsicsX86.td:5392)
    x86_aesenc256kl,                           // llvm.x86.aesenc256kl (IntrinsicsX86.td:5396)
    x86_aesencwide128kl,                       // llvm.x86.aesencwide128kl (IntrinsicsX86.td:5400)
    x86_aesencwide256kl,                       // llvm.x86.aesencwide256kl (IntrinsicsX86.td:5414)
    x86_aesni_aesdec,                          // llvm.x86.aesni.aesdec (IntrinsicsX86.td:678)
    x86_aesni_aesdec_256,                      // llvm.x86.aesni.aesdec.256 (IntrinsicsX86.td:681)
    x86_aesni_aesdec_512,                      // llvm.x86.aesni.aesdec.512 (IntrinsicsX86.td:684)
    x86_aesni_aesdeclast,                      // llvm.x86.aesni.aesdeclast (IntrinsicsX86.td:688)
    x86_aesni_aesdeclast_256,                  // llvm.x86.aesni.aesdeclast.256 (IntrinsicsX86.td:691)
    x86_aesni_aesdeclast_512,                  // llvm.x86.aesni.aesdeclast.512 (IntrinsicsX86.td:695)
    x86_aesni_aesenc,                          // llvm.x86.aesni.aesenc (IntrinsicsX86.td:656)
    x86_aesni_aesenc_256,                      // llvm.x86.aesni.aesenc.256 (IntrinsicsX86.td:659)
    x86_aesni_aesenc_512,                      // llvm.x86.aesni.aesenc.512 (IntrinsicsX86.td:662)
    x86_aesni_aesenclast,                      // llvm.x86.aesni.aesenclast (IntrinsicsX86.td:666)
    x86_aesni_aesenclast_256,                  // llvm.x86.aesni.aesenclast.256 (IntrinsicsX86.td:669)
    x86_aesni_aesenclast_512,                  // llvm.x86.aesni.aesenclast.512 (IntrinsicsX86.td:673)
    x86_aesni_aesimc,                          // llvm.x86.aesni.aesimc (IntrinsicsX86.td:653)
    x86_aesni_aeskeygenassist,                 // llvm.x86.aesni.aeskeygenassist (IntrinsicsX86.td:700)
    x86_aor32,                                 // llvm.x86.aor32 (IntrinsicsX86.td:5842)
    x86_aor64,                                 // llvm.x86.aor64 (IntrinsicsX86.td:5845)
    x86_atomic_add_cc,                         // llvm.x86.atomic.add.cc (IntrinsicsX86.td:85)
    x86_atomic_and_cc,                         // llvm.x86.atomic.and.cc (IntrinsicsX86.td:91)
    x86_atomic_btc,                            // llvm.x86.atomic.btc (IntrinsicsX86.td:69)
    x86_atomic_btc_rm,                         // llvm.x86.atomic.btc.rm (IntrinsicsX86.td:75)
    x86_atomic_btr,                            // llvm.x86.atomic.btr (IntrinsicsX86.td:71)
    x86_atomic_btr_rm,                         // llvm.x86.atomic.btr.rm (IntrinsicsX86.td:77)
    x86_atomic_bts,                            // llvm.x86.atomic.bts (IntrinsicsX86.td:67)
    x86_atomic_bts_rm,                         // llvm.x86.atomic.bts.rm (IntrinsicsX86.td:73)
    x86_atomic_or_cc,                          // llvm.x86.atomic.or.cc (IntrinsicsX86.td:89)
    x86_atomic_sub_cc,                         // llvm.x86.atomic.sub.cc (IntrinsicsX86.td:87)
    x86_atomic_xor_cc,                         // llvm.x86.atomic.xor.cc (IntrinsicsX86.td:93)
    x86_avx_addsub_pd_256,                     // llvm.x86.avx.addsub.pd.256 (IntrinsicsX86.td:901)
    x86_avx_addsub_ps_256,                     // llvm.x86.avx.addsub.ps.256 (IntrinsicsX86.td:904)
    x86_avx_blendv_pd_256,                     // llvm.x86.avx.blendv.pd.256 (IntrinsicsX86.td:1143)
    x86_avx_blendv_ps_256,                     // llvm.x86.avx.blendv.ps.256 (IntrinsicsX86.td:1147)
    x86_avx_cmp_pd_256,                        // llvm.x86.avx.cmp.pd.256 (IntrinsicsX86.td:1163)
    x86_avx_cmp_ps_256,                        // llvm.x86.avx.cmp.ps.256 (IntrinsicsX86.td:1167)
    x86_avx_cvt_pd2_ps_256,                    // llvm.x86.avx.cvt.pd2.ps.256 (IntrinsicsX86.td:1175)
    x86_avx_cvt_pd2dq_256,                     // llvm.x86.avx.cvt.pd2dq.256 (IntrinsicsX86.td:1181)
    x86_avx_cvt_ps2dq_256,                     // llvm.x86.avx.cvt.ps2dq.256 (IntrinsicsX86.td:1177)
    x86_avx_cvtt_pd2dq_256,                    // llvm.x86.avx.cvtt.pd2dq.256 (IntrinsicsX86.td:1179)
    x86_avx_cvtt_ps2dq_256,                    // llvm.x86.avx.cvtt.ps2dq.256 (IntrinsicsX86.td:1183)
    x86_avx_dp_ps_256,                         // llvm.x86.avx.dp.ps.256 (IntrinsicsX86.td:1155)
    x86_avx_hadd_pd_256,                       // llvm.x86.avx.hadd.pd.256 (IntrinsicsX86.td:936)
    x86_avx_hadd_ps_256,                       // llvm.x86.avx.hadd.ps.256 (IntrinsicsX86.td:945)
    x86_avx_hsub_pd_256,                       // llvm.x86.avx.hsub.pd.256 (IntrinsicsX86.td:942)
    x86_avx_hsub_ps_256,                       // llvm.x86.avx.hsub.ps.256 (IntrinsicsX86.td:939)
    x86_avx_ldu_dq_256,                        // llvm.x86.avx.ldu.dq.256 (IntrinsicsX86.td:1283)
    x86_avx_maskload_pd,                       // llvm.x86.avx.maskload.pd (IntrinsicsX86.td:1289)
    x86_avx_maskload_pd_256,                   // llvm.x86.avx.maskload.pd.256 (IntrinsicsX86.td:1295)
    x86_avx_maskload_ps,                       // llvm.x86.avx.maskload.ps (IntrinsicsX86.td:1292)
    x86_avx_maskload_ps_256,                   // llvm.x86.avx.maskload.ps.256 (IntrinsicsX86.td:1298)
    x86_avx_maskstore_pd,                      // llvm.x86.avx.maskstore.pd (IntrinsicsX86.td:1305)
    x86_avx_maskstore_pd_256,                  // llvm.x86.avx.maskstore.pd.256 (IntrinsicsX86.td:1311)
    x86_avx_maskstore_ps,                      // llvm.x86.avx.maskstore.ps (IntrinsicsX86.td:1308)
    x86_avx_maskstore_ps_256,                  // llvm.x86.avx.maskstore.ps.256 (IntrinsicsX86.td:1315)
    x86_avx_max_pd_256,                        // llvm.x86.avx.max.pd.256 (IntrinsicsX86.td:907)
    x86_avx_max_ps_256,                        // llvm.x86.avx.max.ps.256 (IntrinsicsX86.td:910)
    x86_avx_min_pd_256,                        // llvm.x86.avx.min.pd.256 (IntrinsicsX86.td:913)
    x86_avx_min_ps_256,                        // llvm.x86.avx.min.ps.256 (IntrinsicsX86.td:916)
    x86_avx_movmsk_pd_256,                     // llvm.x86.avx.movmsk.pd.256 (IntrinsicsX86.td:1267)
    x86_avx_movmsk_ps_256,                     // llvm.x86.avx.movmsk.ps.256 (IntrinsicsX86.td:1269)
    x86_avx_ptestc_256,                        // llvm.x86.avx.ptestc.256 (IntrinsicsX86.td:1228)
    x86_avx_ptestnzc_256,                      // llvm.x86.avx.ptestnzc.256 (IntrinsicsX86.td:1231)
    x86_avx_ptestz_256,                        // llvm.x86.avx.ptestz.256 (IntrinsicsX86.td:1225)
    x86_avx_rcp_ps_256,                        // llvm.x86.avx.rcp.ps.256 (IntrinsicsX86.td:923)
    x86_avx_round_pd_256,                      // llvm.x86.avx.round.pd.256 (IntrinsicsX86.td:926)
    x86_avx_round_ps_256,                      // llvm.x86.avx.round.ps.256 (IntrinsicsX86.td:929)
    x86_avx_rsqrt_ps_256,                      // llvm.x86.avx.rsqrt.ps.256 (IntrinsicsX86.td:920)
    x86_avx_vpermilvar_pd,                     // llvm.x86.avx.vpermilvar.pd (IntrinsicsX86.td:952)
    x86_avx_vpermilvar_pd_256,                 // llvm.x86.avx.vpermilvar.pd.256 (IntrinsicsX86.td:959)
    x86_avx_vpermilvar_ps,                     // llvm.x86.avx.vpermilvar.ps (IntrinsicsX86.td:955)
    x86_avx_vpermilvar_ps_256,                 // llvm.x86.avx.vpermilvar.ps.256 (IntrinsicsX86.td:963)
    x86_avx_vtestc_pd,                         // llvm.x86.avx.vtestc.pd (IntrinsicsX86.td:1192)
    x86_avx_vtestc_pd_256,                     // llvm.x86.avx.vtestc.pd.256 (IntrinsicsX86.td:1210)
    x86_avx_vtestc_ps,                         // llvm.x86.avx.vtestc.ps (IntrinsicsX86.td:1201)
    x86_avx_vtestc_ps_256,                     // llvm.x86.avx.vtestc.ps.256 (IntrinsicsX86.td:1219)
    x86_avx_vtestnzc_pd,                       // llvm.x86.avx.vtestnzc.pd (IntrinsicsX86.td:1195)
    x86_avx_vtestnzc_pd_256,                   // llvm.x86.avx.vtestnzc.pd.256 (IntrinsicsX86.td:1213)
    x86_avx_vtestnzc_ps,                       // llvm.x86.avx.vtestnzc.ps (IntrinsicsX86.td:1204)
    x86_avx_vtestnzc_ps_256,                   // llvm.x86.avx.vtestnzc.ps.256 (IntrinsicsX86.td:1222)
    x86_avx_vtestz_pd,                         // llvm.x86.avx.vtestz.pd (IntrinsicsX86.td:1189)
    x86_avx_vtestz_pd_256,                     // llvm.x86.avx.vtestz.pd.256 (IntrinsicsX86.td:1207)
    x86_avx_vtestz_ps,                         // llvm.x86.avx.vtestz.ps (IntrinsicsX86.td:1198)
    x86_avx_vtestz_ps_256,                     // llvm.x86.avx.vtestz.ps.256 (IntrinsicsX86.td:1216)
    x86_avx_vzeroall,                          // llvm.x86.avx.vzeroall (IntrinsicsX86.td:1275)
    x86_avx_vzeroupper,                        // llvm.x86.avx.vzeroupper (IntrinsicsX86.td:1277)
    x86_avx10_fpclass_bf16_128,                // llvm.x86.avx10.fpclass.bf16.128 (IntrinsicsX86.td:7138)
    x86_avx10_fpclass_bf16_256,                // llvm.x86.avx10.fpclass.bf16.256 (IntrinsicsX86.td:7141)
    x86_avx10_fpclass_bf16_512,                // llvm.x86.avx10.fpclass.bf16.512 (IntrinsicsX86.td:7144)
    x86_avx10_mask_getexp_bf16_128,            // llvm.x86.avx10.mask.getexp.bf16.128 (IntrinsicsX86.td:7147)
    x86_avx10_mask_getexp_bf16_256,            // llvm.x86.avx10.mask.getexp.bf16.256 (IntrinsicsX86.td:7150)
    x86_avx10_mask_getexp_bf16_512,            // llvm.x86.avx10.mask.getexp.bf16.512 (IntrinsicsX86.td:7153)
    x86_avx10_mask_getmant_bf16_128,           // llvm.x86.avx10.mask.getmant.bf16.128 (IntrinsicsX86.td:7156)
    x86_avx10_mask_getmant_bf16_256,           // llvm.x86.avx10.mask.getmant.bf16.256 (IntrinsicsX86.td:7159)
    x86_avx10_mask_getmant_bf16_512,           // llvm.x86.avx10.mask.getmant.bf16.512 (IntrinsicsX86.td:7162)
    x86_avx10_mask_rcp_bf16_128,               // llvm.x86.avx10.mask.rcp.bf16.128 (IntrinsicsX86.td:7120)
    x86_avx10_mask_rcp_bf16_256,               // llvm.x86.avx10.mask.rcp.bf16.256 (IntrinsicsX86.td:7123)
    x86_avx10_mask_rcp_bf16_512,               // llvm.x86.avx10.mask.rcp.bf16.512 (IntrinsicsX86.td:7126)
    x86_avx10_mask_reduce_bf16_128,            // llvm.x86.avx10.mask.reduce.bf16.128 (IntrinsicsX86.td:7129)
    x86_avx10_mask_reduce_bf16_256,            // llvm.x86.avx10.mask.reduce.bf16.256 (IntrinsicsX86.td:7132)
    x86_avx10_mask_reduce_bf16_512,            // llvm.x86.avx10.mask.reduce.bf16.512 (IntrinsicsX86.td:7135)
    x86_avx10_mask_rndscale_bf16_128,          // llvm.x86.avx10.mask.rndscale.bf16.128 (IntrinsicsX86.td:7165)
    x86_avx10_mask_rndscale_bf16_256,          // llvm.x86.avx10.mask.rndscale.bf16.256 (IntrinsicsX86.td:7168)
    x86_avx10_mask_rndscale_bf16_512,          // llvm.x86.avx10.mask.rndscale.bf16.512 (IntrinsicsX86.td:7171)
    x86_avx10_mask_rsqrt_bf16_128,             // llvm.x86.avx10.mask.rsqrt.bf16.128 (IntrinsicsX86.td:7111)
    x86_avx10_mask_rsqrt_bf16_256,             // llvm.x86.avx10.mask.rsqrt.bf16.256 (IntrinsicsX86.td:7114)
    x86_avx10_mask_rsqrt_bf16_512,             // llvm.x86.avx10.mask.rsqrt.bf16.512 (IntrinsicsX86.td:7117)
    x86_avx10_mask_scalef_bf16_128,            // llvm.x86.avx10.mask.scalef.bf16.128 (IntrinsicsX86.td:7174)
    x86_avx10_mask_scalef_bf16_256,            // llvm.x86.avx10.mask.scalef.bf16.256 (IntrinsicsX86.td:7177)
    x86_avx10_mask_scalef_bf16_512,            // llvm.x86.avx10.mask.scalef.bf16.512 (IntrinsicsX86.td:7180)
    x86_avx10_mask_vcvt2ps2phx_128,            // llvm.x86.avx10.mask.vcvt2ps2phx.128 (IntrinsicsX86.td:6909)
    x86_avx10_mask_vcvt2ps2phx_256,            // llvm.x86.avx10.mask.vcvt2ps2phx.256 (IntrinsicsX86.td:6912)
    x86_avx10_mask_vcvt2ps2phx_512,            // llvm.x86.avx10.mask.vcvt2ps2phx.512 (IntrinsicsX86.td:6915)
    x86_avx10_mask_vcvtbiasph2bf8128,          // llvm.x86.avx10.mask.vcvtbiasph2bf8128 (IntrinsicsX86.td:6918)
    x86_avx10_mask_vcvtbiasph2bf8256,          // llvm.x86.avx10.mask.vcvtbiasph2bf8256 (IntrinsicsX86.td:6921)
    x86_avx10_mask_vcvtbiasph2bf8512,          // llvm.x86.avx10.mask.vcvtbiasph2bf8512 (IntrinsicsX86.td:6924)
    x86_avx10_mask_vcvtbiasph2bf8s128,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s128 (IntrinsicsX86.td:6927)
    x86_avx10_mask_vcvtbiasph2bf8s256,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s256 (IntrinsicsX86.td:6930)
    x86_avx10_mask_vcvtbiasph2bf8s512,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s512 (IntrinsicsX86.td:6933)
    x86_avx10_mask_vcvtbiasph2hf8128,          // llvm.x86.avx10.mask.vcvtbiasph2hf8128 (IntrinsicsX86.td:6936)
    x86_avx10_mask_vcvtbiasph2hf8256,          // llvm.x86.avx10.mask.vcvtbiasph2hf8256 (IntrinsicsX86.td:6939)
    x86_avx10_mask_vcvtbiasph2hf8512,          // llvm.x86.avx10.mask.vcvtbiasph2hf8512 (IntrinsicsX86.td:6942)
    x86_avx10_mask_vcvtbiasph2hf8s128,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s128 (IntrinsicsX86.td:6945)
    x86_avx10_mask_vcvtbiasph2hf8s256,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s256 (IntrinsicsX86.td:6948)
    x86_avx10_mask_vcvtbiasph2hf8s512,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s512 (IntrinsicsX86.td:6951)
    x86_avx10_mask_vcvthf82ph128,              // llvm.x86.avx10.mask.vcvthf82ph128 (IntrinsicsX86.td:6990)
    x86_avx10_mask_vcvthf82ph256,              // llvm.x86.avx10.mask.vcvthf82ph256 (IntrinsicsX86.td:6993)
    x86_avx10_mask_vcvthf82ph512,              // llvm.x86.avx10.mask.vcvthf82ph512 (IntrinsicsX86.td:6996)
    x86_avx10_mask_vcvtph2bf8128,              // llvm.x86.avx10.mask.vcvtph2bf8128 (IntrinsicsX86.td:6999)
    x86_avx10_mask_vcvtph2bf8256,              // llvm.x86.avx10.mask.vcvtph2bf8256 (IntrinsicsX86.td:7002)
    x86_avx10_mask_vcvtph2bf8512,              // llvm.x86.avx10.mask.vcvtph2bf8512 (IntrinsicsX86.td:7005)
    x86_avx10_mask_vcvtph2bf8s128,             // llvm.x86.avx10.mask.vcvtph2bf8s128 (IntrinsicsX86.td:7008)
    x86_avx10_mask_vcvtph2bf8s256,             // llvm.x86.avx10.mask.vcvtph2bf8s256 (IntrinsicsX86.td:7011)
    x86_avx10_mask_vcvtph2bf8s512,             // llvm.x86.avx10.mask.vcvtph2bf8s512 (IntrinsicsX86.td:7014)
    x86_avx10_mask_vcvtph2hf8128,              // llvm.x86.avx10.mask.vcvtph2hf8128 (IntrinsicsX86.td:7017)
    x86_avx10_mask_vcvtph2hf8256,              // llvm.x86.avx10.mask.vcvtph2hf8256 (IntrinsicsX86.td:7020)
    x86_avx10_mask_vcvtph2hf8512,              // llvm.x86.avx10.mask.vcvtph2hf8512 (IntrinsicsX86.td:7023)
    x86_avx10_mask_vcvtph2hf8s128,             // llvm.x86.avx10.mask.vcvtph2hf8s128 (IntrinsicsX86.td:7026)
    x86_avx10_mask_vcvtph2hf8s256,             // llvm.x86.avx10.mask.vcvtph2hf8s256 (IntrinsicsX86.td:7029)
    x86_avx10_mask_vcvtph2hf8s512,             // llvm.x86.avx10.mask.vcvtph2hf8s512 (IntrinsicsX86.td:7032)
    x86_avx10_mask_vcvtph2ibs128,              // llvm.x86.avx10.mask.vcvtph2ibs128 (IntrinsicsX86.td:6815)
    x86_avx10_mask_vcvtph2ibs256,              // llvm.x86.avx10.mask.vcvtph2ibs256 (IntrinsicsX86.td:6818)
    x86_avx10_mask_vcvtph2ibs512,              // llvm.x86.avx10.mask.vcvtph2ibs512 (IntrinsicsX86.td:6821)
    x86_avx10_mask_vcvtph2iubs128,             // llvm.x86.avx10.mask.vcvtph2iubs128 (IntrinsicsX86.td:6824)
    x86_avx10_mask_vcvtph2iubs256,             // llvm.x86.avx10.mask.vcvtph2iubs256 (IntrinsicsX86.td:6827)
    x86_avx10_mask_vcvtph2iubs512,             // llvm.x86.avx10.mask.vcvtph2iubs512 (IntrinsicsX86.td:6830)
    x86_avx10_mask_vcvtps2ibs128,              // llvm.x86.avx10.mask.vcvtps2ibs128 (IntrinsicsX86.td:6833)
    x86_avx10_mask_vcvtps2ibs256,              // llvm.x86.avx10.mask.vcvtps2ibs256 (IntrinsicsX86.td:6836)
    x86_avx10_mask_vcvtps2ibs512,              // llvm.x86.avx10.mask.vcvtps2ibs512 (IntrinsicsX86.td:6839)
    x86_avx10_mask_vcvtps2iubs128,             // llvm.x86.avx10.mask.vcvtps2iubs128 (IntrinsicsX86.td:6842)
    x86_avx10_mask_vcvtps2iubs256,             // llvm.x86.avx10.mask.vcvtps2iubs256 (IntrinsicsX86.td:6845)
    x86_avx10_mask_vcvtps2iubs512,             // llvm.x86.avx10.mask.vcvtps2iubs512 (IntrinsicsX86.td:6848)
    x86_avx10_mask_vcvttpd2dqs_128,            // llvm.x86.avx10.mask.vcvttpd2dqs.128 (IntrinsicsX86.td:5115)
    x86_avx10_mask_vcvttpd2dqs_256,            // llvm.x86.avx10.mask.vcvttpd2dqs.256 (IntrinsicsX86.td:5118)
    x86_avx10_mask_vcvttpd2dqs_round_512,      // llvm.x86.avx10.mask.vcvttpd2dqs.round.512 (IntrinsicsX86.td:5121)
    x86_avx10_mask_vcvttpd2qqs_128,            // llvm.x86.avx10.mask.vcvttpd2qqs.128 (IntrinsicsX86.td:5133)
    x86_avx10_mask_vcvttpd2qqs_256,            // llvm.x86.avx10.mask.vcvttpd2qqs.256 (IntrinsicsX86.td:5136)
    x86_avx10_mask_vcvttpd2qqs_round_512,      // llvm.x86.avx10.mask.vcvttpd2qqs.round.512 (IntrinsicsX86.td:5139)
    x86_avx10_mask_vcvttpd2udqs_128,           // llvm.x86.avx10.mask.vcvttpd2udqs.128 (IntrinsicsX86.td:5124)
    x86_avx10_mask_vcvttpd2udqs_256,           // llvm.x86.avx10.mask.vcvttpd2udqs.256 (IntrinsicsX86.td:5127)
    x86_avx10_mask_vcvttpd2udqs_round_512,     // llvm.x86.avx10.mask.vcvttpd2udqs.round.512 (IntrinsicsX86.td:5130)
    x86_avx10_mask_vcvttpd2uqqs_128,           // llvm.x86.avx10.mask.vcvttpd2uqqs.128 (IntrinsicsX86.td:5142)
    x86_avx10_mask_vcvttpd2uqqs_256,           // llvm.x86.avx10.mask.vcvttpd2uqqs.256 (IntrinsicsX86.td:5145)
    x86_avx10_mask_vcvttpd2uqqs_round_512,     // llvm.x86.avx10.mask.vcvttpd2uqqs.round.512 (IntrinsicsX86.td:5148)
    x86_avx10_mask_vcvttph2ibs128,             // llvm.x86.avx10.mask.vcvttph2ibs128 (IntrinsicsX86.td:6869)
    x86_avx10_mask_vcvttph2ibs256,             // llvm.x86.avx10.mask.vcvttph2ibs256 (IntrinsicsX86.td:6872)
    x86_avx10_mask_vcvttph2ibs512,             // llvm.x86.avx10.mask.vcvttph2ibs512 (IntrinsicsX86.td:6875)
    x86_avx10_mask_vcvttph2iubs128,            // llvm.x86.avx10.mask.vcvttph2iubs128 (IntrinsicsX86.td:6878)
    x86_avx10_mask_vcvttph2iubs256,            // llvm.x86.avx10.mask.vcvttph2iubs256 (IntrinsicsX86.td:6881)
    x86_avx10_mask_vcvttph2iubs512,            // llvm.x86.avx10.mask.vcvttph2iubs512 (IntrinsicsX86.td:6884)
    x86_avx10_mask_vcvttps2dqs_128,            // llvm.x86.avx10.mask.vcvttps2dqs.128 (IntrinsicsX86.td:5151)
    x86_avx10_mask_vcvttps2dqs_256,            // llvm.x86.avx10.mask.vcvttps2dqs.256 (IntrinsicsX86.td:5154)
    x86_avx10_mask_vcvttps2dqs_round_512,      // llvm.x86.avx10.mask.vcvttps2dqs.round.512 (IntrinsicsX86.td:5157)
    x86_avx10_mask_vcvttps2ibs128,             // llvm.x86.avx10.mask.vcvttps2ibs128 (IntrinsicsX86.td:6887)
    x86_avx10_mask_vcvttps2ibs256,             // llvm.x86.avx10.mask.vcvttps2ibs256 (IntrinsicsX86.td:6890)
    x86_avx10_mask_vcvttps2ibs512,             // llvm.x86.avx10.mask.vcvttps2ibs512 (IntrinsicsX86.td:6893)
    x86_avx10_mask_vcvttps2iubs128,            // llvm.x86.avx10.mask.vcvttps2iubs128 (IntrinsicsX86.td:6896)
    x86_avx10_mask_vcvttps2iubs256,            // llvm.x86.avx10.mask.vcvttps2iubs256 (IntrinsicsX86.td:6899)
    x86_avx10_mask_vcvttps2iubs512,            // llvm.x86.avx10.mask.vcvttps2iubs512 (IntrinsicsX86.td:6902)
    x86_avx10_mask_vcvttps2qqs_128,            // llvm.x86.avx10.mask.vcvttps2qqs.128 (IntrinsicsX86.td:5169)
    x86_avx10_mask_vcvttps2qqs_256,            // llvm.x86.avx10.mask.vcvttps2qqs.256 (IntrinsicsX86.td:5172)
    x86_avx10_mask_vcvttps2qqs_round_512,      // llvm.x86.avx10.mask.vcvttps2qqs.round.512 (IntrinsicsX86.td:5175)
    x86_avx10_mask_vcvttps2udqs_128,           // llvm.x86.avx10.mask.vcvttps2udqs.128 (IntrinsicsX86.td:5160)
    x86_avx10_mask_vcvttps2udqs_256,           // llvm.x86.avx10.mask.vcvttps2udqs.256 (IntrinsicsX86.td:5163)
    x86_avx10_mask_vcvttps2udqs_round_512,     // llvm.x86.avx10.mask.vcvttps2udqs.round.512 (IntrinsicsX86.td:5166)
    x86_avx10_mask_vcvttps2uqqs_128,           // llvm.x86.avx10.mask.vcvttps2uqqs.128 (IntrinsicsX86.td:5178)
    x86_avx10_mask_vcvttps2uqqs_256,           // llvm.x86.avx10.mask.vcvttps2uqqs.256 (IntrinsicsX86.td:5181)
    x86_avx10_mask_vcvttps2uqqs_round_512,     // llvm.x86.avx10.mask.vcvttps2uqqs.round.512 (IntrinsicsX86.td:5184)
    x86_avx10_mask_vminmaxpd_round,            // llvm.x86.avx10.mask.vminmaxpd.round (IntrinsicsX86.td:6751)
    x86_avx10_mask_vminmaxpd128,               // llvm.x86.avx10.mask.vminmaxpd128 (IntrinsicsX86.td:6742)
    x86_avx10_mask_vminmaxpd256,               // llvm.x86.avx10.mask.vminmaxpd256 (IntrinsicsX86.td:6748)
    x86_avx10_mask_vminmaxph_round,            // llvm.x86.avx10.mask.vminmaxph.round (IntrinsicsX86.td:6766)
    x86_avx10_mask_vminmaxph128,               // llvm.x86.avx10.mask.vminmaxph128 (IntrinsicsX86.td:6757)
    x86_avx10_mask_vminmaxph256,               // llvm.x86.avx10.mask.vminmaxph256 (IntrinsicsX86.td:6763)
    x86_avx10_mask_vminmaxps_round,            // llvm.x86.avx10.mask.vminmaxps.round (IntrinsicsX86.td:6781)
    x86_avx10_mask_vminmaxps128,               // llvm.x86.avx10.mask.vminmaxps128 (IntrinsicsX86.td:6772)
    x86_avx10_mask_vminmaxps256,               // llvm.x86.avx10.mask.vminmaxps256 (IntrinsicsX86.td:6778)
    x86_avx10_mask_vminmaxsd_round,            // llvm.x86.avx10.mask.vminmaxsd.round (IntrinsicsX86.td:6784)
    x86_avx10_mask_vminmaxsh_round,            // llvm.x86.avx10.mask.vminmaxsh.round (IntrinsicsX86.td:6787)
    x86_avx10_mask_vminmaxss_round,            // llvm.x86.avx10.mask.vminmaxss.round (IntrinsicsX86.td:6790)
    x86_avx10_vaddbf16128,                     // llvm.x86.avx10.vaddbf16128 (IntrinsicsX86.td:7045)
    x86_avx10_vaddbf16256,                     // llvm.x86.avx10.vaddbf16256 (IntrinsicsX86.td:7042)
    x86_avx10_vaddbf16512,                     // llvm.x86.avx10.vaddbf16512 (IntrinsicsX86.td:7039)
    x86_avx10_vaddpd256,                       // llvm.x86.avx10.vaddpd256 (IntrinsicsX86.td:5072)
    x86_avx10_vaddph256,                       // llvm.x86.avx10.vaddph256 (IntrinsicsX86.td:5077)
    x86_avx10_vaddps256,                       // llvm.x86.avx10.vaddps256 (IntrinsicsX86.td:5082)
    x86_avx10_vcomisbf16eq,                    // llvm.x86.avx10.vcomisbf16eq (IntrinsicsX86.td:7093)
    x86_avx10_vcomisbf16ge,                    // llvm.x86.avx10.vcomisbf16ge (IntrinsicsX86.td:7105)
    x86_avx10_vcomisbf16gt,                    // llvm.x86.avx10.vcomisbf16gt (IntrinsicsX86.td:7102)
    x86_avx10_vcomisbf16le,                    // llvm.x86.avx10.vcomisbf16le (IntrinsicsX86.td:7099)
    x86_avx10_vcomisbf16lt,                    // llvm.x86.avx10.vcomisbf16lt (IntrinsicsX86.td:7096)
    x86_avx10_vcomisbf16neq,                   // llvm.x86.avx10.vcomisbf16neq (IntrinsicsX86.td:7108)
    x86_avx10_vcvt2ph2bf8128,                  // llvm.x86.avx10.vcvt2ph2bf8128 (IntrinsicsX86.td:6954)
    x86_avx10_vcvt2ph2bf8256,                  // llvm.x86.avx10.vcvt2ph2bf8256 (IntrinsicsX86.td:6957)
    x86_avx10_vcvt2ph2bf8512,                  // llvm.x86.avx10.vcvt2ph2bf8512 (IntrinsicsX86.td:6960)
    x86_avx10_vcvt2ph2bf8s128,                 // llvm.x86.avx10.vcvt2ph2bf8s128 (IntrinsicsX86.td:6963)
    x86_avx10_vcvt2ph2bf8s256,                 // llvm.x86.avx10.vcvt2ph2bf8s256 (IntrinsicsX86.td:6966)
    x86_avx10_vcvt2ph2bf8s512,                 // llvm.x86.avx10.vcvt2ph2bf8s512 (IntrinsicsX86.td:6969)
    x86_avx10_vcvt2ph2hf8128,                  // llvm.x86.avx10.vcvt2ph2hf8128 (IntrinsicsX86.td:6972)
    x86_avx10_vcvt2ph2hf8256,                  // llvm.x86.avx10.vcvt2ph2hf8256 (IntrinsicsX86.td:6975)
    x86_avx10_vcvt2ph2hf8512,                  // llvm.x86.avx10.vcvt2ph2hf8512 (IntrinsicsX86.td:6978)
    x86_avx10_vcvt2ph2hf8s128,                 // llvm.x86.avx10.vcvt2ph2hf8s128 (IntrinsicsX86.td:6981)
    x86_avx10_vcvt2ph2hf8s256,                 // llvm.x86.avx10.vcvt2ph2hf8s256 (IntrinsicsX86.td:6984)
    x86_avx10_vcvt2ph2hf8s512,                 // llvm.x86.avx10.vcvt2ph2hf8s512 (IntrinsicsX86.td:6987)
    x86_avx10_vcvtbf162ibs128,                 // llvm.x86.avx10.vcvtbf162ibs128 (IntrinsicsX86.td:6797)
    x86_avx10_vcvtbf162ibs256,                 // llvm.x86.avx10.vcvtbf162ibs256 (IntrinsicsX86.td:6800)
    x86_avx10_vcvtbf162ibs512,                 // llvm.x86.avx10.vcvtbf162ibs512 (IntrinsicsX86.td:6803)
    x86_avx10_vcvtbf162iubs128,                // llvm.x86.avx10.vcvtbf162iubs128 (IntrinsicsX86.td:6806)
    x86_avx10_vcvtbf162iubs256,                // llvm.x86.avx10.vcvtbf162iubs256 (IntrinsicsX86.td:6809)
    x86_avx10_vcvtbf162iubs512,                // llvm.x86.avx10.vcvtbf162iubs512 (IntrinsicsX86.td:6812)
    x86_avx10_vcvttbf162ibs128,                // llvm.x86.avx10.vcvttbf162ibs128 (IntrinsicsX86.td:6851)
    x86_avx10_vcvttbf162ibs256,                // llvm.x86.avx10.vcvttbf162ibs256 (IntrinsicsX86.td:6854)
    x86_avx10_vcvttbf162ibs512,                // llvm.x86.avx10.vcvttbf162ibs512 (IntrinsicsX86.td:6857)
    x86_avx10_vcvttbf162iubs128,               // llvm.x86.avx10.vcvttbf162iubs128 (IntrinsicsX86.td:6860)
    x86_avx10_vcvttbf162iubs256,               // llvm.x86.avx10.vcvttbf162iubs256 (IntrinsicsX86.td:6863)
    x86_avx10_vcvttbf162iubs512,               // llvm.x86.avx10.vcvttbf162iubs512 (IntrinsicsX86.td:6866)
    x86_avx10_vcvttsd2sis,                     // llvm.x86.avx10.vcvttsd2sis (IntrinsicsX86.td:5103)
    x86_avx10_vcvttsd2sis64,                   // llvm.x86.avx10.vcvttsd2sis64 (IntrinsicsX86.td:5106)
    x86_avx10_vcvttsd2usis,                    // llvm.x86.avx10.vcvttsd2usis (IntrinsicsX86.td:5109)
    x86_avx10_vcvttsd2usis64,                  // llvm.x86.avx10.vcvttsd2usis64 (IntrinsicsX86.td:5112)
    x86_avx10_vcvttss2sis,                     // llvm.x86.avx10.vcvttss2sis (IntrinsicsX86.td:5091)
    x86_avx10_vcvttss2sis64,                   // llvm.x86.avx10.vcvttss2sis64 (IntrinsicsX86.td:5094)
    x86_avx10_vcvttss2usis,                    // llvm.x86.avx10.vcvttss2usis (IntrinsicsX86.td:5097)
    x86_avx10_vcvttss2usis64,                  // llvm.x86.avx10.vcvttss2usis64 (IntrinsicsX86.td:5100)
    x86_avx10_vdivbf16128,                     // llvm.x86.avx10.vdivbf16128 (IntrinsicsX86.td:7072)
    x86_avx10_vdivbf16256,                     // llvm.x86.avx10.vdivbf16256 (IntrinsicsX86.td:7069)
    x86_avx10_vdivbf16512,                     // llvm.x86.avx10.vdivbf16512 (IntrinsicsX86.td:7066)
    x86_avx10_vdpphps_128,                     // llvm.x86.avx10.vdpphps.128 (IntrinsicsX86.td:4986)
    x86_avx10_vdpphps_256,                     // llvm.x86.avx10.vdpphps.256 (IntrinsicsX86.td:4991)
    x86_avx10_vdpphps_512,                     // llvm.x86.avx10.vdpphps.512 (IntrinsicsX86.td:4996)
    x86_avx10_vfmadd132bf16128,                // llvm.x86.avx10.vfmadd132bf16128 (IntrinsicsX86.td:7195)
    x86_avx10_vfmadd132bf16256,                // llvm.x86.avx10.vfmadd132bf16256 (IntrinsicsX86.td:7192)
    x86_avx10_vfmadd132bf16512,                // llvm.x86.avx10.vfmadd132bf16512 (IntrinsicsX86.td:7189)
    x86_avx10_vfmadd213bf16128,                // llvm.x86.avx10.vfmadd213bf16128 (IntrinsicsX86.td:7186)
    x86_avx10_vfmadd213bf16256,                // llvm.x86.avx10.vfmadd213bf16256 (IntrinsicsX86.td:7183)
    x86_avx10_vfmadd231bf16128,                // llvm.x86.avx10.vfmadd231bf16128 (IntrinsicsX86.td:7204)
    x86_avx10_vfmadd231bf16256,                // llvm.x86.avx10.vfmadd231bf16256 (IntrinsicsX86.td:7201)
    x86_avx10_vfmadd231bf16512,                // llvm.x86.avx10.vfmadd231bf16512 (IntrinsicsX86.td:7198)
    x86_avx10_vfmsub132bf16128,                // llvm.x86.avx10.vfmsub132bf16128 (IntrinsicsX86.td:7222)
    x86_avx10_vfmsub132bf16256,                // llvm.x86.avx10.vfmsub132bf16256 (IntrinsicsX86.td:7219)
    x86_avx10_vfmsub132bf16512,                // llvm.x86.avx10.vfmsub132bf16512 (IntrinsicsX86.td:7216)
    x86_avx10_vfmsub213bf16128,                // llvm.x86.avx10.vfmsub213bf16128 (IntrinsicsX86.td:7213)
    x86_avx10_vfmsub213bf16256,                // llvm.x86.avx10.vfmsub213bf16256 (IntrinsicsX86.td:7210)
    x86_avx10_vfmsub213bf16512,                // llvm.x86.avx10.vfmsub213bf16512 (IntrinsicsX86.td:7207)
    x86_avx10_vfmsub231bf16128,                // llvm.x86.avx10.vfmsub231bf16128 (IntrinsicsX86.td:7231)
    x86_avx10_vfmsub231bf16256,                // llvm.x86.avx10.vfmsub231bf16256 (IntrinsicsX86.td:7228)
    x86_avx10_vfmsub231bf16512,                // llvm.x86.avx10.vfmsub231bf16512 (IntrinsicsX86.td:7225)
    x86_avx10_vfnmadd132bf16128,               // llvm.x86.avx10.vfnmadd132bf16128 (IntrinsicsX86.td:7249)
    x86_avx10_vfnmadd132bf16256,               // llvm.x86.avx10.vfnmadd132bf16256 (IntrinsicsX86.td:7246)
    x86_avx10_vfnmadd132bf16512,               // llvm.x86.avx10.vfnmadd132bf16512 (IntrinsicsX86.td:7243)
    x86_avx10_vfnmadd213bf16128,               // llvm.x86.avx10.vfnmadd213bf16128 (IntrinsicsX86.td:7240)
    x86_avx10_vfnmadd213bf16256,               // llvm.x86.avx10.vfnmadd213bf16256 (IntrinsicsX86.td:7237)
    x86_avx10_vfnmadd213bf16512,               // llvm.x86.avx10.vfnmadd213bf16512 (IntrinsicsX86.td:7234)
    x86_avx10_vfnmadd231bf16128,               // llvm.x86.avx10.vfnmadd231bf16128 (IntrinsicsX86.td:7258)
    x86_avx10_vfnmadd231bf16256,               // llvm.x86.avx10.vfnmadd231bf16256 (IntrinsicsX86.td:7255)
    x86_avx10_vfnmadd231bf16512,               // llvm.x86.avx10.vfnmadd231bf16512 (IntrinsicsX86.td:7252)
    x86_avx10_vfnmsub132bf16128,               // llvm.x86.avx10.vfnmsub132bf16128 (IntrinsicsX86.td:7276)
    x86_avx10_vfnmsub132bf16256,               // llvm.x86.avx10.vfnmsub132bf16256 (IntrinsicsX86.td:7273)
    x86_avx10_vfnmsub132bf16512,               // llvm.x86.avx10.vfnmsub132bf16512 (IntrinsicsX86.td:7270)
    x86_avx10_vfnmsub213bf16128,               // llvm.x86.avx10.vfnmsub213bf16128 (IntrinsicsX86.td:7267)
    x86_avx10_vfnmsub213bf16256,               // llvm.x86.avx10.vfnmsub213bf16256 (IntrinsicsX86.td:7264)
    x86_avx10_vfnmsub213bf16512,               // llvm.x86.avx10.vfnmsub213bf16512 (IntrinsicsX86.td:7261)
    x86_avx10_vfnmsub231bf16128,               // llvm.x86.avx10.vfnmsub231bf16128 (IntrinsicsX86.td:7285)
    x86_avx10_vfnmsub231bf16256,               // llvm.x86.avx10.vfnmsub231bf16256 (IntrinsicsX86.td:7282)
    x86_avx10_vfnmsub231bf16512,               // llvm.x86.avx10.vfnmsub231bf16512 (IntrinsicsX86.td:7279)
    x86_avx10_vmaxbf16128,                     // llvm.x86.avx10.vmaxbf16128 (IntrinsicsX86.td:7081)
    x86_avx10_vmaxbf16256,                     // llvm.x86.avx10.vmaxbf16256 (IntrinsicsX86.td:7078)
    x86_avx10_vmaxbf16512,                     // llvm.x86.avx10.vmaxbf16512 (IntrinsicsX86.td:7075)
    x86_avx10_vminbf16128,                     // llvm.x86.avx10.vminbf16128 (IntrinsicsX86.td:7090)
    x86_avx10_vminbf16256,                     // llvm.x86.avx10.vminbf16256 (IntrinsicsX86.td:7087)
    x86_avx10_vminbf16512,                     // llvm.x86.avx10.vminbf16512 (IntrinsicsX86.td:7084)
    x86_avx10_vminmaxbf16128,                  // llvm.x86.avx10.vminmaxbf16128 (IntrinsicsX86.td:6730)
    x86_avx10_vminmaxbf16256,                  // llvm.x86.avx10.vminmaxbf16256 (IntrinsicsX86.td:6733)
    x86_avx10_vminmaxbf16512,                  // llvm.x86.avx10.vminmaxbf16512 (IntrinsicsX86.td:6736)
    x86_avx10_vminmaxpd128,                    // llvm.x86.avx10.vminmaxpd128 (IntrinsicsX86.td:6739)
    x86_avx10_vminmaxpd256,                    // llvm.x86.avx10.vminmaxpd256 (IntrinsicsX86.td:6745)
    x86_avx10_vminmaxph128,                    // llvm.x86.avx10.vminmaxph128 (IntrinsicsX86.td:6754)
    x86_avx10_vminmaxph256,                    // llvm.x86.avx10.vminmaxph256 (IntrinsicsX86.td:6760)
    x86_avx10_vminmaxps128,                    // llvm.x86.avx10.vminmaxps128 (IntrinsicsX86.td:6769)
    x86_avx10_vminmaxps256,                    // llvm.x86.avx10.vminmaxps256 (IntrinsicsX86.td:6775)
    x86_avx10_vmovrsb128,                      // llvm.x86.avx10.vmovrsb128 (IntrinsicsX86.td:7291)
    x86_avx10_vmovrsb256,                      // llvm.x86.avx10.vmovrsb256 (IntrinsicsX86.td:7294)
    x86_avx10_vmovrsb512,                      // llvm.x86.avx10.vmovrsb512 (IntrinsicsX86.td:7297)
    x86_avx10_vmovrsd128,                      // llvm.x86.avx10.vmovrsd128 (IntrinsicsX86.td:7300)
    x86_avx10_vmovrsd256,                      // llvm.x86.avx10.vmovrsd256 (IntrinsicsX86.td:7303)
    x86_avx10_vmovrsd512,                      // llvm.x86.avx10.vmovrsd512 (IntrinsicsX86.td:7306)
    x86_avx10_vmovrsq128,                      // llvm.x86.avx10.vmovrsq128 (IntrinsicsX86.td:7309)
    x86_avx10_vmovrsq256,                      // llvm.x86.avx10.vmovrsq256 (IntrinsicsX86.td:7312)
    x86_avx10_vmovrsq512,                      // llvm.x86.avx10.vmovrsq512 (IntrinsicsX86.td:7315)
    x86_avx10_vmovrsw128,                      // llvm.x86.avx10.vmovrsw128 (IntrinsicsX86.td:7318)
    x86_avx10_vmovrsw256,                      // llvm.x86.avx10.vmovrsw256 (IntrinsicsX86.td:7321)
    x86_avx10_vmovrsw512,                      // llvm.x86.avx10.vmovrsw512 (IntrinsicsX86.td:7324)
    x86_avx10_vmpsadbw_512,                    // llvm.x86.avx10.vmpsadbw.512 (IntrinsicsX86.td:5065)
    x86_avx10_vmulbf16128,                     // llvm.x86.avx10.vmulbf16128 (IntrinsicsX86.td:7063)
    x86_avx10_vmulbf16256,                     // llvm.x86.avx10.vmulbf16256 (IntrinsicsX86.td:7060)
    x86_avx10_vmulbf16512,                     // llvm.x86.avx10.vmulbf16512 (IntrinsicsX86.td:7057)
    x86_avx10_vpdpbssd_512,                    // llvm.x86.avx10.vpdpbssd.512 (IntrinsicsX86.td:5002)
    x86_avx10_vpdpbssds_512,                   // llvm.x86.avx10.vpdpbssds.512 (IntrinsicsX86.td:5007)
    x86_avx10_vpdpbsud_512,                    // llvm.x86.avx10.vpdpbsud.512 (IntrinsicsX86.td:5012)
    x86_avx10_vpdpbsuds_512,                   // llvm.x86.avx10.vpdpbsuds.512 (IntrinsicsX86.td:5017)
    x86_avx10_vpdpbuud_512,                    // llvm.x86.avx10.vpdpbuud.512 (IntrinsicsX86.td:5022)
    x86_avx10_vpdpbuuds_512,                   // llvm.x86.avx10.vpdpbuuds.512 (IntrinsicsX86.td:5027)
    x86_avx10_vpdpwsud_512,                    // llvm.x86.avx10.vpdpwsud.512 (IntrinsicsX86.td:5033)
    x86_avx10_vpdpwsuds_512,                   // llvm.x86.avx10.vpdpwsuds.512 (IntrinsicsX86.td:5038)
    x86_avx10_vpdpwusd_512,                    // llvm.x86.avx10.vpdpwusd.512 (IntrinsicsX86.td:5043)
    x86_avx10_vpdpwusds_512,                   // llvm.x86.avx10.vpdpwusds.512 (IntrinsicsX86.td:5048)
    x86_avx10_vpdpwuud_512,                    // llvm.x86.avx10.vpdpwuud.512 (IntrinsicsX86.td:5053)
    x86_avx10_vpdpwuuds_512,                   // llvm.x86.avx10.vpdpwuuds.512 (IntrinsicsX86.td:5058)
    x86_avx10_vsubbf16128,                     // llvm.x86.avx10.vsubbf16128 (IntrinsicsX86.td:7054)
    x86_avx10_vsubbf16256,                     // llvm.x86.avx10.vsubbf16256 (IntrinsicsX86.td:7051)
    x86_avx10_vsubbf16512,                     // llvm.x86.avx10.vsubbf16512 (IntrinsicsX86.td:7048)
    x86_avx2_gather_d_d,                       // llvm.x86.avx2.gather.d.d (IntrinsicsX86.td:1760)
    x86_avx2_gather_d_d_256,                   // llvm.x86.avx2.gather.d.d.256 (IntrinsicsX86.td:1764)
    x86_avx2_gather_d_pd,                      // llvm.x86.avx2.gather.d.pd (IntrinsicsX86.td:1711)
    x86_avx2_gather_d_pd_256,                  // llvm.x86.avx2.gather.d.pd.256 (IntrinsicsX86.td:1715)
    x86_avx2_gather_d_ps,                      // llvm.x86.avx2.gather.d.ps (IntrinsicsX86.td:1727)
    x86_avx2_gather_d_ps_256,                  // llvm.x86.avx2.gather.d.ps.256 (IntrinsicsX86.td:1731)
    x86_avx2_gather_d_q,                       // llvm.x86.avx2.gather.d.q (IntrinsicsX86.td:1744)
    x86_avx2_gather_d_q_256,                   // llvm.x86.avx2.gather.d.q.256 (IntrinsicsX86.td:1748)
    x86_avx2_gather_q_d,                       // llvm.x86.avx2.gather.q.d (IntrinsicsX86.td:1768)
    x86_avx2_gather_q_d_256,                   // llvm.x86.avx2.gather.q.d.256 (IntrinsicsX86.td:1772)
    x86_avx2_gather_q_pd,                      // llvm.x86.avx2.gather.q.pd (IntrinsicsX86.td:1719)
    x86_avx2_gather_q_pd_256,                  // llvm.x86.avx2.gather.q.pd.256 (IntrinsicsX86.td:1723)
    x86_avx2_gather_q_ps,                      // llvm.x86.avx2.gather.q.ps (IntrinsicsX86.td:1735)
    x86_avx2_gather_q_ps_256,                  // llvm.x86.avx2.gather.q.ps.256 (IntrinsicsX86.td:1739)
    x86_avx2_gather_q_q,                       // llvm.x86.avx2.gather.q.q (IntrinsicsX86.td:1752)
    x86_avx2_gather_q_q_256,                   // llvm.x86.avx2.gather.q.q.256 (IntrinsicsX86.td:1756)
    x86_avx2_maskload_d,                       // llvm.x86.avx2.maskload.d (IntrinsicsX86.td:1582)
    x86_avx2_maskload_d_256,                   // llvm.x86.avx2.maskload.d.256 (IntrinsicsX86.td:1588)
    x86_avx2_maskload_q,                       // llvm.x86.avx2.maskload.q (IntrinsicsX86.td:1585)
    x86_avx2_maskload_q_256,                   // llvm.x86.avx2.maskload.q.256 (IntrinsicsX86.td:1591)
    x86_avx2_maskstore_d,                      // llvm.x86.avx2.maskstore.d (IntrinsicsX86.td:1598)
    x86_avx2_maskstore_d_256,                  // llvm.x86.avx2.maskstore.d.256 (IntrinsicsX86.td:1604)
    x86_avx2_maskstore_q,                      // llvm.x86.avx2.maskstore.q (IntrinsicsX86.td:1601)
    x86_avx2_maskstore_q_256,                  // llvm.x86.avx2.maskstore.q.256 (IntrinsicsX86.td:1608)
    x86_avx2_mpsadbw,                          // llvm.x86.avx2.mpsadbw (IntrinsicsX86.td:1785)
    x86_avx2_packssdw,                         // llvm.x86.avx2.packssdw (IntrinsicsX86.td:1503)
    x86_avx2_packsswb,                         // llvm.x86.avx2.packsswb (IntrinsicsX86.td:1500)
    x86_avx2_packusdw,                         // llvm.x86.avx2.packusdw (IntrinsicsX86.td:1509)
    x86_avx2_packuswb,                         // llvm.x86.avx2.packuswb (IntrinsicsX86.td:1506)
    x86_avx2_pavg_b,                           // llvm.x86.avx2.pavg.b (IntrinsicsX86.td:1348)
    x86_avx2_pavg_w,                           // llvm.x86.avx2.pavg.w (IntrinsicsX86.td:1351)
    x86_avx2_pblendvb,                         // llvm.x86.avx2.pblendvb (IntrinsicsX86.td:1564)
    x86_avx2_permd,                            // llvm.x86.avx2.permd (IntrinsicsX86.td:1572)
    x86_avx2_permps,                           // llvm.x86.avx2.permps (IntrinsicsX86.td:1575)
    x86_avx2_phadd_d,                          // llvm.x86.avx2.phadd.d (IntrinsicsX86.td:1519)
    x86_avx2_phadd_sw,                         // llvm.x86.avx2.phadd.sw (IntrinsicsX86.td:1522)
    x86_avx2_phadd_w,                          // llvm.x86.avx2.phadd.w (IntrinsicsX86.td:1516)
    x86_avx2_phsub_d,                          // llvm.x86.avx2.phsub.d (IntrinsicsX86.td:1528)
    x86_avx2_phsub_sw,                         // llvm.x86.avx2.phsub.sw (IntrinsicsX86.td:1531)
    x86_avx2_phsub_w,                          // llvm.x86.avx2.phsub.w (IntrinsicsX86.td:1525)
    x86_avx2_pmadd_ub_sw,                      // llvm.x86.avx2.pmadd.ub.sw (IntrinsicsX86.td:1534)
    x86_avx2_pmadd_wd,                         // llvm.x86.avx2.pmadd.wd (IntrinsicsX86.td:1345)
    x86_avx2_pmovmskb,                         // llvm.x86.avx2.pmovmskb (IntrinsicsX86.td:1780)
    x86_avx2_pmul_hr_sw,                       // llvm.x86.avx2.pmul.hr.sw (IntrinsicsX86.td:1554)
    x86_avx2_pmulh_w,                          // llvm.x86.avx2.pmulh.w (IntrinsicsX86.td:1342)
    x86_avx2_pmulhu_w,                         // llvm.x86.avx2.pmulhu.w (IntrinsicsX86.td:1339)
    x86_avx2_psad_bw,                          // llvm.x86.avx2.psad.bw (IntrinsicsX86.td:1354)
    x86_avx2_pshuf_b,                          // llvm.x86.avx2.pshuf.b (IntrinsicsX86.td:1782)
    x86_avx2_psign_b,                          // llvm.x86.avx2.psign.b (IntrinsicsX86.td:1541)
    x86_avx2_psign_d,                          // llvm.x86.avx2.psign.d (IntrinsicsX86.td:1547)
    x86_avx2_psign_w,                          // llvm.x86.avx2.psign.w (IntrinsicsX86.td:1544)
    x86_avx2_psll_d,                           // llvm.x86.avx2.psll.d (IntrinsicsX86.td:1364)
    x86_avx2_psll_q,                           // llvm.x86.avx2.psll.q (IntrinsicsX86.td:1367)
    x86_avx2_psll_w,                           // llvm.x86.avx2.psll.w (IntrinsicsX86.td:1361)
    x86_avx2_pslli_d,                          // llvm.x86.avx2.pslli.d (IntrinsicsX86.td:1390)
    x86_avx2_pslli_q,                          // llvm.x86.avx2.pslli.q (IntrinsicsX86.td:1393)
    x86_avx2_pslli_w,                          // llvm.x86.avx2.pslli.w (IntrinsicsX86.td:1387)
    x86_avx2_psllv_d,                          // llvm.x86.avx2.psllv.d (IntrinsicsX86.td:1616)
    x86_avx2_psllv_d_256,                      // llvm.x86.avx2.psllv.d.256 (IntrinsicsX86.td:1619)
    x86_avx2_psllv_q,                          // llvm.x86.avx2.psllv.q (IntrinsicsX86.td:1622)
    x86_avx2_psllv_q_256,                      // llvm.x86.avx2.psllv.q.256 (IntrinsicsX86.td:1625)
    x86_avx2_psra_d,                           // llvm.x86.avx2.psra.d (IntrinsicsX86.td:1382)
    x86_avx2_psra_w,                           // llvm.x86.avx2.psra.w (IntrinsicsX86.td:1379)
    x86_avx2_psrai_d,                          // llvm.x86.avx2.psrai.d (IntrinsicsX86.td:1408)
    x86_avx2_psrai_w,                          // llvm.x86.avx2.psrai.w (IntrinsicsX86.td:1405)
    x86_avx2_psrav_d,                          // llvm.x86.avx2.psrav.d (IntrinsicsX86.td:1656)
    x86_avx2_psrav_d_256,                      // llvm.x86.avx2.psrav.d.256 (IntrinsicsX86.td:1659)
    x86_avx2_psrl_d,                           // llvm.x86.avx2.psrl.d (IntrinsicsX86.td:1373)
    x86_avx2_psrl_q,                           // llvm.x86.avx2.psrl.q (IntrinsicsX86.td:1376)
    x86_avx2_psrl_w,                           // llvm.x86.avx2.psrl.w (IntrinsicsX86.td:1370)
    x86_avx2_psrli_d,                          // llvm.x86.avx2.psrli.d (IntrinsicsX86.td:1399)
    x86_avx2_psrli_q,                          // llvm.x86.avx2.psrli.q (IntrinsicsX86.td:1402)
    x86_avx2_psrli_w,                          // llvm.x86.avx2.psrli.w (IntrinsicsX86.td:1396)
    x86_avx2_psrlv_d,                          // llvm.x86.avx2.psrlv.d (IntrinsicsX86.td:1636)
    x86_avx2_psrlv_d_256,                      // llvm.x86.avx2.psrlv.d.256 (IntrinsicsX86.td:1639)
    x86_avx2_psrlv_q,                          // llvm.x86.avx2.psrlv.q (IntrinsicsX86.td:1642)
    x86_avx2_psrlv_q_256,                      // llvm.x86.avx2.psrlv.q.256 (IntrinsicsX86.td:1645)
    x86_avx2_vpdpbssd_128,                     // llvm.x86.avx2.vpdpbssd.128 (IntrinsicsX86.td:1921)
    x86_avx2_vpdpbssd_256,                     // llvm.x86.avx2.vpdpbssd.256 (IntrinsicsX86.td:1926)
    x86_avx2_vpdpbssds_128,                    // llvm.x86.avx2.vpdpbssds.128 (IntrinsicsX86.td:1931)
    x86_avx2_vpdpbssds_256,                    // llvm.x86.avx2.vpdpbssds.256 (IntrinsicsX86.td:1936)
    x86_avx2_vpdpbsud_128,                     // llvm.x86.avx2.vpdpbsud.128 (IntrinsicsX86.td:1941)
    x86_avx2_vpdpbsud_256,                     // llvm.x86.avx2.vpdpbsud.256 (IntrinsicsX86.td:1946)
    x86_avx2_vpdpbsuds_128,                    // llvm.x86.avx2.vpdpbsuds.128 (IntrinsicsX86.td:1951)
    x86_avx2_vpdpbsuds_256,                    // llvm.x86.avx2.vpdpbsuds.256 (IntrinsicsX86.td:1956)
    x86_avx2_vpdpbuud_128,                     // llvm.x86.avx2.vpdpbuud.128 (IntrinsicsX86.td:1961)
    x86_avx2_vpdpbuud_256,                     // llvm.x86.avx2.vpdpbuud.256 (IntrinsicsX86.td:1966)
    x86_avx2_vpdpbuuds_128,                    // llvm.x86.avx2.vpdpbuuds.128 (IntrinsicsX86.td:1971)
    x86_avx2_vpdpbuuds_256,                    // llvm.x86.avx2.vpdpbuuds.256 (IntrinsicsX86.td:1976)
    x86_avx2_vpdpwsud_128,                     // llvm.x86.avx2.vpdpwsud.128 (IntrinsicsX86.td:1982)
    x86_avx2_vpdpwsud_256,                     // llvm.x86.avx2.vpdpwsud.256 (IntrinsicsX86.td:1987)
    x86_avx2_vpdpwsuds_128,                    // llvm.x86.avx2.vpdpwsuds.128 (IntrinsicsX86.td:1992)
    x86_avx2_vpdpwsuds_256,                    // llvm.x86.avx2.vpdpwsuds.256 (IntrinsicsX86.td:1997)
    x86_avx2_vpdpwusd_128,                     // llvm.x86.avx2.vpdpwusd.128 (IntrinsicsX86.td:2002)
    x86_avx2_vpdpwusd_256,                     // llvm.x86.avx2.vpdpwusd.256 (IntrinsicsX86.td:2007)
    x86_avx2_vpdpwusds_128,                    // llvm.x86.avx2.vpdpwusds.128 (IntrinsicsX86.td:2012)
    x86_avx2_vpdpwusds_256,                    // llvm.x86.avx2.vpdpwusds.256 (IntrinsicsX86.td:2017)
    x86_avx2_vpdpwuud_128,                     // llvm.x86.avx2.vpdpwuud.128 (IntrinsicsX86.td:2022)
    x86_avx2_vpdpwuud_256,                     // llvm.x86.avx2.vpdpwuud.256 (IntrinsicsX86.td:2027)
    x86_avx2_vpdpwuuds_128,                    // llvm.x86.avx2.vpdpwuuds.128 (IntrinsicsX86.td:2032)
    x86_avx2_vpdpwuuds_256,                    // llvm.x86.avx2.vpdpwuuds.256 (IntrinsicsX86.td:2037)
    x86_avx512_add_pd_512,                     // llvm.x86.avx512.add.pd.512 (IntrinsicsX86.td:3349)
    x86_avx512_add_ps_512,                     // llvm.x86.avx512.add.ps.512 (IntrinsicsX86.td:3346)
    x86_avx512_broadcastmb_128,                // llvm.x86.avx512.broadcastmb.128 (IntrinsicsX86.td:3338)
    x86_avx512_broadcastmb_256,                // llvm.x86.avx512.broadcastmb.256 (IntrinsicsX86.td:3335)
    x86_avx512_broadcastmb_512,                // llvm.x86.avx512.broadcastmb.512 (IntrinsicsX86.td:3332)
    x86_avx512_broadcastmw_128,                // llvm.x86.avx512.broadcastmw.128 (IntrinsicsX86.td:3329)
    x86_avx512_broadcastmw_256,                // llvm.x86.avx512.broadcastmw.256 (IntrinsicsX86.td:3326)
    x86_avx512_broadcastmw_512,                // llvm.x86.avx512.broadcastmw.512 (IntrinsicsX86.td:3323)
    x86_avx512_conflict_d_128,                 // llvm.x86.avx512.conflict.d.128 (IntrinsicsX86.td:4293)
    x86_avx512_conflict_d_256,                 // llvm.x86.avx512.conflict.d.256 (IntrinsicsX86.td:4296)
    x86_avx512_conflict_d_512,                 // llvm.x86.avx512.conflict.d.512 (IntrinsicsX86.td:4299)
    x86_avx512_conflict_q_128,                 // llvm.x86.avx512.conflict.q.128 (IntrinsicsX86.td:4304)
    x86_avx512_conflict_q_256,                 // llvm.x86.avx512.conflict.q.256 (IntrinsicsX86.td:4307)
    x86_avx512_conflict_q_512,                 // llvm.x86.avx512.conflict.q.512 (IntrinsicsX86.td:4310)
    x86_avx512_cvtsi2sd64,                     // llvm.x86.avx512.cvtsi2sd64 (IntrinsicsX86.td:2885)
    x86_avx512_cvtsi2ss32,                     // llvm.x86.avx512.cvtsi2ss32 (IntrinsicsX86.td:2877)
    x86_avx512_cvtsi2ss64,                     // llvm.x86.avx512.cvtsi2ss64 (IntrinsicsX86.td:2881)
    x86_avx512_cvttsd2si,                      // llvm.x86.avx512.cvttsd2si (IntrinsicsX86.td:2837)
    x86_avx512_cvttsd2si64,                    // llvm.x86.avx512.cvttsd2si64 (IntrinsicsX86.td:2840)
    x86_avx512_cvttsd2usi,                     // llvm.x86.avx512.cvttsd2usi (IntrinsicsX86.td:2843)
    x86_avx512_cvttsd2usi64,                   // llvm.x86.avx512.cvttsd2usi64 (IntrinsicsX86.td:2846)
    x86_avx512_cvttss2si,                      // llvm.x86.avx512.cvttss2si (IntrinsicsX86.td:2817)
    x86_avx512_cvttss2si64,                    // llvm.x86.avx512.cvttss2si64 (IntrinsicsX86.td:2820)
    x86_avx512_cvttss2usi,                     // llvm.x86.avx512.cvttss2usi (IntrinsicsX86.td:2823)
    x86_avx512_cvttss2usi64,                   // llvm.x86.avx512.cvttss2usi64 (IntrinsicsX86.td:2826)
    x86_avx512_cvtusi2ss,                      // llvm.x86.avx512.cvtusi2ss (IntrinsicsX86.td:2829)
    x86_avx512_cvtusi642sd,                    // llvm.x86.avx512.cvtusi642sd (IntrinsicsX86.td:2849)
    x86_avx512_cvtusi642ss,                    // llvm.x86.avx512.cvtusi642ss (IntrinsicsX86.td:2833)
    x86_avx512_dbpsadbw_128,                   // llvm.x86.avx512.dbpsadbw.128 (IntrinsicsX86.td:3794)
    x86_avx512_dbpsadbw_256,                   // llvm.x86.avx512.dbpsadbw.256 (IntrinsicsX86.td:3800)
    x86_avx512_dbpsadbw_512,                   // llvm.x86.avx512.dbpsadbw.512 (IntrinsicsX86.td:3806)
    x86_avx512_div_pd_512,                     // llvm.x86.avx512.div.pd.512 (IntrinsicsX86.td:3367)
    x86_avx512_div_ps_512,                     // llvm.x86.avx512.div.ps.512 (IntrinsicsX86.td:3364)
    x86_avx512_fpclass_pd_128,                 // llvm.x86.avx512.fpclass.pd.128 (IntrinsicsX86.td:1235)
    x86_avx512_fpclass_pd_256,                 // llvm.x86.avx512.fpclass.pd.256 (IntrinsicsX86.td:1238)
    x86_avx512_fpclass_pd_512,                 // llvm.x86.avx512.fpclass.pd.512 (IntrinsicsX86.td:1241)
    x86_avx512_fpclass_ps_128,                 // llvm.x86.avx512.fpclass.ps.128 (IntrinsicsX86.td:1244)
    x86_avx512_fpclass_ps_256,                 // llvm.x86.avx512.fpclass.ps.256 (IntrinsicsX86.td:1247)
    x86_avx512_fpclass_ps_512,                 // llvm.x86.avx512.fpclass.ps.512 (IntrinsicsX86.td:1250)
    x86_avx512_gather_dpd_512,                 // llvm.x86.avx512.gather.dpd.512 (IntrinsicsX86.td:3818)
    x86_avx512_gather_dpi_512,                 // llvm.x86.avx512.gather.dpi.512 (IntrinsicsX86.td:3840)
    x86_avx512_gather_dpq_512,                 // llvm.x86.avx512.gather.dpq.512 (IntrinsicsX86.td:3836)
    x86_avx512_gather_dps_512,                 // llvm.x86.avx512.gather.dps.512 (IntrinsicsX86.td:3822)
    x86_avx512_gather_qpd_512,                 // llvm.x86.avx512.gather.qpd.512 (IntrinsicsX86.td:3826)
    x86_avx512_gather_qpi_512,                 // llvm.x86.avx512.gather.qpi.512 (IntrinsicsX86.td:3848)
    x86_avx512_gather_qpq_512,                 // llvm.x86.avx512.gather.qpq.512 (IntrinsicsX86.td:3844)
    x86_avx512_gather_qps_512,                 // llvm.x86.avx512.gather.qps.512 (IntrinsicsX86.td:3830)
    x86_avx512_gather3div2_df,                 // llvm.x86.avx512.gather3div2.df (IntrinsicsX86.td:3853)
    x86_avx512_gather3div2_di,                 // llvm.x86.avx512.gather3div2.di (IntrinsicsX86.td:3858)
    x86_avx512_gather3div4_df,                 // llvm.x86.avx512.gather3div4.df (IntrinsicsX86.td:3863)
    x86_avx512_gather3div4_di,                 // llvm.x86.avx512.gather3div4.di (IntrinsicsX86.td:3868)
    x86_avx512_gather3div4_sf,                 // llvm.x86.avx512.gather3div4.sf (IntrinsicsX86.td:3873)
    x86_avx512_gather3div4_si,                 // llvm.x86.avx512.gather3div4.si (IntrinsicsX86.td:3878)
    x86_avx512_gather3div8_sf,                 // llvm.x86.avx512.gather3div8.sf (IntrinsicsX86.td:3883)
    x86_avx512_gather3div8_si,                 // llvm.x86.avx512.gather3div8.si (IntrinsicsX86.td:3888)
    x86_avx512_gather3siv2_df,                 // llvm.x86.avx512.gather3siv2.df (IntrinsicsX86.td:3893)
    x86_avx512_gather3siv2_di,                 // llvm.x86.avx512.gather3siv2.di (IntrinsicsX86.td:3898)
    x86_avx512_gather3siv4_df,                 // llvm.x86.avx512.gather3siv4.df (IntrinsicsX86.td:3903)
    x86_avx512_gather3siv4_di,                 // llvm.x86.avx512.gather3siv4.di (IntrinsicsX86.td:3908)
    x86_avx512_gather3siv4_sf,                 // llvm.x86.avx512.gather3siv4.sf (IntrinsicsX86.td:3913)
    x86_avx512_gather3siv4_si,                 // llvm.x86.avx512.gather3siv4.si (IntrinsicsX86.td:3918)
    x86_avx512_gather3siv8_sf,                 // llvm.x86.avx512.gather3siv8.sf (IntrinsicsX86.td:3923)
    x86_avx512_gather3siv8_si,                 // llvm.x86.avx512.gather3siv8.si (IntrinsicsX86.td:3928)
    x86_avx512_kadd_b,                         // llvm.x86.avx512.kadd.b (IntrinsicsX86.td:2775)
    x86_avx512_kadd_d,                         // llvm.x86.avx512.kadd.d (IntrinsicsX86.td:2781)
    x86_avx512_kadd_q,                         // llvm.x86.avx512.kadd.q (IntrinsicsX86.td:2784)
    x86_avx512_kadd_w,                         // llvm.x86.avx512.kadd.w (IntrinsicsX86.td:2778)
    x86_avx512_ktestc_b,                       // llvm.x86.avx512.ktestc.b (IntrinsicsX86.td:2788)
    x86_avx512_ktestc_d,                       // llvm.x86.avx512.ktestc.d (IntrinsicsX86.td:2794)
    x86_avx512_ktestc_q,                       // llvm.x86.avx512.ktestc.q (IntrinsicsX86.td:2797)
    x86_avx512_ktestc_w,                       // llvm.x86.avx512.ktestc.w (IntrinsicsX86.td:2791)
    x86_avx512_ktestz_b,                       // llvm.x86.avx512.ktestz.b (IntrinsicsX86.td:2801)
    x86_avx512_ktestz_d,                       // llvm.x86.avx512.ktestz.d (IntrinsicsX86.td:2807)
    x86_avx512_ktestz_q,                       // llvm.x86.avx512.ktestz.q (IntrinsicsX86.td:2810)
    x86_avx512_ktestz_w,                       // llvm.x86.avx512.ktestz.w (IntrinsicsX86.td:2804)
    x86_avx512_mask_add_sd_round,              // llvm.x86.avx512.mask.add.sd.round (IntrinsicsX86.td:3414)
    x86_avx512_mask_add_ss_round,              // llvm.x86.avx512.mask.add.ss.round (IntrinsicsX86.td:3384)
    x86_avx512_mask_cmp_pd_128,                // llvm.x86.avx512.mask.cmp.pd.128 (IntrinsicsX86.td:4963)
    x86_avx512_mask_cmp_pd_256,                // llvm.x86.avx512.mask.cmp.pd.256 (IntrinsicsX86.td:4955)
    x86_avx512_mask_cmp_pd_512,                // llvm.x86.avx512.mask.cmp.pd.512 (IntrinsicsX86.td:4946)
    x86_avx512_mask_cmp_ps_128,                // llvm.x86.avx512.mask.cmp.ps.128 (IntrinsicsX86.td:4959)
    x86_avx512_mask_cmp_ps_256,                // llvm.x86.avx512.mask.cmp.ps.256 (IntrinsicsX86.td:4951)
    x86_avx512_mask_cmp_ps_512,                // llvm.x86.avx512.mask.cmp.ps.512 (IntrinsicsX86.td:4941)
    x86_avx512_mask_cmp_sd,                    // llvm.x86.avx512.mask.cmp.sd (IntrinsicsX86.td:4974)
    x86_avx512_mask_cmp_ss,                    // llvm.x86.avx512.mask.cmp.ss (IntrinsicsX86.td:4968)
    x86_avx512_mask_compress,                  // llvm.x86.avx512.mask.compress (IntrinsicsX86.td:4332)
    x86_avx512_mask_cvtpd2dq_128,              // llvm.x86.avx512.mask.cvtpd2dq.128 (IntrinsicsX86.td:2917)
    x86_avx512_mask_cvtpd2dq_512,              // llvm.x86.avx512.mask.cvtpd2dq.512 (IntrinsicsX86.td:2923)
    x86_avx512_mask_cvtpd2ps,                  // llvm.x86.avx512.mask.cvtpd2ps (IntrinsicsX86.td:2947)
    x86_avx512_mask_cvtpd2ps_512,              // llvm.x86.avx512.mask.cvtpd2ps.512 (IntrinsicsX86.td:2929)
    x86_avx512_mask_cvtpd2qq_128,              // llvm.x86.avx512.mask.cvtpd2qq.128 (IntrinsicsX86.td:2953)
    x86_avx512_mask_cvtpd2qq_256,              // llvm.x86.avx512.mask.cvtpd2qq.256 (IntrinsicsX86.td:2959)
    x86_avx512_mask_cvtpd2qq_512,              // llvm.x86.avx512.mask.cvtpd2qq.512 (IntrinsicsX86.td:2965)
    x86_avx512_mask_cvtpd2udq_128,             // llvm.x86.avx512.mask.cvtpd2udq.128 (IntrinsicsX86.td:2971)
    x86_avx512_mask_cvtpd2udq_256,             // llvm.x86.avx512.mask.cvtpd2udq.256 (IntrinsicsX86.td:2977)
    x86_avx512_mask_cvtpd2udq_512,             // llvm.x86.avx512.mask.cvtpd2udq.512 (IntrinsicsX86.td:2983)
    x86_avx512_mask_cvtpd2uqq_128,             // llvm.x86.avx512.mask.cvtpd2uqq.128 (IntrinsicsX86.td:2989)
    x86_avx512_mask_cvtpd2uqq_256,             // llvm.x86.avx512.mask.cvtpd2uqq.256 (IntrinsicsX86.td:2995)
    x86_avx512_mask_cvtpd2uqq_512,             // llvm.x86.avx512.mask.cvtpd2uqq.512 (IntrinsicsX86.td:3001)
    x86_avx512_mask_cvtps2dq_128,              // llvm.x86.avx512.mask.cvtps2dq.128 (IntrinsicsX86.td:3007)
    x86_avx512_mask_cvtps2dq_256,              // llvm.x86.avx512.mask.cvtps2dq.256 (IntrinsicsX86.td:3013)
    x86_avx512_mask_cvtps2dq_512,              // llvm.x86.avx512.mask.cvtps2dq.512 (IntrinsicsX86.td:3019)
    x86_avx512_mask_cvtps2pd_512,              // llvm.x86.avx512.mask.cvtps2pd.512 (IntrinsicsX86.td:3025)
    x86_avx512_mask_cvtps2qq_128,              // llvm.x86.avx512.mask.cvtps2qq.128 (IntrinsicsX86.td:3031)
    x86_avx512_mask_cvtps2qq_256,              // llvm.x86.avx512.mask.cvtps2qq.256 (IntrinsicsX86.td:3037)
    x86_avx512_mask_cvtps2qq_512,              // llvm.x86.avx512.mask.cvtps2qq.512 (IntrinsicsX86.td:3043)
    x86_avx512_mask_cvtps2udq_128,             // llvm.x86.avx512.mask.cvtps2udq.128 (IntrinsicsX86.td:3049)
    x86_avx512_mask_cvtps2udq_256,             // llvm.x86.avx512.mask.cvtps2udq.256 (IntrinsicsX86.td:3055)
    x86_avx512_mask_cvtps2udq_512,             // llvm.x86.avx512.mask.cvtps2udq.512 (IntrinsicsX86.td:3061)
    x86_avx512_mask_cvtps2uqq_128,             // llvm.x86.avx512.mask.cvtps2uqq.128 (IntrinsicsX86.td:3067)
    x86_avx512_mask_cvtps2uqq_256,             // llvm.x86.avx512.mask.cvtps2uqq.256 (IntrinsicsX86.td:3073)
    x86_avx512_mask_cvtps2uqq_512,             // llvm.x86.avx512.mask.cvtps2uqq.512 (IntrinsicsX86.td:3079)
    x86_avx512_mask_cvtqq2ps_128,              // llvm.x86.avx512.mask.cvtqq2ps.128 (IntrinsicsX86.td:3085)
    x86_avx512_mask_cvtsd2ss_round,            // llvm.x86.avx512.mask.cvtsd2ss.round (IntrinsicsX86.td:2935)
    x86_avx512_mask_cvtss2sd_round,            // llvm.x86.avx512.mask.cvtss2sd.round (IntrinsicsX86.td:2941)
    x86_avx512_mask_cvttpd2dq_128,             // llvm.x86.avx512.mask.cvttpd2dq.128 (IntrinsicsX86.td:3091)
    x86_avx512_mask_cvttpd2dq_512,             // llvm.x86.avx512.mask.cvttpd2dq.512 (IntrinsicsX86.td:3097)
    x86_avx512_mask_cvttpd2qq_128,             // llvm.x86.avx512.mask.cvttpd2qq.128 (IntrinsicsX86.td:3103)
    x86_avx512_mask_cvttpd2qq_256,             // llvm.x86.avx512.mask.cvttpd2qq.256 (IntrinsicsX86.td:3109)
    x86_avx512_mask_cvttpd2qq_512,             // llvm.x86.avx512.mask.cvttpd2qq.512 (IntrinsicsX86.td:3115)
    x86_avx512_mask_cvttpd2udq_128,            // llvm.x86.avx512.mask.cvttpd2udq.128 (IntrinsicsX86.td:3121)
    x86_avx512_mask_cvttpd2udq_256,            // llvm.x86.avx512.mask.cvttpd2udq.256 (IntrinsicsX86.td:3127)
    x86_avx512_mask_cvttpd2udq_512,            // llvm.x86.avx512.mask.cvttpd2udq.512 (IntrinsicsX86.td:3133)
    x86_avx512_mask_cvttpd2uqq_128,            // llvm.x86.avx512.mask.cvttpd2uqq.128 (IntrinsicsX86.td:3139)
    x86_avx512_mask_cvttpd2uqq_256,            // llvm.x86.avx512.mask.cvttpd2uqq.256 (IntrinsicsX86.td:3145)
    x86_avx512_mask_cvttpd2uqq_512,            // llvm.x86.avx512.mask.cvttpd2uqq.512 (IntrinsicsX86.td:3151)
    x86_avx512_mask_cvttps2dq_512,             // llvm.x86.avx512.mask.cvttps2dq.512 (IntrinsicsX86.td:3157)
    x86_avx512_mask_cvttps2qq_128,             // llvm.x86.avx512.mask.cvttps2qq.128 (IntrinsicsX86.td:3163)
    x86_avx512_mask_cvttps2qq_256,             // llvm.x86.avx512.mask.cvttps2qq.256 (IntrinsicsX86.td:3169)
    x86_avx512_mask_cvttps2qq_512,             // llvm.x86.avx512.mask.cvttps2qq.512 (IntrinsicsX86.td:3175)
    x86_avx512_mask_cvttps2udq_128,            // llvm.x86.avx512.mask.cvttps2udq.128 (IntrinsicsX86.td:3181)
    x86_avx512_mask_cvttps2udq_256,            // llvm.x86.avx512.mask.cvttps2udq.256 (IntrinsicsX86.td:3187)
    x86_avx512_mask_cvttps2udq_512,            // llvm.x86.avx512.mask.cvttps2udq.512 (IntrinsicsX86.td:3193)
    x86_avx512_mask_cvttps2uqq_128,            // llvm.x86.avx512.mask.cvttps2uqq.128 (IntrinsicsX86.td:3199)
    x86_avx512_mask_cvttps2uqq_256,            // llvm.x86.avx512.mask.cvttps2uqq.256 (IntrinsicsX86.td:3205)
    x86_avx512_mask_cvttps2uqq_512,            // llvm.x86.avx512.mask.cvttps2uqq.512 (IntrinsicsX86.td:3211)
    x86_avx512_mask_cvtuqq2ps_128,             // llvm.x86.avx512.mask.cvtuqq2ps.128 (IntrinsicsX86.td:3217)
    x86_avx512_mask_div_sd_round,              // llvm.x86.avx512.mask.div.sd.round (IntrinsicsX86.td:3419)
    x86_avx512_mask_div_ss_round,              // llvm.x86.avx512.mask.div.ss.round (IntrinsicsX86.td:3389)
    x86_avx512_mask_expand,                    // llvm.x86.avx512.mask.expand (IntrinsicsX86.td:4337)
    x86_avx512_mask_fixupimm_pd_128,           // llvm.x86.avx512.mask.fixupimm.pd.128 (IntrinsicsX86.td:3533)
    x86_avx512_mask_fixupimm_pd_256,           // llvm.x86.avx512.mask.fixupimm.pd.256 (IntrinsicsX86.td:3543)
    x86_avx512_mask_fixupimm_pd_512,           // llvm.x86.avx512.mask.fixupimm.pd.512 (IntrinsicsX86.td:3553)
    x86_avx512_mask_fixupimm_ps_128,           // llvm.x86.avx512.mask.fixupimm.ps.128 (IntrinsicsX86.td:3563)
    x86_avx512_mask_fixupimm_ps_256,           // llvm.x86.avx512.mask.fixupimm.ps.256 (IntrinsicsX86.td:3573)
    x86_avx512_mask_fixupimm_ps_512,           // llvm.x86.avx512.mask.fixupimm.ps.512 (IntrinsicsX86.td:3583)
    x86_avx512_mask_fixupimm_sd,               // llvm.x86.avx512.mask.fixupimm.sd (IntrinsicsX86.td:3593)
    x86_avx512_mask_fixupimm_ss,               // llvm.x86.avx512.mask.fixupimm.ss (IntrinsicsX86.td:3603)
    x86_avx512_mask_fpclass_sd,                // llvm.x86.avx512.mask.fpclass.sd (IntrinsicsX86.td:1253)
    x86_avx512_mask_fpclass_ss,                // llvm.x86.avx512.mask.fpclass.ss (IntrinsicsX86.td:1258)
    x86_avx512_mask_gather_dpd_512,            // llvm.x86.avx512.mask.gather.dpd.512 (IntrinsicsX86.td:4057)
    x86_avx512_mask_gather_dpi_512,            // llvm.x86.avx512.mask.gather.dpi.512 (IntrinsicsX86.td:4079)
    x86_avx512_mask_gather_dpq_512,            // llvm.x86.avx512.mask.gather.dpq.512 (IntrinsicsX86.td:4075)
    x86_avx512_mask_gather_dps_512,            // llvm.x86.avx512.mask.gather.dps.512 (IntrinsicsX86.td:4061)
    x86_avx512_mask_gather_qpd_512,            // llvm.x86.avx512.mask.gather.qpd.512 (IntrinsicsX86.td:4065)
    x86_avx512_mask_gather_qpi_512,            // llvm.x86.avx512.mask.gather.qpi.512 (IntrinsicsX86.td:4087)
    x86_avx512_mask_gather_qpq_512,            // llvm.x86.avx512.mask.gather.qpq.512 (IntrinsicsX86.td:4083)
    x86_avx512_mask_gather_qps_512,            // llvm.x86.avx512.mask.gather.qps.512 (IntrinsicsX86.td:4069)
    x86_avx512_mask_gather3div2_df,            // llvm.x86.avx512.mask.gather3div2.df (IntrinsicsX86.td:4092)
    x86_avx512_mask_gather3div2_di,            // llvm.x86.avx512.mask.gather3div2.di (IntrinsicsX86.td:4097)
    x86_avx512_mask_gather3div4_df,            // llvm.x86.avx512.mask.gather3div4.df (IntrinsicsX86.td:4102)
    x86_avx512_mask_gather3div4_di,            // llvm.x86.avx512.mask.gather3div4.di (IntrinsicsX86.td:4107)
    x86_avx512_mask_gather3div4_sf,            // llvm.x86.avx512.mask.gather3div4.sf (IntrinsicsX86.td:4112)
    x86_avx512_mask_gather3div4_si,            // llvm.x86.avx512.mask.gather3div4.si (IntrinsicsX86.td:4117)
    x86_avx512_mask_gather3div8_sf,            // llvm.x86.avx512.mask.gather3div8.sf (IntrinsicsX86.td:4122)
    x86_avx512_mask_gather3div8_si,            // llvm.x86.avx512.mask.gather3div8.si (IntrinsicsX86.td:4127)
    x86_avx512_mask_gather3siv2_df,            // llvm.x86.avx512.mask.gather3siv2.df (IntrinsicsX86.td:4132)
    x86_avx512_mask_gather3siv2_di,            // llvm.x86.avx512.mask.gather3siv2.di (IntrinsicsX86.td:4137)
    x86_avx512_mask_gather3siv4_df,            // llvm.x86.avx512.mask.gather3siv4.df (IntrinsicsX86.td:4142)
    x86_avx512_mask_gather3siv4_di,            // llvm.x86.avx512.mask.gather3siv4.di (IntrinsicsX86.td:4147)
    x86_avx512_mask_gather3siv4_sf,            // llvm.x86.avx512.mask.gather3siv4.sf (IntrinsicsX86.td:4152)
    x86_avx512_mask_gather3siv4_si,            // llvm.x86.avx512.mask.gather3siv4.si (IntrinsicsX86.td:4157)
    x86_avx512_mask_gather3siv8_sf,            // llvm.x86.avx512.mask.gather3siv8.sf (IntrinsicsX86.td:4162)
    x86_avx512_mask_gather3siv8_si,            // llvm.x86.avx512.mask.gather3siv8.si (IntrinsicsX86.td:4167)
    x86_avx512_mask_getexp_pd_128,             // llvm.x86.avx512.mask.getexp.pd.128 (IntrinsicsX86.td:3613)
    x86_avx512_mask_getexp_pd_256,             // llvm.x86.avx512.mask.getexp.pd.256 (IntrinsicsX86.td:3617)
    x86_avx512_mask_getexp_pd_512,             // llvm.x86.avx512.mask.getexp.pd.512 (IntrinsicsX86.td:3621)
    x86_avx512_mask_getexp_ps_128,             // llvm.x86.avx512.mask.getexp.ps.128 (IntrinsicsX86.td:3626)
    x86_avx512_mask_getexp_ps_256,             // llvm.x86.avx512.mask.getexp.ps.256 (IntrinsicsX86.td:3630)
    x86_avx512_mask_getexp_ps_512,             // llvm.x86.avx512.mask.getexp.ps.512 (IntrinsicsX86.td:3634)
    x86_avx512_mask_getexp_sd,                 // llvm.x86.avx512.mask.getexp.sd (IntrinsicsX86.td:3645)
    x86_avx512_mask_getexp_ss,                 // llvm.x86.avx512.mask.getexp.ss (IntrinsicsX86.td:3640)
    x86_avx512_mask_getmant_pd_128,            // llvm.x86.avx512.mask.getmant.pd.128 (IntrinsicsX86.td:3651)
    x86_avx512_mask_getmant_pd_256,            // llvm.x86.avx512.mask.getmant.pd.256 (IntrinsicsX86.td:3657)
    x86_avx512_mask_getmant_pd_512,            // llvm.x86.avx512.mask.getmant.pd.512 (IntrinsicsX86.td:3663)
    x86_avx512_mask_getmant_ps_128,            // llvm.x86.avx512.mask.getmant.ps.128 (IntrinsicsX86.td:3669)
    x86_avx512_mask_getmant_ps_256,            // llvm.x86.avx512.mask.getmant.ps.256 (IntrinsicsX86.td:3675)
    x86_avx512_mask_getmant_ps_512,            // llvm.x86.avx512.mask.getmant.ps.512 (IntrinsicsX86.td:3681)
    x86_avx512_mask_getmant_sd,                // llvm.x86.avx512.mask.getmant.sd (IntrinsicsX86.td:3693)
    x86_avx512_mask_getmant_ss,                // llvm.x86.avx512.mask.getmant.ss (IntrinsicsX86.td:3687)
    x86_avx512_mask_max_sd_round,              // llvm.x86.avx512.mask.max.sd.round (IntrinsicsX86.td:3434)
    x86_avx512_mask_max_ss_round,              // llvm.x86.avx512.mask.max.ss.round (IntrinsicsX86.td:3404)
    x86_avx512_mask_min_sd_round,              // llvm.x86.avx512.mask.min.sd.round (IntrinsicsX86.td:3439)
    x86_avx512_mask_min_ss_round,              // llvm.x86.avx512.mask.min.ss.round (IntrinsicsX86.td:3409)
    x86_avx512_mask_mul_sd_round,              // llvm.x86.avx512.mask.mul.sd.round (IntrinsicsX86.td:3424)
    x86_avx512_mask_mul_ss_round,              // llvm.x86.avx512.mask.mul.ss.round (IntrinsicsX86.td:3394)
    x86_avx512_mask_pmov_db_128,               // llvm.x86.avx512.mask.pmov.db.128 (IntrinsicsX86.td:4605)
    x86_avx512_mask_pmov_db_256,               // llvm.x86.avx512.mask.pmov.db.256 (IntrinsicsX86.td:4635)
    x86_avx512_mask_pmov_db_512,               // llvm.x86.avx512.mask.pmov.db.512 (IntrinsicsX86.td:4665)
    x86_avx512_mask_pmov_db_mem_128,           // llvm.x86.avx512.mask.pmov.db.mem.128 (IntrinsicsX86.td:4610)
    x86_avx512_mask_pmov_db_mem_256,           // llvm.x86.avx512.mask.pmov.db.mem.256 (IntrinsicsX86.td:4640)
    x86_avx512_mask_pmov_db_mem_512,           // llvm.x86.avx512.mask.pmov.db.mem.512 (IntrinsicsX86.td:4669)
    x86_avx512_mask_pmov_dw_128,               // llvm.x86.avx512.mask.pmov.dw.128 (IntrinsicsX86.td:4694)
    x86_avx512_mask_pmov_dw_256,               // llvm.x86.avx512.mask.pmov.dw.256 (IntrinsicsX86.td:4724)
    x86_avx512_mask_pmov_dw_512,               // llvm.x86.avx512.mask.pmov.dw.512 (IntrinsicsX86.td:4754)
    x86_avx512_mask_pmov_dw_mem_128,           // llvm.x86.avx512.mask.pmov.dw.mem.128 (IntrinsicsX86.td:4699)
    x86_avx512_mask_pmov_dw_mem_256,           // llvm.x86.avx512.mask.pmov.dw.mem.256 (IntrinsicsX86.td:4729)
    x86_avx512_mask_pmov_dw_mem_512,           // llvm.x86.avx512.mask.pmov.dw.mem.512 (IntrinsicsX86.td:4758)
    x86_avx512_mask_pmov_qb_128,               // llvm.x86.avx512.mask.pmov.qb.128 (IntrinsicsX86.td:4346)
    x86_avx512_mask_pmov_qb_256,               // llvm.x86.avx512.mask.pmov.qb.256 (IntrinsicsX86.td:4376)
    x86_avx512_mask_pmov_qb_512,               // llvm.x86.avx512.mask.pmov.qb.512 (IntrinsicsX86.td:4406)
    x86_avx512_mask_pmov_qb_mem_128,           // llvm.x86.avx512.mask.pmov.qb.mem.128 (IntrinsicsX86.td:4351)
    x86_avx512_mask_pmov_qb_mem_256,           // llvm.x86.avx512.mask.pmov.qb.mem.256 (IntrinsicsX86.td:4381)
    x86_avx512_mask_pmov_qb_mem_512,           // llvm.x86.avx512.mask.pmov.qb.mem.512 (IntrinsicsX86.td:4411)
    x86_avx512_mask_pmov_qd_128,               // llvm.x86.avx512.mask.pmov.qd.128 (IntrinsicsX86.td:4525)
    x86_avx512_mask_pmov_qd_mem_128,           // llvm.x86.avx512.mask.pmov.qd.mem.128 (IntrinsicsX86.td:4530)
    x86_avx512_mask_pmov_qd_mem_256,           // llvm.x86.avx512.mask.pmov.qd.mem.256 (IntrinsicsX86.td:4555)
    x86_avx512_mask_pmov_qd_mem_512,           // llvm.x86.avx512.mask.pmov.qd.mem.512 (IntrinsicsX86.td:4580)
    x86_avx512_mask_pmov_qw_128,               // llvm.x86.avx512.mask.pmov.qw.128 (IntrinsicsX86.td:4436)
    x86_avx512_mask_pmov_qw_256,               // llvm.x86.avx512.mask.pmov.qw.256 (IntrinsicsX86.td:4466)
    x86_avx512_mask_pmov_qw_512,               // llvm.x86.avx512.mask.pmov.qw.512 (IntrinsicsX86.td:4496)
    x86_avx512_mask_pmov_qw_mem_128,           // llvm.x86.avx512.mask.pmov.qw.mem.128 (IntrinsicsX86.td:4441)
    x86_avx512_mask_pmov_qw_mem_256,           // llvm.x86.avx512.mask.pmov.qw.mem.256 (IntrinsicsX86.td:4471)
    x86_avx512_mask_pmov_qw_mem_512,           // llvm.x86.avx512.mask.pmov.qw.mem.512 (IntrinsicsX86.td:4500)
    x86_avx512_mask_pmov_wb_128,               // llvm.x86.avx512.mask.pmov.wb.128 (IntrinsicsX86.td:4783)
    x86_avx512_mask_pmov_wb_mem_128,           // llvm.x86.avx512.mask.pmov.wb.mem.128 (IntrinsicsX86.td:4788)
    x86_avx512_mask_pmov_wb_mem_256,           // llvm.x86.avx512.mask.pmov.wb.mem.256 (IntrinsicsX86.td:4813)
    x86_avx512_mask_pmov_wb_mem_512,           // llvm.x86.avx512.mask.pmov.wb.mem.512 (IntrinsicsX86.td:4838)
    x86_avx512_mask_pmovs_db_128,              // llvm.x86.avx512.mask.pmovs.db.128 (IntrinsicsX86.td:4615)
    x86_avx512_mask_pmovs_db_256,              // llvm.x86.avx512.mask.pmovs.db.256 (IntrinsicsX86.td:4645)
    x86_avx512_mask_pmovs_db_512,              // llvm.x86.avx512.mask.pmovs.db.512 (IntrinsicsX86.td:4674)
    x86_avx512_mask_pmovs_db_mem_128,          // llvm.x86.avx512.mask.pmovs.db.mem.128 (IntrinsicsX86.td:4620)
    x86_avx512_mask_pmovs_db_mem_256,          // llvm.x86.avx512.mask.pmovs.db.mem.256 (IntrinsicsX86.td:4650)
    x86_avx512_mask_pmovs_db_mem_512,          // llvm.x86.avx512.mask.pmovs.db.mem.512 (IntrinsicsX86.td:4679)
    x86_avx512_mask_pmovs_dw_128,              // llvm.x86.avx512.mask.pmovs.dw.128 (IntrinsicsX86.td:4704)
    x86_avx512_mask_pmovs_dw_256,              // llvm.x86.avx512.mask.pmovs.dw.256 (IntrinsicsX86.td:4734)
    x86_avx512_mask_pmovs_dw_512,              // llvm.x86.avx512.mask.pmovs.dw.512 (IntrinsicsX86.td:4763)
    x86_avx512_mask_pmovs_dw_mem_128,          // llvm.x86.avx512.mask.pmovs.dw.mem.128 (IntrinsicsX86.td:4709)
    x86_avx512_mask_pmovs_dw_mem_256,          // llvm.x86.avx512.mask.pmovs.dw.mem.256 (IntrinsicsX86.td:4739)
    x86_avx512_mask_pmovs_dw_mem_512,          // llvm.x86.avx512.mask.pmovs.dw.mem.512 (IntrinsicsX86.td:4768)
    x86_avx512_mask_pmovs_qb_128,              // llvm.x86.avx512.mask.pmovs.qb.128 (IntrinsicsX86.td:4356)
    x86_avx512_mask_pmovs_qb_256,              // llvm.x86.avx512.mask.pmovs.qb.256 (IntrinsicsX86.td:4386)
    x86_avx512_mask_pmovs_qb_512,              // llvm.x86.avx512.mask.pmovs.qb.512 (IntrinsicsX86.td:4416)
    x86_avx512_mask_pmovs_qb_mem_128,          // llvm.x86.avx512.mask.pmovs.qb.mem.128 (IntrinsicsX86.td:4361)
    x86_avx512_mask_pmovs_qb_mem_256,          // llvm.x86.avx512.mask.pmovs.qb.mem.256 (IntrinsicsX86.td:4391)
    x86_avx512_mask_pmovs_qb_mem_512,          // llvm.x86.avx512.mask.pmovs.qb.mem.512 (IntrinsicsX86.td:4421)
    x86_avx512_mask_pmovs_qd_128,              // llvm.x86.avx512.mask.pmovs.qd.128 (IntrinsicsX86.td:4535)
    x86_avx512_mask_pmovs_qd_256,              // llvm.x86.avx512.mask.pmovs.qd.256 (IntrinsicsX86.td:4560)
    x86_avx512_mask_pmovs_qd_512,              // llvm.x86.avx512.mask.pmovs.qd.512 (IntrinsicsX86.td:4585)
    x86_avx512_mask_pmovs_qd_mem_128,          // llvm.x86.avx512.mask.pmovs.qd.mem.128 (IntrinsicsX86.td:4540)
    x86_avx512_mask_pmovs_qd_mem_256,          // llvm.x86.avx512.mask.pmovs.qd.mem.256 (IntrinsicsX86.td:4565)
    x86_avx512_mask_pmovs_qd_mem_512,          // llvm.x86.avx512.mask.pmovs.qd.mem.512 (IntrinsicsX86.td:4590)
    x86_avx512_mask_pmovs_qw_128,              // llvm.x86.avx512.mask.pmovs.qw.128 (IntrinsicsX86.td:4446)
    x86_avx512_mask_pmovs_qw_256,              // llvm.x86.avx512.mask.pmovs.qw.256 (IntrinsicsX86.td:4476)
    x86_avx512_mask_pmovs_qw_512,              // llvm.x86.avx512.mask.pmovs.qw.512 (IntrinsicsX86.td:4505)
    x86_avx512_mask_pmovs_qw_mem_128,          // llvm.x86.avx512.mask.pmovs.qw.mem.128 (IntrinsicsX86.td:4451)
    x86_avx512_mask_pmovs_qw_mem_256,          // llvm.x86.avx512.mask.pmovs.qw.mem.256 (IntrinsicsX86.td:4481)
    x86_avx512_mask_pmovs_qw_mem_512,          // llvm.x86.avx512.mask.pmovs.qw.mem.512 (IntrinsicsX86.td:4510)
    x86_avx512_mask_pmovs_wb_128,              // llvm.x86.avx512.mask.pmovs.wb.128 (IntrinsicsX86.td:4793)
    x86_avx512_mask_pmovs_wb_256,              // llvm.x86.avx512.mask.pmovs.wb.256 (IntrinsicsX86.td:4818)
    x86_avx512_mask_pmovs_wb_512,              // llvm.x86.avx512.mask.pmovs.wb.512 (IntrinsicsX86.td:4843)
    x86_avx512_mask_pmovs_wb_mem_128,          // llvm.x86.avx512.mask.pmovs.wb.mem.128 (IntrinsicsX86.td:4798)
    x86_avx512_mask_pmovs_wb_mem_256,          // llvm.x86.avx512.mask.pmovs.wb.mem.256 (IntrinsicsX86.td:4823)
    x86_avx512_mask_pmovs_wb_mem_512,          // llvm.x86.avx512.mask.pmovs.wb.mem.512 (IntrinsicsX86.td:4848)
    x86_avx512_mask_pmovus_db_128,             // llvm.x86.avx512.mask.pmovus.db.128 (IntrinsicsX86.td:4625)
    x86_avx512_mask_pmovus_db_256,             // llvm.x86.avx512.mask.pmovus.db.256 (IntrinsicsX86.td:4655)
    x86_avx512_mask_pmovus_db_512,             // llvm.x86.avx512.mask.pmovus.db.512 (IntrinsicsX86.td:4684)
    x86_avx512_mask_pmovus_db_mem_128,         // llvm.x86.avx512.mask.pmovus.db.mem.128 (IntrinsicsX86.td:4630)
    x86_avx512_mask_pmovus_db_mem_256,         // llvm.x86.avx512.mask.pmovus.db.mem.256 (IntrinsicsX86.td:4660)
    x86_avx512_mask_pmovus_db_mem_512,         // llvm.x86.avx512.mask.pmovus.db.mem.512 (IntrinsicsX86.td:4689)
    x86_avx512_mask_pmovus_dw_128,             // llvm.x86.avx512.mask.pmovus.dw.128 (IntrinsicsX86.td:4714)
    x86_avx512_mask_pmovus_dw_256,             // llvm.x86.avx512.mask.pmovus.dw.256 (IntrinsicsX86.td:4744)
    x86_avx512_mask_pmovus_dw_512,             // llvm.x86.avx512.mask.pmovus.dw.512 (IntrinsicsX86.td:4773)
    x86_avx512_mask_pmovus_dw_mem_128,         // llvm.x86.avx512.mask.pmovus.dw.mem.128 (IntrinsicsX86.td:4719)
    x86_avx512_mask_pmovus_dw_mem_256,         // llvm.x86.avx512.mask.pmovus.dw.mem.256 (IntrinsicsX86.td:4749)
    x86_avx512_mask_pmovus_dw_mem_512,         // llvm.x86.avx512.mask.pmovus.dw.mem.512 (IntrinsicsX86.td:4778)
    x86_avx512_mask_pmovus_qb_128,             // llvm.x86.avx512.mask.pmovus.qb.128 (IntrinsicsX86.td:4366)
    x86_avx512_mask_pmovus_qb_256,             // llvm.x86.avx512.mask.pmovus.qb.256 (IntrinsicsX86.td:4396)
    x86_avx512_mask_pmovus_qb_512,             // llvm.x86.avx512.mask.pmovus.qb.512 (IntrinsicsX86.td:4426)
    x86_avx512_mask_pmovus_qb_mem_128,         // llvm.x86.avx512.mask.pmovus.qb.mem.128 (IntrinsicsX86.td:4371)
    x86_avx512_mask_pmovus_qb_mem_256,         // llvm.x86.avx512.mask.pmovus.qb.mem.256 (IntrinsicsX86.td:4401)
    x86_avx512_mask_pmovus_qb_mem_512,         // llvm.x86.avx512.mask.pmovus.qb.mem.512 (IntrinsicsX86.td:4431)
    x86_avx512_mask_pmovus_qd_128,             // llvm.x86.avx512.mask.pmovus.qd.128 (IntrinsicsX86.td:4545)
    x86_avx512_mask_pmovus_qd_256,             // llvm.x86.avx512.mask.pmovus.qd.256 (IntrinsicsX86.td:4570)
    x86_avx512_mask_pmovus_qd_512,             // llvm.x86.avx512.mask.pmovus.qd.512 (IntrinsicsX86.td:4595)
    x86_avx512_mask_pmovus_qd_mem_128,         // llvm.x86.avx512.mask.pmovus.qd.mem.128 (IntrinsicsX86.td:4550)
    x86_avx512_mask_pmovus_qd_mem_256,         // llvm.x86.avx512.mask.pmovus.qd.mem.256 (IntrinsicsX86.td:4575)
    x86_avx512_mask_pmovus_qd_mem_512,         // llvm.x86.avx512.mask.pmovus.qd.mem.512 (IntrinsicsX86.td:4600)
    x86_avx512_mask_pmovus_qw_128,             // llvm.x86.avx512.mask.pmovus.qw.128 (IntrinsicsX86.td:4456)
    x86_avx512_mask_pmovus_qw_256,             // llvm.x86.avx512.mask.pmovus.qw.256 (IntrinsicsX86.td:4486)
    x86_avx512_mask_pmovus_qw_512,             // llvm.x86.avx512.mask.pmovus.qw.512 (IntrinsicsX86.td:4515)
    x86_avx512_mask_pmovus_qw_mem_128,         // llvm.x86.avx512.mask.pmovus.qw.mem.128 (IntrinsicsX86.td:4461)
    x86_avx512_mask_pmovus_qw_mem_256,         // llvm.x86.avx512.mask.pmovus.qw.mem.256 (IntrinsicsX86.td:4491)
    x86_avx512_mask_pmovus_qw_mem_512,         // llvm.x86.avx512.mask.pmovus.qw.mem.512 (IntrinsicsX86.td:4520)
    x86_avx512_mask_pmovus_wb_128,             // llvm.x86.avx512.mask.pmovus.wb.128 (IntrinsicsX86.td:4803)
    x86_avx512_mask_pmovus_wb_256,             // llvm.x86.avx512.mask.pmovus.wb.256 (IntrinsicsX86.td:4828)
    x86_avx512_mask_pmovus_wb_512,             // llvm.x86.avx512.mask.pmovus.wb.512 (IntrinsicsX86.td:4853)
    x86_avx512_mask_pmovus_wb_mem_128,         // llvm.x86.avx512.mask.pmovus.wb.mem.128 (IntrinsicsX86.td:4808)
    x86_avx512_mask_pmovus_wb_mem_256,         // llvm.x86.avx512.mask.pmovus.wb.mem.256 (IntrinsicsX86.td:4833)
    x86_avx512_mask_pmovus_wb_mem_512,         // llvm.x86.avx512.mask.pmovus.wb.mem.512 (IntrinsicsX86.td:4858)
    x86_avx512_mask_range_pd_128,              // llvm.x86.avx512.mask.range.pd.128 (IntrinsicsX86.td:3287)
    x86_avx512_mask_range_pd_256,              // llvm.x86.avx512.mask.range.pd.256 (IntrinsicsX86.td:3292)
    x86_avx512_mask_range_pd_512,              // llvm.x86.avx512.mask.range.pd.512 (IntrinsicsX86.td:3297)
    x86_avx512_mask_range_ps_128,              // llvm.x86.avx512.mask.range.ps.128 (IntrinsicsX86.td:3303)
    x86_avx512_mask_range_ps_256,              // llvm.x86.avx512.mask.range.ps.256 (IntrinsicsX86.td:3308)
    x86_avx512_mask_range_ps_512,              // llvm.x86.avx512.mask.range.ps.512 (IntrinsicsX86.td:3313)
    x86_avx512_mask_range_sd,                  // llvm.x86.avx512.mask.range.sd (IntrinsicsX86.td:3463)
    x86_avx512_mask_range_ss,                  // llvm.x86.avx512.mask.range.ss (IntrinsicsX86.td:3457)
    x86_avx512_mask_reduce_pd_128,             // llvm.x86.avx512.mask.reduce.pd.128 (IntrinsicsX86.td:3255)
    x86_avx512_mask_reduce_pd_256,             // llvm.x86.avx512.mask.reduce.pd.256 (IntrinsicsX86.td:3260)
    x86_avx512_mask_reduce_pd_512,             // llvm.x86.avx512.mask.reduce.pd.512 (IntrinsicsX86.td:3265)
    x86_avx512_mask_reduce_ps_128,             // llvm.x86.avx512.mask.reduce.ps.128 (IntrinsicsX86.td:3271)
    x86_avx512_mask_reduce_ps_256,             // llvm.x86.avx512.mask.reduce.ps.256 (IntrinsicsX86.td:3276)
    x86_avx512_mask_reduce_ps_512,             // llvm.x86.avx512.mask.reduce.ps.512 (IntrinsicsX86.td:3281)
    x86_avx512_mask_reduce_sd,                 // llvm.x86.avx512.mask.reduce.sd (IntrinsicsX86.td:3475)
    x86_avx512_mask_reduce_ss,                 // llvm.x86.avx512.mask.reduce.ss (IntrinsicsX86.td:3469)
    x86_avx512_mask_rndscale_pd_128,           // llvm.x86.avx512.mask.rndscale.pd.128 (IntrinsicsX86.td:3223)
    x86_avx512_mask_rndscale_pd_256,           // llvm.x86.avx512.mask.rndscale.pd.256 (IntrinsicsX86.td:3228)
    x86_avx512_mask_rndscale_pd_512,           // llvm.x86.avx512.mask.rndscale.pd.512 (IntrinsicsX86.td:3233)
    x86_avx512_mask_rndscale_ps_128,           // llvm.x86.avx512.mask.rndscale.ps.128 (IntrinsicsX86.td:3239)
    x86_avx512_mask_rndscale_ps_256,           // llvm.x86.avx512.mask.rndscale.ps.256 (IntrinsicsX86.td:3244)
    x86_avx512_mask_rndscale_ps_512,           // llvm.x86.avx512.mask.rndscale.ps.512 (IntrinsicsX86.td:3249)
    x86_avx512_mask_rndscale_sd,               // llvm.x86.avx512.mask.rndscale.sd (IntrinsicsX86.td:3451)
    x86_avx512_mask_rndscale_ss,               // llvm.x86.avx512.mask.rndscale.ss (IntrinsicsX86.td:3445)
    x86_avx512_mask_scalef_pd_128,             // llvm.x86.avx512.mask.scalef.pd.128 (IntrinsicsX86.td:3491)
    x86_avx512_mask_scalef_pd_256,             // llvm.x86.avx512.mask.scalef.pd.256 (IntrinsicsX86.td:3494)
    x86_avx512_mask_scalef_pd_512,             // llvm.x86.avx512.mask.scalef.pd.512 (IntrinsicsX86.td:3499)
    x86_avx512_mask_scalef_ps_128,             // llvm.x86.avx512.mask.scalef.ps.128 (IntrinsicsX86.td:3504)
    x86_avx512_mask_scalef_ps_256,             // llvm.x86.avx512.mask.scalef.ps.256 (IntrinsicsX86.td:3507)
    x86_avx512_mask_scalef_ps_512,             // llvm.x86.avx512.mask.scalef.ps.512 (IntrinsicsX86.td:3510)
    x86_avx512_mask_scalef_sd,                 // llvm.x86.avx512.mask.scalef.sd (IntrinsicsX86.td:3481)
    x86_avx512_mask_scalef_ss,                 // llvm.x86.avx512.mask.scalef.ss (IntrinsicsX86.td:3486)
    x86_avx512_mask_scatter_dpd_512,           // llvm.x86.avx512.mask.scatter.dpd.512 (IntrinsicsX86.td:4172)
    x86_avx512_mask_scatter_dpi_512,           // llvm.x86.avx512.mask.scatter.dpi.512 (IntrinsicsX86.td:4196)
    x86_avx512_mask_scatter_dpq_512,           // llvm.x86.avx512.mask.scatter.dpq.512 (IntrinsicsX86.td:4192)
    x86_avx512_mask_scatter_dps_512,           // llvm.x86.avx512.mask.scatter.dps.512 (IntrinsicsX86.td:4176)
    x86_avx512_mask_scatter_qpd_512,           // llvm.x86.avx512.mask.scatter.qpd.512 (IntrinsicsX86.td:4180)
    x86_avx512_mask_scatter_qpi_512,           // llvm.x86.avx512.mask.scatter.qpi.512 (IntrinsicsX86.td:4204)
    x86_avx512_mask_scatter_qpq_512,           // llvm.x86.avx512.mask.scatter.qpq.512 (IntrinsicsX86.td:4200)
    x86_avx512_mask_scatter_qps_512,           // llvm.x86.avx512.mask.scatter.qps.512 (IntrinsicsX86.td:4184)
    x86_avx512_mask_scatterdiv2_df,            // llvm.x86.avx512.mask.scatterdiv2.df (IntrinsicsX86.td:4209)
    x86_avx512_mask_scatterdiv2_di,            // llvm.x86.avx512.mask.scatterdiv2.di (IntrinsicsX86.td:4214)
    x86_avx512_mask_scatterdiv4_df,            // llvm.x86.avx512.mask.scatterdiv4.df (IntrinsicsX86.td:4219)
    x86_avx512_mask_scatterdiv4_di,            // llvm.x86.avx512.mask.scatterdiv4.di (IntrinsicsX86.td:4224)
    x86_avx512_mask_scatterdiv4_sf,            // llvm.x86.avx512.mask.scatterdiv4.sf (IntrinsicsX86.td:4229)
    x86_avx512_mask_scatterdiv4_si,            // llvm.x86.avx512.mask.scatterdiv4.si (IntrinsicsX86.td:4234)
    x86_avx512_mask_scatterdiv8_sf,            // llvm.x86.avx512.mask.scatterdiv8.sf (IntrinsicsX86.td:4239)
    x86_avx512_mask_scatterdiv8_si,            // llvm.x86.avx512.mask.scatterdiv8.si (IntrinsicsX86.td:4244)
    x86_avx512_mask_scattersiv2_df,            // llvm.x86.avx512.mask.scattersiv2.df (IntrinsicsX86.td:4249)
    x86_avx512_mask_scattersiv2_di,            // llvm.x86.avx512.mask.scattersiv2.di (IntrinsicsX86.td:4254)
    x86_avx512_mask_scattersiv4_df,            // llvm.x86.avx512.mask.scattersiv4.df (IntrinsicsX86.td:4259)
    x86_avx512_mask_scattersiv4_di,            // llvm.x86.avx512.mask.scattersiv4.di (IntrinsicsX86.td:4264)
    x86_avx512_mask_scattersiv4_sf,            // llvm.x86.avx512.mask.scattersiv4.sf (IntrinsicsX86.td:4269)
    x86_avx512_mask_scattersiv4_si,            // llvm.x86.avx512.mask.scattersiv4.si (IntrinsicsX86.td:4274)
    x86_avx512_mask_scattersiv8_sf,            // llvm.x86.avx512.mask.scattersiv8.sf (IntrinsicsX86.td:4279)
    x86_avx512_mask_scattersiv8_si,            // llvm.x86.avx512.mask.scattersiv8.si (IntrinsicsX86.td:4284)
    x86_avx512_mask_sqrt_sd,                   // llvm.x86.avx512.mask.sqrt.sd (IntrinsicsX86.td:3521)
    x86_avx512_mask_sqrt_ss,                   // llvm.x86.avx512.mask.sqrt.ss (IntrinsicsX86.td:3516)
    x86_avx512_mask_sub_sd_round,              // llvm.x86.avx512.mask.sub.sd.round (IntrinsicsX86.td:3429)
    x86_avx512_mask_sub_ss_round,              // llvm.x86.avx512.mask.sub.ss.round (IntrinsicsX86.td:3399)
    x86_avx512_mask_vcvtph2ps_512,             // llvm.x86.avx512.mask.vcvtph2ps.512 (IntrinsicsX86.td:2688)
    x86_avx512_mask_vcvtps2ph_128,             // llvm.x86.avx512.mask.vcvtps2ph.128 (IntrinsicsX86.td:2700)
    x86_avx512_mask_vcvtps2ph_256,             // llvm.x86.avx512.mask.vcvtps2ph.256 (IntrinsicsX86.td:2696)
    x86_avx512_mask_vcvtps2ph_512,             // llvm.x86.avx512.mask.vcvtps2ph.512 (IntrinsicsX86.td:2692)
    x86_avx512_maskz_fixupimm_pd_128,          // llvm.x86.avx512.maskz.fixupimm.pd.128 (IntrinsicsX86.td:3538)
    x86_avx512_maskz_fixupimm_pd_256,          // llvm.x86.avx512.maskz.fixupimm.pd.256 (IntrinsicsX86.td:3548)
    x86_avx512_maskz_fixupimm_pd_512,          // llvm.x86.avx512.maskz.fixupimm.pd.512 (IntrinsicsX86.td:3558)
    x86_avx512_maskz_fixupimm_ps_128,          // llvm.x86.avx512.maskz.fixupimm.ps.128 (IntrinsicsX86.td:3568)
    x86_avx512_maskz_fixupimm_ps_256,          // llvm.x86.avx512.maskz.fixupimm.ps.256 (IntrinsicsX86.td:3578)
    x86_avx512_maskz_fixupimm_ps_512,          // llvm.x86.avx512.maskz.fixupimm.ps.512 (IntrinsicsX86.td:3588)
    x86_avx512_maskz_fixupimm_sd,              // llvm.x86.avx512.maskz.fixupimm.sd (IntrinsicsX86.td:3598)
    x86_avx512_maskz_fixupimm_ss,              // llvm.x86.avx512.maskz.fixupimm.ss (IntrinsicsX86.td:3608)
    x86_avx512_max_pd_512,                     // llvm.x86.avx512.max.pd.512 (IntrinsicsX86.td:3374)
    x86_avx512_max_ps_512,                     // llvm.x86.avx512.max.ps.512 (IntrinsicsX86.td:3371)
    x86_avx512_min_pd_512,                     // llvm.x86.avx512.min.pd.512 (IntrinsicsX86.td:3380)
    x86_avx512_min_ps_512,                     // llvm.x86.avx512.min.ps.512 (IntrinsicsX86.td:3377)
    x86_avx512_mul_pd_512,                     // llvm.x86.avx512.mul.pd.512 (IntrinsicsX86.td:3361)
    x86_avx512_mul_ps_512,                     // llvm.x86.avx512.mul.ps.512 (IntrinsicsX86.td:3358)
    x86_avx512_packssdw_512,                   // llvm.x86.avx512.packssdw.512 (IntrinsicsX86.td:2896)
    x86_avx512_packsswb_512,                   // llvm.x86.avx512.packsswb.512 (IntrinsicsX86.td:2893)
    x86_avx512_packusdw_512,                   // llvm.x86.avx512.packusdw.512 (IntrinsicsX86.td:2902)
    x86_avx512_packuswb_512,                   // llvm.x86.avx512.packuswb.512 (IntrinsicsX86.td:2899)
    x86_avx512_pavg_b_512,                     // llvm.x86.avx512.pavg.b.512 (IntrinsicsX86.td:3781)
    x86_avx512_pavg_w_512,                     // llvm.x86.avx512.pavg.w.512 (IntrinsicsX86.td:3784)
    x86_avx512_permvar_df_256,                 // llvm.x86.avx512.permvar.df.256 (IntrinsicsX86.td:2441)
    x86_avx512_permvar_df_512,                 // llvm.x86.avx512.permvar.df.512 (IntrinsicsX86.td:2444)
    x86_avx512_permvar_di_256,                 // llvm.x86.avx512.permvar.di.256 (IntrinsicsX86.td:2447)
    x86_avx512_permvar_di_512,                 // llvm.x86.avx512.permvar.di.512 (IntrinsicsX86.td:2450)
    x86_avx512_permvar_hi_128,                 // llvm.x86.avx512.permvar.hi.128 (IntrinsicsX86.td:2453)
    x86_avx512_permvar_hi_256,                 // llvm.x86.avx512.permvar.hi.256 (IntrinsicsX86.td:2456)
    x86_avx512_permvar_hi_512,                 // llvm.x86.avx512.permvar.hi.512 (IntrinsicsX86.td:2459)
    x86_avx512_permvar_qi_128,                 // llvm.x86.avx512.permvar.qi.128 (IntrinsicsX86.td:2462)
    x86_avx512_permvar_qi_256,                 // llvm.x86.avx512.permvar.qi.256 (IntrinsicsX86.td:2465)
    x86_avx512_permvar_qi_512,                 // llvm.x86.avx512.permvar.qi.512 (IntrinsicsX86.td:2468)
    x86_avx512_permvar_sf_512,                 // llvm.x86.avx512.permvar.sf.512 (IntrinsicsX86.td:2471)
    x86_avx512_permvar_si_512,                 // llvm.x86.avx512.permvar.si.512 (IntrinsicsX86.td:2474)
    x86_avx512_pmaddubs_w_512,                 // llvm.x86.avx512.pmaddubs.w.512 (IntrinsicsX86.td:3790)
    x86_avx512_pmaddw_d_512,                   // llvm.x86.avx512.pmaddw.d.512 (IntrinsicsX86.td:3787)
    x86_avx512_pmul_hr_sw_512,                 // llvm.x86.avx512.pmul.hr.sw.512 (IntrinsicsX86.td:1557)
    x86_avx512_pmulh_w_512,                    // llvm.x86.avx512.pmulh.w.512 (IntrinsicsX86.td:3778)
    x86_avx512_pmulhu_w_512,                   // llvm.x86.avx512.pmulhu.w.512 (IntrinsicsX86.td:3775)
    x86_avx512_pmultishift_qb_128,             // llvm.x86.avx512.pmultishift.qb.128 (IntrinsicsX86.td:1484)
    x86_avx512_pmultishift_qb_256,             // llvm.x86.avx512.pmultishift.qb.256 (IntrinsicsX86.td:1488)
    x86_avx512_pmultishift_qb_512,             // llvm.x86.avx512.pmultishift.qb.512 (IntrinsicsX86.td:1492)
    x86_avx512_psad_bw_512,                    // llvm.x86.avx512.psad.bw.512 (IntrinsicsX86.td:3769)
    x86_avx512_pshuf_b_512,                    // llvm.x86.avx512.pshuf.b.512 (IntrinsicsX86.td:1086)
    x86_avx512_psll_d_512,                     // llvm.x86.avx512.psll.d.512 (IntrinsicsX86.td:1430)
    x86_avx512_psll_q_512,                     // llvm.x86.avx512.psll.q.512 (IntrinsicsX86.td:1433)
    x86_avx512_psll_w_512,                     // llvm.x86.avx512.psll.w.512 (IntrinsicsX86.td:1427)
    x86_avx512_pslli_d_512,                    // llvm.x86.avx512.pslli.d.512 (IntrinsicsX86.td:1459)
    x86_avx512_pslli_q_512,                    // llvm.x86.avx512.pslli.q.512 (IntrinsicsX86.td:1462)
    x86_avx512_pslli_w_512,                    // llvm.x86.avx512.pslli.w.512 (IntrinsicsX86.td:1456)
    x86_avx512_psllv_d_512,                    // llvm.x86.avx512.psllv.d.512 (IntrinsicsX86.td:1629)
    x86_avx512_psllv_q_512,                    // llvm.x86.avx512.psllv.q.512 (IntrinsicsX86.td:1632)
    x86_avx512_psllv_w_128,                    // llvm.x86.avx512.psllv.w.128 (IntrinsicsX86.td:1676)
    x86_avx512_psllv_w_256,                    // llvm.x86.avx512.psllv.w.256 (IntrinsicsX86.td:1679)
    x86_avx512_psllv_w_512,                    // llvm.x86.avx512.psllv.w.512 (IntrinsicsX86.td:1682)
    x86_avx512_psra_d_512,                     // llvm.x86.avx512.psra.d.512 (IntrinsicsX86.td:1448)
    x86_avx512_psra_q_128,                     // llvm.x86.avx512.psra.q.128 (IntrinsicsX86.td:1412)
    x86_avx512_psra_q_256,                     // llvm.x86.avx512.psra.q.256 (IntrinsicsX86.td:1415)
    x86_avx512_psra_q_512,                     // llvm.x86.avx512.psra.q.512 (IntrinsicsX86.td:1451)
    x86_avx512_psra_w_512,                     // llvm.x86.avx512.psra.w.512 (IntrinsicsX86.td:1445)
    x86_avx512_psrai_d_512,                    // llvm.x86.avx512.psrai.d.512 (IntrinsicsX86.td:1477)
    x86_avx512_psrai_q_128,                    // llvm.x86.avx512.psrai.q.128 (IntrinsicsX86.td:1420)
    x86_avx512_psrai_q_256,                    // llvm.x86.avx512.psrai.q.256 (IntrinsicsX86.td:1423)
    x86_avx512_psrai_q_512,                    // llvm.x86.avx512.psrai.q.512 (IntrinsicsX86.td:1480)
    x86_avx512_psrai_w_512,                    // llvm.x86.avx512.psrai.w.512 (IntrinsicsX86.td:1474)
    x86_avx512_psrav_d_512,                    // llvm.x86.avx512.psrav.d.512 (IntrinsicsX86.td:1663)
    x86_avx512_psrav_q_128,                    // llvm.x86.avx512.psrav.q.128 (IntrinsicsX86.td:1666)
    x86_avx512_psrav_q_256,                    // llvm.x86.avx512.psrav.q.256 (IntrinsicsX86.td:1669)
    x86_avx512_psrav_q_512,                    // llvm.x86.avx512.psrav.q.512 (IntrinsicsX86.td:1672)
    x86_avx512_psrav_w_128,                    // llvm.x86.avx512.psrav.w.128 (IntrinsicsX86.td:1696)
    x86_avx512_psrav_w_256,                    // llvm.x86.avx512.psrav.w.256 (IntrinsicsX86.td:1699)
    x86_avx512_psrav_w_512,                    // llvm.x86.avx512.psrav.w.512 (IntrinsicsX86.td:1702)
    x86_avx512_psrl_d_512,                     // llvm.x86.avx512.psrl.d.512 (IntrinsicsX86.td:1439)
    x86_avx512_psrl_q_512,                     // llvm.x86.avx512.psrl.q.512 (IntrinsicsX86.td:1442)
    x86_avx512_psrl_w_512,                     // llvm.x86.avx512.psrl.w.512 (IntrinsicsX86.td:1436)
    x86_avx512_psrli_d_512,                    // llvm.x86.avx512.psrli.d.512 (IntrinsicsX86.td:1468)
    x86_avx512_psrli_q_512,                    // llvm.x86.avx512.psrli.q.512 (IntrinsicsX86.td:1471)
    x86_avx512_psrli_w_512,                    // llvm.x86.avx512.psrli.w.512 (IntrinsicsX86.td:1465)
    x86_avx512_psrlv_d_512,                    // llvm.x86.avx512.psrlv.d.512 (IntrinsicsX86.td:1649)
    x86_avx512_psrlv_q_512,                    // llvm.x86.avx512.psrlv.q.512 (IntrinsicsX86.td:1652)
    x86_avx512_psrlv_w_128,                    // llvm.x86.avx512.psrlv.w.128 (IntrinsicsX86.td:1686)
    x86_avx512_psrlv_w_256,                    // llvm.x86.avx512.psrlv.w.256 (IntrinsicsX86.td:1689)
    x86_avx512_psrlv_w_512,                    // llvm.x86.avx512.psrlv.w.512 (IntrinsicsX86.td:1692)
    x86_avx512_pternlog_d_128,                 // llvm.x86.avx512.pternlog.d.128 (IntrinsicsX86.td:4867)
    x86_avx512_pternlog_d_256,                 // llvm.x86.avx512.pternlog.d.256 (IntrinsicsX86.td:4874)
    x86_avx512_pternlog_d_512,                 // llvm.x86.avx512.pternlog.d.512 (IntrinsicsX86.td:4881)
    x86_avx512_pternlog_q_128,                 // llvm.x86.avx512.pternlog.q.128 (IntrinsicsX86.td:4887)
    x86_avx512_pternlog_q_256,                 // llvm.x86.avx512.pternlog.q.256 (IntrinsicsX86.td:4894)
    x86_avx512_pternlog_q_512,                 // llvm.x86.avx512.pternlog.q.512 (IntrinsicsX86.td:4901)
    x86_avx512_rcp14_pd_128,                   // llvm.x86.avx512.rcp14.pd.128 (IntrinsicsX86.td:3745)
    x86_avx512_rcp14_pd_256,                   // llvm.x86.avx512.rcp14.pd.256 (IntrinsicsX86.td:3749)
    x86_avx512_rcp14_pd_512,                   // llvm.x86.avx512.rcp14.pd.512 (IntrinsicsX86.td:3753)
    x86_avx512_rcp14_ps_128,                   // llvm.x86.avx512.rcp14.ps.128 (IntrinsicsX86.td:3757)
    x86_avx512_rcp14_ps_256,                   // llvm.x86.avx512.rcp14.ps.256 (IntrinsicsX86.td:3761)
    x86_avx512_rcp14_ps_512,                   // llvm.x86.avx512.rcp14.ps.512 (IntrinsicsX86.td:3765)
    x86_avx512_rcp14_sd,                       // llvm.x86.avx512.rcp14.sd (IntrinsicsX86.td:3739)
    x86_avx512_rcp14_ss,                       // llvm.x86.avx512.rcp14.ss (IntrinsicsX86.td:3734)
    x86_avx512_rsqrt14_pd_128,                 // llvm.x86.avx512.rsqrt14.pd.128 (IntrinsicsX86.td:3710)
    x86_avx512_rsqrt14_pd_256,                 // llvm.x86.avx512.rsqrt14.pd.256 (IntrinsicsX86.td:3714)
    x86_avx512_rsqrt14_pd_512,                 // llvm.x86.avx512.rsqrt14.pd.512 (IntrinsicsX86.td:3718)
    x86_avx512_rsqrt14_ps_128,                 // llvm.x86.avx512.rsqrt14.ps.128 (IntrinsicsX86.td:3722)
    x86_avx512_rsqrt14_ps_256,                 // llvm.x86.avx512.rsqrt14.ps.256 (IntrinsicsX86.td:3726)
    x86_avx512_rsqrt14_ps_512,                 // llvm.x86.avx512.rsqrt14.ps.512 (IntrinsicsX86.td:3730)
    x86_avx512_rsqrt14_sd,                     // llvm.x86.avx512.rsqrt14.sd (IntrinsicsX86.td:3704)
    x86_avx512_rsqrt14_ss,                     // llvm.x86.avx512.rsqrt14.ss (IntrinsicsX86.td:3699)
    x86_avx512_scatter_dpd_512,                // llvm.x86.avx512.scatter.dpd.512 (IntrinsicsX86.td:3937)
    x86_avx512_scatter_dpi_512,                // llvm.x86.avx512.scatter.dpi.512 (IntrinsicsX86.td:3959)
    x86_avx512_scatter_dpq_512,                // llvm.x86.avx512.scatter.dpq.512 (IntrinsicsX86.td:3955)
    x86_avx512_scatter_dps_512,                // llvm.x86.avx512.scatter.dps.512 (IntrinsicsX86.td:3941)
    x86_avx512_scatter_qpd_512,                // llvm.x86.avx512.scatter.qpd.512 (IntrinsicsX86.td:3945)
    x86_avx512_scatter_qpi_512,                // llvm.x86.avx512.scatter.qpi.512 (IntrinsicsX86.td:3967)
    x86_avx512_scatter_qpq_512,                // llvm.x86.avx512.scatter.qpq.512 (IntrinsicsX86.td:3963)
    x86_avx512_scatter_qps_512,                // llvm.x86.avx512.scatter.qps.512 (IntrinsicsX86.td:3949)
    x86_avx512_scatterdiv2_df,                 // llvm.x86.avx512.scatterdiv2.df (IntrinsicsX86.td:3972)
    x86_avx512_scatterdiv2_di,                 // llvm.x86.avx512.scatterdiv2.di (IntrinsicsX86.td:3977)
    x86_avx512_scatterdiv4_df,                 // llvm.x86.avx512.scatterdiv4.df (IntrinsicsX86.td:3982)
    x86_avx512_scatterdiv4_di,                 // llvm.x86.avx512.scatterdiv4.di (IntrinsicsX86.td:3987)
    x86_avx512_scatterdiv4_sf,                 // llvm.x86.avx512.scatterdiv4.sf (IntrinsicsX86.td:3992)
    x86_avx512_scatterdiv4_si,                 // llvm.x86.avx512.scatterdiv4.si (IntrinsicsX86.td:3997)
    x86_avx512_scatterdiv8_sf,                 // llvm.x86.avx512.scatterdiv8.sf (IntrinsicsX86.td:4002)
    x86_avx512_scatterdiv8_si,                 // llvm.x86.avx512.scatterdiv8.si (IntrinsicsX86.td:4007)
    x86_avx512_scattersiv2_df,                 // llvm.x86.avx512.scattersiv2.df (IntrinsicsX86.td:4012)
    x86_avx512_scattersiv2_di,                 // llvm.x86.avx512.scattersiv2.di (IntrinsicsX86.td:4017)
    x86_avx512_scattersiv4_df,                 // llvm.x86.avx512.scattersiv4.df (IntrinsicsX86.td:4022)
    x86_avx512_scattersiv4_di,                 // llvm.x86.avx512.scattersiv4.di (IntrinsicsX86.td:4027)
    x86_avx512_scattersiv4_sf,                 // llvm.x86.avx512.scattersiv4.sf (IntrinsicsX86.td:4032)
    x86_avx512_scattersiv4_si,                 // llvm.x86.avx512.scattersiv4.si (IntrinsicsX86.td:4037)
    x86_avx512_scattersiv8_sf,                 // llvm.x86.avx512.scattersiv8.sf (IntrinsicsX86.td:4042)
    x86_avx512_scattersiv8_si,                 // llvm.x86.avx512.scattersiv8.si (IntrinsicsX86.td:4047)
    x86_avx512_sitofp_round,                   // llvm.x86.avx512.sitofp.round (IntrinsicsX86.td:2909)
    x86_avx512_sqrt_pd_512,                    // llvm.x86.avx512.sqrt.pd.512 (IntrinsicsX86.td:3527)
    x86_avx512_sqrt_ps_512,                    // llvm.x86.avx512.sqrt.ps.512 (IntrinsicsX86.td:3530)
    x86_avx512_sub_pd_512,                     // llvm.x86.avx512.sub.pd.512 (IntrinsicsX86.td:3355)
    x86_avx512_sub_ps_512,                     // llvm.x86.avx512.sub.ps.512 (IntrinsicsX86.td:3352)
    x86_avx512_uitofp_round,                   // llvm.x86.avx512.uitofp.round (IntrinsicsX86.td:2913)
    x86_avx512_vcomi_sd,                       // llvm.x86.avx512.vcomi.sd (IntrinsicsX86.td:4318)
    x86_avx512_vcomi_ss,                       // llvm.x86.avx512.vcomi.ss (IntrinsicsX86.td:4323)
    x86_avx512_vcvtsd2si32,                    // llvm.x86.avx512.vcvtsd2si32 (IntrinsicsX86.td:2871)
    x86_avx512_vcvtsd2si64,                    // llvm.x86.avx512.vcvtsd2si64 (IntrinsicsX86.td:2874)
    x86_avx512_vcvtsd2usi32,                   // llvm.x86.avx512.vcvtsd2usi32 (IntrinsicsX86.td:2865)
    x86_avx512_vcvtsd2usi64,                   // llvm.x86.avx512.vcvtsd2usi64 (IntrinsicsX86.td:2868)
    x86_avx512_vcvtss2si32,                    // llvm.x86.avx512.vcvtss2si32 (IntrinsicsX86.td:2859)
    x86_avx512_vcvtss2si64,                    // llvm.x86.avx512.vcvtss2si64 (IntrinsicsX86.td:2862)
    x86_avx512_vcvtss2usi32,                   // llvm.x86.avx512.vcvtss2usi32 (IntrinsicsX86.td:2853)
    x86_avx512_vcvtss2usi64,                   // llvm.x86.avx512.vcvtss2usi64 (IntrinsicsX86.td:2856)
    x86_avx512_vfmadd_f32,                     // llvm.x86.avx512.vfmadd.f32 (IntrinsicsX86.td:1837)
    x86_avx512_vfmadd_f64,                     // llvm.x86.avx512.vfmadd.f64 (IntrinsicsX86.td:1833)
    x86_avx512_vfmadd_pd_512,                  // llvm.x86.avx512.vfmadd.pd.512 (IntrinsicsX86.td:1813)
    x86_avx512_vfmadd_ps_512,                  // llvm.x86.avx512.vfmadd.ps.512 (IntrinsicsX86.td:1818)
    x86_avx512_vfmaddsub_pd_512,               // llvm.x86.avx512.vfmaddsub.pd.512 (IntrinsicsX86.td:1823)
    x86_avx512_vfmaddsub_ps_512,               // llvm.x86.avx512.vfmaddsub.ps.512 (IntrinsicsX86.td:1828)
    x86_avx512_vp2intersect_d_128,             // llvm.x86.avx512.vp2intersect.d.128 (IntrinsicsX86.td:4931)
    x86_avx512_vp2intersect_d_256,             // llvm.x86.avx512.vp2intersect.d.256 (IntrinsicsX86.td:4927)
    x86_avx512_vp2intersect_d_512,             // llvm.x86.avx512.vp2intersect.d.512 (IntrinsicsX86.td:4923)
    x86_avx512_vp2intersect_q_128,             // llvm.x86.avx512.vp2intersect.q.128 (IntrinsicsX86.td:4919)
    x86_avx512_vp2intersect_q_256,             // llvm.x86.avx512.vp2intersect.q.256 (IntrinsicsX86.td:4915)
    x86_avx512_vp2intersect_q_512,             // llvm.x86.avx512.vp2intersect.q.512 (IntrinsicsX86.td:4911)
    x86_avx512_vpdpbusd_128,                   // llvm.x86.avx512.vpdpbusd.128 (IntrinsicsX86.td:1870)
    x86_avx512_vpdpbusd_256,                   // llvm.x86.avx512.vpdpbusd.256 (IntrinsicsX86.td:1874)
    x86_avx512_vpdpbusd_512,                   // llvm.x86.avx512.vpdpbusd.512 (IntrinsicsX86.td:1878)
    x86_avx512_vpdpbusds_128,                  // llvm.x86.avx512.vpdpbusds.128 (IntrinsicsX86.td:1883)
    x86_avx512_vpdpbusds_256,                  // llvm.x86.avx512.vpdpbusds.256 (IntrinsicsX86.td:1887)
    x86_avx512_vpdpbusds_512,                  // llvm.x86.avx512.vpdpbusds.512 (IntrinsicsX86.td:1891)
    x86_avx512_vpdpwssd_128,                   // llvm.x86.avx512.vpdpwssd.128 (IntrinsicsX86.td:1896)
    x86_avx512_vpdpwssd_256,                   // llvm.x86.avx512.vpdpwssd.256 (IntrinsicsX86.td:1900)
    x86_avx512_vpdpwssd_512,                   // llvm.x86.avx512.vpdpwssd.512 (IntrinsicsX86.td:1904)
    x86_avx512_vpdpwssds_128,                  // llvm.x86.avx512.vpdpwssds.128 (IntrinsicsX86.td:1909)
    x86_avx512_vpdpwssds_256,                  // llvm.x86.avx512.vpdpwssds.256 (IntrinsicsX86.td:1913)
    x86_avx512_vpdpwssds_512,                  // llvm.x86.avx512.vpdpwssds.512 (IntrinsicsX86.td:1917)
    x86_avx512_vpermi2var_d_128,               // llvm.x86.avx512.vpermi2var.d.128 (IntrinsicsX86.td:968)
    x86_avx512_vpermi2var_d_256,               // llvm.x86.avx512.vpermi2var.d.256 (IntrinsicsX86.td:974)
    x86_avx512_vpermi2var_d_512,               // llvm.x86.avx512.vpermi2var.d.512 (IntrinsicsX86.td:980)
    x86_avx512_vpermi2var_hi_128,              // llvm.x86.avx512.vpermi2var.hi.128 (IntrinsicsX86.td:986)
    x86_avx512_vpermi2var_hi_256,              // llvm.x86.avx512.vpermi2var.hi.256 (IntrinsicsX86.td:992)
    x86_avx512_vpermi2var_hi_512,              // llvm.x86.avx512.vpermi2var.hi.512 (IntrinsicsX86.td:998)
    x86_avx512_vpermi2var_pd_128,              // llvm.x86.avx512.vpermi2var.pd.128 (IntrinsicsX86.td:1004)
    x86_avx512_vpermi2var_pd_256,              // llvm.x86.avx512.vpermi2var.pd.256 (IntrinsicsX86.td:1010)
    x86_avx512_vpermi2var_pd_512,              // llvm.x86.avx512.vpermi2var.pd.512 (IntrinsicsX86.td:1016)
    x86_avx512_vpermi2var_ps_128,              // llvm.x86.avx512.vpermi2var.ps.128 (IntrinsicsX86.td:1022)
    x86_avx512_vpermi2var_ps_256,              // llvm.x86.avx512.vpermi2var.ps.256 (IntrinsicsX86.td:1028)
    x86_avx512_vpermi2var_ps_512,              // llvm.x86.avx512.vpermi2var.ps.512 (IntrinsicsX86.td:1034)
    x86_avx512_vpermi2var_q_128,               // llvm.x86.avx512.vpermi2var.q.128 (IntrinsicsX86.td:1040)
    x86_avx512_vpermi2var_q_256,               // llvm.x86.avx512.vpermi2var.q.256 (IntrinsicsX86.td:1046)
    x86_avx512_vpermi2var_q_512,               // llvm.x86.avx512.vpermi2var.q.512 (IntrinsicsX86.td:1052)
    x86_avx512_vpermi2var_qi_128,              // llvm.x86.avx512.vpermi2var.qi.128 (IntrinsicsX86.td:1058)
    x86_avx512_vpermi2var_qi_256,              // llvm.x86.avx512.vpermi2var.qi.256 (IntrinsicsX86.td:1064)
    x86_avx512_vpermi2var_qi_512,              // llvm.x86.avx512.vpermi2var.qi.512 (IntrinsicsX86.td:1070)
    x86_avx512_vpermilvar_pd_512,              // llvm.x86.avx512.vpermilvar.pd.512 (IntrinsicsX86.td:1076)
    x86_avx512_vpermilvar_ps_512,              // llvm.x86.avx512.vpermilvar.ps.512 (IntrinsicsX86.td:1081)
    x86_avx512_vpmadd52h_uq_128,               // llvm.x86.avx512.vpmadd52h.uq.128 (IntrinsicsX86.td:1842)
    x86_avx512_vpmadd52h_uq_256,               // llvm.x86.avx512.vpmadd52h.uq.256 (IntrinsicsX86.td:1850)
    x86_avx512_vpmadd52h_uq_512,               // llvm.x86.avx512.vpmadd52h.uq.512 (IntrinsicsX86.td:1858)
    x86_avx512_vpmadd52l_uq_128,               // llvm.x86.avx512.vpmadd52l.uq.128 (IntrinsicsX86.td:1846)
    x86_avx512_vpmadd52l_uq_256,               // llvm.x86.avx512.vpmadd52l.uq.256 (IntrinsicsX86.td:1854)
    x86_avx512_vpmadd52l_uq_512,               // llvm.x86.avx512.vpmadd52l.uq.512 (IntrinsicsX86.td:1862)
    x86_avx512_vpshufbitqmb_128,               // llvm.x86.avx512.vpshufbitqmb.128 (IntrinsicsX86.td:1323)
    x86_avx512_vpshufbitqmb_256,               // llvm.x86.avx512.vpshufbitqmb.256 (IntrinsicsX86.td:1326)
    x86_avx512_vpshufbitqmb_512,               // llvm.x86.avx512.vpshufbitqmb.512 (IntrinsicsX86.td:1329)
    x86_avx512bf16_cvtne2ps2bf16_128,          // llvm.x86.avx512bf16.cvtne2ps2bf16.128 (IntrinsicsX86.td:5310)
    x86_avx512bf16_cvtne2ps2bf16_256,          // llvm.x86.avx512bf16.cvtne2ps2bf16.256 (IntrinsicsX86.td:5314)
    x86_avx512bf16_cvtne2ps2bf16_512,          // llvm.x86.avx512bf16.cvtne2ps2bf16.512 (IntrinsicsX86.td:5318)
    x86_avx512bf16_cvtneps2bf16_256,           // llvm.x86.avx512bf16.cvtneps2bf16.256 (IntrinsicsX86.td:5327)
    x86_avx512bf16_cvtneps2bf16_512,           // llvm.x86.avx512bf16.cvtneps2bf16.512 (IntrinsicsX86.td:5330)
    x86_avx512bf16_dpbf16ps_128,               // llvm.x86.avx512bf16.dpbf16ps.128 (IntrinsicsX86.td:5333)
    x86_avx512bf16_dpbf16ps_256,               // llvm.x86.avx512bf16.dpbf16ps.256 (IntrinsicsX86.td:5338)
    x86_avx512bf16_dpbf16ps_512,               // llvm.x86.avx512bf16.dpbf16ps.512 (IntrinsicsX86.td:5343)
    x86_avx512bf16_mask_cvtneps2bf16_128,      // llvm.x86.avx512bf16.mask.cvtneps2bf16.128 (IntrinsicsX86.td:5323)
    x86_avx512fp16_add_ph_512,                 // llvm.x86.avx512fp16.add.ph.512 (IntrinsicsX86.td:5881)
    x86_avx512fp16_div_ph_512,                 // llvm.x86.avx512fp16.div.ph.512 (IntrinsicsX86.td:5896)
    x86_avx512fp16_fpclass_ph_128,             // llvm.x86.avx512fp16.fpclass.ph.128 (IntrinsicsX86.td:6441)
    x86_avx512fp16_fpclass_ph_256,             // llvm.x86.avx512fp16.fpclass.ph.256 (IntrinsicsX86.td:6444)
    x86_avx512fp16_fpclass_ph_512,             // llvm.x86.avx512fp16.fpclass.ph.512 (IntrinsicsX86.td:6448)
    x86_avx512fp16_mask_add_sh_round,          // llvm.x86.avx512fp16.mask.add.sh.round (IntrinsicsX86.td:5946)
    x86_avx512fp16_mask_cmp_ph_128,            // llvm.x86.avx512fp16.mask.cmp.ph.128 (IntrinsicsX86.td:5940)
    x86_avx512fp16_mask_cmp_ph_256,            // llvm.x86.avx512fp16.mask.cmp.ph.256 (IntrinsicsX86.td:5935)
    x86_avx512fp16_mask_cmp_ph_512,            // llvm.x86.avx512fp16.mask.cmp.ph.512 (IntrinsicsX86.td:5930)
    x86_avx512fp16_mask_cmp_sh,                // llvm.x86.avx512fp16.mask.cmp.sh (IntrinsicsX86.td:5982)
    x86_avx512fp16_mask_div_sh_round,          // llvm.x86.avx512fp16.mask.div.sh.round (IntrinsicsX86.td:5964)
    x86_avx512fp16_mask_fpclass_sh,            // llvm.x86.avx512fp16.mask.fpclass.sh (IntrinsicsX86.td:6452)
    x86_avx512fp16_mask_getexp_ph_128,         // llvm.x86.avx512fp16.mask.getexp.ph.128 (IntrinsicsX86.td:6457)
    x86_avx512fp16_mask_getexp_ph_256,         // llvm.x86.avx512fp16.mask.getexp.ph.256 (IntrinsicsX86.td:6462)
    x86_avx512fp16_mask_getexp_ph_512,         // llvm.x86.avx512fp16.mask.getexp.ph.512 (IntrinsicsX86.td:6467)
    x86_avx512fp16_mask_getexp_sh,             // llvm.x86.avx512fp16.mask.getexp.sh (IntrinsicsX86.td:6473)
    x86_avx512fp16_mask_getmant_ph_128,        // llvm.x86.avx512fp16.mask.getmant.ph.128 (IntrinsicsX86.td:6479)
    x86_avx512fp16_mask_getmant_ph_256,        // llvm.x86.avx512fp16.mask.getmant.ph.256 (IntrinsicsX86.td:6485)
    x86_avx512fp16_mask_getmant_ph_512,        // llvm.x86.avx512fp16.mask.getmant.ph.512 (IntrinsicsX86.td:6491)
    x86_avx512fp16_mask_getmant_sh,            // llvm.x86.avx512fp16.mask.getmant.sh (IntrinsicsX86.td:6498)
    x86_avx512fp16_mask_max_sh_round,          // llvm.x86.avx512fp16.mask.max.sh.round (IntrinsicsX86.td:5976)
    x86_avx512fp16_mask_min_sh_round,          // llvm.x86.avx512fp16.mask.min.sh.round (IntrinsicsX86.td:5970)
    x86_avx512fp16_mask_mul_sh_round,          // llvm.x86.avx512fp16.mask.mul.sh.round (IntrinsicsX86.td:5958)
    x86_avx512fp16_mask_rcp_ph_128,            // llvm.x86.avx512fp16.mask.rcp.ph.128 (IntrinsicsX86.td:6394)
    x86_avx512fp16_mask_rcp_ph_256,            // llvm.x86.avx512fp16.mask.rcp.ph.256 (IntrinsicsX86.td:6399)
    x86_avx512fp16_mask_rcp_ph_512,            // llvm.x86.avx512fp16.mask.rcp.ph.512 (IntrinsicsX86.td:6404)
    x86_avx512fp16_mask_rcp_sh,                // llvm.x86.avx512fp16.mask.rcp.sh (IntrinsicsX86.td:6409)
    x86_avx512fp16_mask_reduce_ph_128,         // llvm.x86.avx512fp16.mask.reduce.ph.128 (IntrinsicsX86.td:6415)
    x86_avx512fp16_mask_reduce_ph_256,         // llvm.x86.avx512fp16.mask.reduce.ph.256 (IntrinsicsX86.td:6421)
    x86_avx512fp16_mask_reduce_ph_512,         // llvm.x86.avx512fp16.mask.reduce.ph.512 (IntrinsicsX86.td:6427)
    x86_avx512fp16_mask_reduce_sh,             // llvm.x86.avx512fp16.mask.reduce.sh (IntrinsicsX86.td:6434)
    x86_avx512fp16_mask_rndscale_ph_128,       // llvm.x86.avx512fp16.mask.rndscale.ph.128 (IntrinsicsX86.td:6505)
    x86_avx512fp16_mask_rndscale_ph_256,       // llvm.x86.avx512fp16.mask.rndscale.ph.256 (IntrinsicsX86.td:6511)
    x86_avx512fp16_mask_rndscale_ph_512,       // llvm.x86.avx512fp16.mask.rndscale.ph.512 (IntrinsicsX86.td:6517)
    x86_avx512fp16_mask_rndscale_sh,           // llvm.x86.avx512fp16.mask.rndscale.sh (IntrinsicsX86.td:6524)
    x86_avx512fp16_mask_rsqrt_ph_128,          // llvm.x86.avx512fp16.mask.rsqrt.ph.128 (IntrinsicsX86.td:6373)
    x86_avx512fp16_mask_rsqrt_ph_256,          // llvm.x86.avx512fp16.mask.rsqrt.ph.256 (IntrinsicsX86.td:6378)
    x86_avx512fp16_mask_rsqrt_ph_512,          // llvm.x86.avx512fp16.mask.rsqrt.ph.512 (IntrinsicsX86.td:6383)
    x86_avx512fp16_mask_rsqrt_sh,              // llvm.x86.avx512fp16.mask.rsqrt.sh (IntrinsicsX86.td:6388)
    x86_avx512fp16_mask_scalef_ph_128,         // llvm.x86.avx512fp16.mask.scalef.ph.128 (IntrinsicsX86.td:6531)
    x86_avx512fp16_mask_scalef_ph_256,         // llvm.x86.avx512fp16.mask.scalef.ph.256 (IntrinsicsX86.td:6537)
    x86_avx512fp16_mask_scalef_ph_512,         // llvm.x86.avx512fp16.mask.scalef.ph.512 (IntrinsicsX86.td:6543)
    x86_avx512fp16_mask_scalef_sh,             // llvm.x86.avx512fp16.mask.scalef.sh (IntrinsicsX86.td:6549)
    x86_avx512fp16_mask_sqrt_sh,               // llvm.x86.avx512fp16.mask.sqrt.sh (IntrinsicsX86.td:6368)
    x86_avx512fp16_mask_sub_sh_round,          // llvm.x86.avx512fp16.mask.sub.sh.round (IntrinsicsX86.td:5952)
    x86_avx512fp16_mask_vcvtdq2ph_128,         // llvm.x86.avx512fp16.mask.vcvtdq2ph.128 (IntrinsicsX86.td:6183)
    x86_avx512fp16_mask_vcvtpd2ph_128,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.128 (IntrinsicsX86.td:6029)
    x86_avx512fp16_mask_vcvtpd2ph_256,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.256 (IntrinsicsX86.td:6034)
    x86_avx512fp16_mask_vcvtpd2ph_512,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.512 (IntrinsicsX86.td:6039)
    x86_avx512fp16_mask_vcvtph2dq_128,         // llvm.x86.avx512fp16.mask.vcvtph2dq.128 (IntrinsicsX86.td:6151)
    x86_avx512fp16_mask_vcvtph2dq_256,         // llvm.x86.avx512fp16.mask.vcvtph2dq.256 (IntrinsicsX86.td:6156)
    x86_avx512fp16_mask_vcvtph2dq_512,         // llvm.x86.avx512fp16.mask.vcvtph2dq.512 (IntrinsicsX86.td:6161)
    x86_avx512fp16_mask_vcvtph2pd_128,         // llvm.x86.avx512fp16.mask.vcvtph2pd.128 (IntrinsicsX86.td:6045)
    x86_avx512fp16_mask_vcvtph2pd_256,         // llvm.x86.avx512fp16.mask.vcvtph2pd.256 (IntrinsicsX86.td:6050)
    x86_avx512fp16_mask_vcvtph2pd_512,         // llvm.x86.avx512fp16.mask.vcvtph2pd.512 (IntrinsicsX86.td:6055)
    x86_avx512fp16_mask_vcvtph2psx_128,        // llvm.x86.avx512fp16.mask.vcvtph2psx.128 (IntrinsicsX86.td:5997)
    x86_avx512fp16_mask_vcvtph2psx_256,        // llvm.x86.avx512fp16.mask.vcvtph2psx.256 (IntrinsicsX86.td:6002)
    x86_avx512fp16_mask_vcvtph2psx_512,        // llvm.x86.avx512fp16.mask.vcvtph2psx.512 (IntrinsicsX86.td:6007)
    x86_avx512fp16_mask_vcvtph2qq_128,         // llvm.x86.avx512fp16.mask.vcvtph2qq.128 (IntrinsicsX86.td:6236)
    x86_avx512fp16_mask_vcvtph2qq_256,         // llvm.x86.avx512fp16.mask.vcvtph2qq.256 (IntrinsicsX86.td:6241)
    x86_avx512fp16_mask_vcvtph2qq_512,         // llvm.x86.avx512fp16.mask.vcvtph2qq.512 (IntrinsicsX86.td:6246)
    x86_avx512fp16_mask_vcvtph2udq_128,        // llvm.x86.avx512fp16.mask.vcvtph2udq.128 (IntrinsicsX86.td:6167)
    x86_avx512fp16_mask_vcvtph2udq_256,        // llvm.x86.avx512fp16.mask.vcvtph2udq.256 (IntrinsicsX86.td:6172)
    x86_avx512fp16_mask_vcvtph2udq_512,        // llvm.x86.avx512fp16.mask.vcvtph2udq.512 (IntrinsicsX86.td:6177)
    x86_avx512fp16_mask_vcvtph2uqq_128,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.128 (IntrinsicsX86.td:6262)
    x86_avx512fp16_mask_vcvtph2uqq_256,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.256 (IntrinsicsX86.td:6267)
    x86_avx512fp16_mask_vcvtph2uqq_512,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.512 (IntrinsicsX86.td:6272)
    x86_avx512fp16_mask_vcvtph2uw_128,         // llvm.x86.avx512fp16.mask.vcvtph2uw.128 (IntrinsicsX86.td:6118)
    x86_avx512fp16_mask_vcvtph2uw_256,         // llvm.x86.avx512fp16.mask.vcvtph2uw.256 (IntrinsicsX86.td:6123)
    x86_avx512fp16_mask_vcvtph2uw_512,         // llvm.x86.avx512fp16.mask.vcvtph2uw.512 (IntrinsicsX86.td:6128)
    x86_avx512fp16_mask_vcvtph2w_128,          // llvm.x86.avx512fp16.mask.vcvtph2w.128 (IntrinsicsX86.td:6086)
    x86_avx512fp16_mask_vcvtph2w_256,          // llvm.x86.avx512fp16.mask.vcvtph2w.256 (IntrinsicsX86.td:6091)
    x86_avx512fp16_mask_vcvtph2w_512,          // llvm.x86.avx512fp16.mask.vcvtph2w.512 (IntrinsicsX86.td:6096)
    x86_avx512fp16_mask_vcvtps2phx_128,        // llvm.x86.avx512fp16.mask.vcvtps2phx.128 (IntrinsicsX86.td:6013)
    x86_avx512fp16_mask_vcvtps2phx_256,        // llvm.x86.avx512fp16.mask.vcvtps2phx.256 (IntrinsicsX86.td:6018)
    x86_avx512fp16_mask_vcvtps2phx_512,        // llvm.x86.avx512fp16.mask.vcvtps2phx.512 (IntrinsicsX86.td:6023)
    x86_avx512fp16_mask_vcvtqq2ph_128,         // llvm.x86.avx512fp16.mask.vcvtqq2ph.128 (IntrinsicsX86.td:6226)
    x86_avx512fp16_mask_vcvtqq2ph_256,         // llvm.x86.avx512fp16.mask.vcvtqq2ph.256 (IntrinsicsX86.td:6231)
    x86_avx512fp16_mask_vcvtsd2sh_round,       // llvm.x86.avx512fp16.mask.vcvtsd2sh.round (IntrinsicsX86.td:6073)
    x86_avx512fp16_mask_vcvtsh2sd_round,       // llvm.x86.avx512fp16.mask.vcvtsh2sd.round (IntrinsicsX86.td:6079)
    x86_avx512fp16_mask_vcvtsh2ss_round,       // llvm.x86.avx512fp16.mask.vcvtsh2ss.round (IntrinsicsX86.td:6061)
    x86_avx512fp16_mask_vcvtss2sh_round,       // llvm.x86.avx512fp16.mask.vcvtss2sh.round (IntrinsicsX86.td:6067)
    x86_avx512fp16_mask_vcvttph2dq_128,        // llvm.x86.avx512fp16.mask.vcvttph2dq.128 (IntrinsicsX86.td:6193)
    x86_avx512fp16_mask_vcvttph2dq_256,        // llvm.x86.avx512fp16.mask.vcvttph2dq.256 (IntrinsicsX86.td:6198)
    x86_avx512fp16_mask_vcvttph2dq_512,        // llvm.x86.avx512fp16.mask.vcvttph2dq.512 (IntrinsicsX86.td:6203)
    x86_avx512fp16_mask_vcvttph2qq_128,        // llvm.x86.avx512fp16.mask.vcvttph2qq.128 (IntrinsicsX86.td:6278)
    x86_avx512fp16_mask_vcvttph2qq_256,        // llvm.x86.avx512fp16.mask.vcvttph2qq.256 (IntrinsicsX86.td:6283)
    x86_avx512fp16_mask_vcvttph2qq_512,        // llvm.x86.avx512fp16.mask.vcvttph2qq.512 (IntrinsicsX86.td:6288)
    x86_avx512fp16_mask_vcvttph2udq_128,       // llvm.x86.avx512fp16.mask.vcvttph2udq.128 (IntrinsicsX86.td:6209)
    x86_avx512fp16_mask_vcvttph2udq_256,       // llvm.x86.avx512fp16.mask.vcvttph2udq.256 (IntrinsicsX86.td:6214)
    x86_avx512fp16_mask_vcvttph2udq_512,       // llvm.x86.avx512fp16.mask.vcvttph2udq.512 (IntrinsicsX86.td:6219)
    x86_avx512fp16_mask_vcvttph2uqq_128,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.128 (IntrinsicsX86.td:6294)
    x86_avx512fp16_mask_vcvttph2uqq_256,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.256 (IntrinsicsX86.td:6299)
    x86_avx512fp16_mask_vcvttph2uqq_512,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.512 (IntrinsicsX86.td:6304)
    x86_avx512fp16_mask_vcvttph2uw_128,        // llvm.x86.avx512fp16.mask.vcvttph2uw.128 (IntrinsicsX86.td:6134)
    x86_avx512fp16_mask_vcvttph2uw_256,        // llvm.x86.avx512fp16.mask.vcvttph2uw.256 (IntrinsicsX86.td:6139)
    x86_avx512fp16_mask_vcvttph2uw_512,        // llvm.x86.avx512fp16.mask.vcvttph2uw.512 (IntrinsicsX86.td:6144)
    x86_avx512fp16_mask_vcvttph2w_128,         // llvm.x86.avx512fp16.mask.vcvttph2w.128 (IntrinsicsX86.td:6102)
    x86_avx512fp16_mask_vcvttph2w_256,         // llvm.x86.avx512fp16.mask.vcvttph2w.256 (IntrinsicsX86.td:6107)
    x86_avx512fp16_mask_vcvttph2w_512,         // llvm.x86.avx512fp16.mask.vcvttph2w.512 (IntrinsicsX86.td:6112)
    x86_avx512fp16_mask_vcvtudq2ph_128,        // llvm.x86.avx512fp16.mask.vcvtudq2ph.128 (IntrinsicsX86.td:6188)
    x86_avx512fp16_mask_vcvtuqq2ph_128,        // llvm.x86.avx512fp16.mask.vcvtuqq2ph.128 (IntrinsicsX86.td:6252)
    x86_avx512fp16_mask_vcvtuqq2ph_256,        // llvm.x86.avx512fp16.mask.vcvtuqq2ph.256 (IntrinsicsX86.td:6257)
    x86_avx512fp16_mask_vfcmadd_cph_128,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.128 (IntrinsicsX86.td:6583)
    x86_avx512fp16_mask_vfcmadd_cph_256,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.256 (IntrinsicsX86.td:6595)
    x86_avx512fp16_mask_vfcmadd_cph_512,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.512 (IntrinsicsX86.td:6607)
    x86_avx512fp16_mask_vfcmadd_csh,           // llvm.x86.avx512fp16.mask.vfcmadd.csh (IntrinsicsX86.td:6667)
    x86_avx512fp16_mask_vfcmul_cph_128,        // llvm.x86.avx512fp16.mask.vfcmul.cph.128 (IntrinsicsX86.td:6685)
    x86_avx512fp16_mask_vfcmul_cph_256,        // llvm.x86.avx512fp16.mask.vfcmul.cph.256 (IntrinsicsX86.td:6697)
    x86_avx512fp16_mask_vfcmul_cph_512,        // llvm.x86.avx512fp16.mask.vfcmul.cph.512 (IntrinsicsX86.td:6709)
    x86_avx512fp16_mask_vfcmul_csh,            // llvm.x86.avx512fp16.mask.vfcmul.csh (IntrinsicsX86.td:6721)
    x86_avx512fp16_mask_vfmadd_cph_128,        // llvm.x86.avx512fp16.mask.vfmadd.cph.128 (IntrinsicsX86.td:6619)
    x86_avx512fp16_mask_vfmadd_cph_256,        // llvm.x86.avx512fp16.mask.vfmadd.cph.256 (IntrinsicsX86.td:6631)
    x86_avx512fp16_mask_vfmadd_cph_512,        // llvm.x86.avx512fp16.mask.vfmadd.cph.512 (IntrinsicsX86.td:6643)
    x86_avx512fp16_mask_vfmadd_csh,            // llvm.x86.avx512fp16.mask.vfmadd.csh (IntrinsicsX86.td:6655)
    x86_avx512fp16_mask_vfmul_cph_128,         // llvm.x86.avx512fp16.mask.vfmul.cph.128 (IntrinsicsX86.td:6679)
    x86_avx512fp16_mask_vfmul_cph_256,         // llvm.x86.avx512fp16.mask.vfmul.cph.256 (IntrinsicsX86.td:6691)
    x86_avx512fp16_mask_vfmul_cph_512,         // llvm.x86.avx512fp16.mask.vfmul.cph.512 (IntrinsicsX86.td:6703)
    x86_avx512fp16_mask_vfmul_csh,             // llvm.x86.avx512fp16.mask.vfmul.csh (IntrinsicsX86.td:6715)
    x86_avx512fp16_maskz_vfcmadd_cph_128,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.128 (IntrinsicsX86.td:6589)
    x86_avx512fp16_maskz_vfcmadd_cph_256,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.256 (IntrinsicsX86.td:6601)
    x86_avx512fp16_maskz_vfcmadd_cph_512,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.512 (IntrinsicsX86.td:6613)
    x86_avx512fp16_maskz_vfcmadd_csh,          // llvm.x86.avx512fp16.maskz.vfcmadd.csh (IntrinsicsX86.td:6673)
    x86_avx512fp16_maskz_vfmadd_cph_128,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.128 (IntrinsicsX86.td:6625)
    x86_avx512fp16_maskz_vfmadd_cph_256,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.256 (IntrinsicsX86.td:6637)
    x86_avx512fp16_maskz_vfmadd_cph_512,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.512 (IntrinsicsX86.td:6649)
    x86_avx512fp16_maskz_vfmadd_csh,           // llvm.x86.avx512fp16.maskz.vfmadd.csh (IntrinsicsX86.td:6661)
    x86_avx512fp16_max_ph_128,                 // llvm.x86.avx512fp16.max.ph.128 (IntrinsicsX86.td:5901)
    x86_avx512fp16_max_ph_256,                 // llvm.x86.avx512fp16.max.ph.256 (IntrinsicsX86.td:5905)
    x86_avx512fp16_max_ph_512,                 // llvm.x86.avx512fp16.max.ph.512 (IntrinsicsX86.td:5910)
    x86_avx512fp16_min_ph_128,                 // llvm.x86.avx512fp16.min.ph.128 (IntrinsicsX86.td:5915)
    x86_avx512fp16_min_ph_256,                 // llvm.x86.avx512fp16.min.ph.256 (IntrinsicsX86.td:5919)
    x86_avx512fp16_min_ph_512,                 // llvm.x86.avx512fp16.min.ph.512 (IntrinsicsX86.td:5924)
    x86_avx512fp16_mul_ph_512,                 // llvm.x86.avx512fp16.mul.ph.512 (IntrinsicsX86.td:5891)
    x86_avx512fp16_sqrt_ph_512,                // llvm.x86.avx512fp16.sqrt.ph.512 (IntrinsicsX86.td:6364)
    x86_avx512fp16_sub_ph_512,                 // llvm.x86.avx512fp16.sub.ph.512 (IntrinsicsX86.td:5886)
    x86_avx512fp16_vcomi_sh,                   // llvm.x86.avx512fp16.vcomi.sh (IntrinsicsX86.td:5989)
    x86_avx512fp16_vcvtsh2si32,                // llvm.x86.avx512fp16.vcvtsh2si32 (IntrinsicsX86.td:6311)
    x86_avx512fp16_vcvtsh2si64,                // llvm.x86.avx512fp16.vcvtsh2si64 (IntrinsicsX86.td:6319)
    x86_avx512fp16_vcvtsh2usi32,               // llvm.x86.avx512fp16.vcvtsh2usi32 (IntrinsicsX86.td:6315)
    x86_avx512fp16_vcvtsh2usi64,               // llvm.x86.avx512fp16.vcvtsh2usi64 (IntrinsicsX86.td:6323)
    x86_avx512fp16_vcvtsi2sh,                  // llvm.x86.avx512fp16.vcvtsi2sh (IntrinsicsX86.td:6337)
    x86_avx512fp16_vcvtsi642sh,                // llvm.x86.avx512fp16.vcvtsi642sh (IntrinsicsX86.td:6342)
    x86_avx512fp16_vcvttsh2si32,               // llvm.x86.avx512fp16.vcvttsh2si32 (IntrinsicsX86.td:6347)
    x86_avx512fp16_vcvttsh2si64,               // llvm.x86.avx512fp16.vcvttsh2si64 (IntrinsicsX86.td:6351)
    x86_avx512fp16_vcvttsh2usi32,              // llvm.x86.avx512fp16.vcvttsh2usi32 (IntrinsicsX86.td:6355)
    x86_avx512fp16_vcvttsh2usi64,              // llvm.x86.avx512fp16.vcvttsh2usi64 (IntrinsicsX86.td:6359)
    x86_avx512fp16_vcvtusi2sh,                 // llvm.x86.avx512fp16.vcvtusi2sh (IntrinsicsX86.td:6327)
    x86_avx512fp16_vcvtusi642sh,               // llvm.x86.avx512fp16.vcvtusi642sh (IntrinsicsX86.td:6332)
    x86_avx512fp16_vfmadd_f16,                 // llvm.x86.avx512fp16.vfmadd.f16 (IntrinsicsX86.td:6577)
    x86_avx512fp16_vfmadd_ph_512,              // llvm.x86.avx512fp16.vfmadd.ph.512 (IntrinsicsX86.td:6556)
    x86_avx512fp16_vfmaddsub_ph_128,           // llvm.x86.avx512fp16.vfmaddsub.ph.128 (IntrinsicsX86.td:6561)
    x86_avx512fp16_vfmaddsub_ph_256,           // llvm.x86.avx512fp16.vfmaddsub.ph.256 (IntrinsicsX86.td:6566)
    x86_avx512fp16_vfmaddsub_ph_512,           // llvm.x86.avx512fp16.vfmaddsub.ph.512 (IntrinsicsX86.td:6572)
    x86_axor32,                                // llvm.x86.axor32 (IntrinsicsX86.td:5848)
    x86_axor64,                                // llvm.x86.axor64 (IntrinsicsX86.td:5851)
    x86_bmi_bextr_32,                          // llvm.x86.bmi.bextr.32 (IntrinsicsX86.td:2566)
    x86_bmi_bextr_64,                          // llvm.x86.bmi.bextr.64 (IntrinsicsX86.td:2569)
    x86_bmi_bzhi_32,                           // llvm.x86.bmi.bzhi.32 (IntrinsicsX86.td:2572)
    x86_bmi_bzhi_64,                           // llvm.x86.bmi.bzhi.64 (IntrinsicsX86.td:2575)
    x86_bmi_pdep_32,                           // llvm.x86.bmi.pdep.32 (IntrinsicsX86.td:2578)
    x86_bmi_pdep_64,                           // llvm.x86.bmi.pdep.64 (IntrinsicsX86.td:2581)
    x86_bmi_pext_32,                           // llvm.x86.bmi.pext.32 (IntrinsicsX86.td:2584)
    x86_bmi_pext_64,                           // llvm.x86.bmi.pext.64 (IntrinsicsX86.td:2587)
    x86_cast_tile_to_vector,                   // llvm.x86.cast.tile.to.vector (IntrinsicsX86.td:5620)
    x86_cast_vector_to_tile,                   // llvm.x86.cast.vector.to.tile (IntrinsicsX86.td:5617)
    x86_cldemote,                              // llvm.x86.cldemote (IntrinsicsX86.td:5264)
    x86_clflushopt,                            // llvm.x86.clflushopt (IntrinsicsX86.td:2663)
    x86_clrssbsy,                              // llvm.x86.clrssbsy (IntrinsicsX86.td:128)
    x86_clui,                                  // llvm.x86.clui (IntrinsicsX86.td:5860)
    x86_clwb,                                  // llvm.x86.clwb (IntrinsicsX86.td:2666)
    x86_clzero,                                // llvm.x86.clzero (IntrinsicsX86.td:5243)
    x86_cmpccxadd32,                           // llvm.x86.cmpccxadd32 (IntrinsicsX86.td:5706)
    x86_cmpccxadd64,                           // llvm.x86.cmpccxadd64 (IntrinsicsX86.td:5712)
    x86_directstore32,                         // llvm.x86.directstore32 (IntrinsicsX86.td:5283)
    x86_directstore64,                         // llvm.x86.directstore64 (IntrinsicsX86.td:5285)
    x86_encodekey128,                          // llvm.x86.encodekey128 (IntrinsicsX86.td:5384)
    x86_encodekey256,                          // llvm.x86.encodekey256 (IntrinsicsX86.td:5388)
    x86_enqcmd,                                // llvm.x86.enqcmd (IntrinsicsX86.td:5354)
    x86_enqcmds,                               // llvm.x86.enqcmds (IntrinsicsX86.td:5356)
    x86_flags_read_u32,                        // llvm.x86.flags.read.u32 (IntrinsicsX86.td:34)
    x86_flags_read_u64,                        // llvm.x86.flags.read.u64 (IntrinsicsX86.td:36)
    x86_flags_write_u32,                       // llvm.x86.flags.write.u32 (IntrinsicsX86.td:38)
    x86_flags_write_u64,                       // llvm.x86.flags.write.u64 (IntrinsicsX86.td:40)
    x86_fma_vfmaddsub_pd,                      // llvm.x86.fma.vfmaddsub.pd (IntrinsicsX86.td:1798)
    x86_fma_vfmaddsub_pd_256,                  // llvm.x86.fma.vfmaddsub.pd.256 (IntrinsicsX86.td:1807)
    x86_fma_vfmaddsub_ps,                      // llvm.x86.fma.vfmaddsub.ps (IntrinsicsX86.td:1794)
    x86_fma_vfmaddsub_ps_256,                  // llvm.x86.fma.vfmaddsub.ps.256 (IntrinsicsX86.td:1802)
    x86_fxrstor,                               // llvm.x86.fxrstor (IntrinsicsX86.td:2617)
    x86_fxrstor64,                             // llvm.x86.fxrstor64 (IntrinsicsX86.td:2619)
    x86_fxsave,                                // llvm.x86.fxsave (IntrinsicsX86.td:2621)
    x86_fxsave64,                              // llvm.x86.fxsave64 (IntrinsicsX86.td:2623)
    x86_incsspd,                               // llvm.x86.incsspd (IntrinsicsX86.td:106)
    x86_incsspq,                               // llvm.x86.incsspq (IntrinsicsX86.td:108)
    x86_int,                                   // llvm.x86.int (IntrinsicsX86.td:16)
    x86_invpcid,                               // llvm.x86.invpcid (IntrinsicsX86.td:5305)
    x86_ldtilecfg,                             // llvm.x86.ldtilecfg (IntrinsicsX86.td:5434)
    x86_ldtilecfg_internal,                    // llvm.x86.ldtilecfg.internal (IntrinsicsX86.td:5549)
    x86_llwpcb,                                // llvm.x86.llwpcb (IntrinsicsX86.td:2229)
    x86_loadiwkey,                             // llvm.x86.loadiwkey (IntrinsicsX86.td:5381)
    x86_lwpins32,                              // llvm.x86.lwpins32 (IntrinsicsX86.td:2235)
    x86_lwpins64,                              // llvm.x86.lwpins64 (IntrinsicsX86.td:2239)
    x86_lwpval32,                              // llvm.x86.lwpval32 (IntrinsicsX86.td:2243)
    x86_lwpval64,                              // llvm.x86.lwpval64 (IntrinsicsX86.td:2247)
    x86_mmx_emms,                              // llvm.x86.mmx.emms (IntrinsicsX86.td:2258)
    x86_mmx_maskmovq,                          // llvm.x86.mmx.maskmovq (IntrinsicsX86.td:2538)
    x86_mmx_movnt_dq,                          // llvm.x86.mmx.movnt.dq (IntrinsicsX86.td:2544)
    x86_mmx_packssdw,                          // llvm.x86.mmx.packssdw (IntrinsicsX86.td:2483)
    x86_mmx_packsswb,                          // llvm.x86.mmx.packsswb (IntrinsicsX86.td:2480)
    x86_mmx_packuswb,                          // llvm.x86.mmx.packuswb (IntrinsicsX86.td:2486)
    x86_mmx_padd_b,                            // llvm.x86.mmx.padd.b (IntrinsicsX86.td:2265)
    x86_mmx_padd_d,                            // llvm.x86.mmx.padd.d (IntrinsicsX86.td:2271)
    x86_mmx_padd_q,                            // llvm.x86.mmx.padd.q (IntrinsicsX86.td:2274)
    x86_mmx_padd_w,                            // llvm.x86.mmx.padd.w (IntrinsicsX86.td:2268)
    x86_mmx_padds_b,                           // llvm.x86.mmx.padds.b (IntrinsicsX86.td:2278)
    x86_mmx_padds_w,                           // llvm.x86.mmx.padds.w (IntrinsicsX86.td:2281)
    x86_mmx_paddus_b,                          // llvm.x86.mmx.paddus.b (IntrinsicsX86.td:2285)
    x86_mmx_paddus_w,                          // llvm.x86.mmx.paddus.w (IntrinsicsX86.td:2288)
    x86_mmx_palignr_b,                         // llvm.x86.mmx.palignr.b (IntrinsicsX86.td:2547)
    x86_mmx_pand,                              // llvm.x86.mmx.pand (IntrinsicsX86.td:2338)
    x86_mmx_pandn,                             // llvm.x86.mmx.pandn (IntrinsicsX86.td:2341)
    x86_mmx_pavg_b,                            // llvm.x86.mmx.pavg.b (IntrinsicsX86.td:2352)
    x86_mmx_pavg_w,                            // llvm.x86.mmx.pavg.w (IntrinsicsX86.td:2355)
    x86_mmx_pcmpeq_b,                          // llvm.x86.mmx.pcmpeq.b (IntrinsicsX86.td:2515)
    x86_mmx_pcmpeq_d,                          // llvm.x86.mmx.pcmpeq.d (IntrinsicsX86.td:2521)
    x86_mmx_pcmpeq_w,                          // llvm.x86.mmx.pcmpeq.w (IntrinsicsX86.td:2518)
    x86_mmx_pcmpgt_b,                          // llvm.x86.mmx.pcmpgt.b (IntrinsicsX86.td:2525)
    x86_mmx_pcmpgt_d,                          // llvm.x86.mmx.pcmpgt.d (IntrinsicsX86.td:2531)
    x86_mmx_pcmpgt_w,                          // llvm.x86.mmx.pcmpgt.w (IntrinsicsX86.td:2528)
    x86_mmx_pextr_w,                           // llvm.x86.mmx.pextr.w (IntrinsicsX86.td:2552)
    x86_mmx_pinsr_w,                           // llvm.x86.mmx.pinsr.w (IntrinsicsX86.td:2556)
    x86_mmx_pmadd_wd,                          // llvm.x86.mmx.pmadd.wd (IntrinsicsX86.td:2333)
    x86_mmx_pmaxs_w,                           // llvm.x86.mmx.pmaxs.w (IntrinsicsX86.td:2363)
    x86_mmx_pmaxu_b,                           // llvm.x86.mmx.pmaxu.b (IntrinsicsX86.td:2360)
    x86_mmx_pmins_w,                           // llvm.x86.mmx.pmins.w (IntrinsicsX86.td:2371)
    x86_mmx_pminu_b,                           // llvm.x86.mmx.pminu.b (IntrinsicsX86.td:2368)
    x86_mmx_pmovmskb,                          // llvm.x86.mmx.pmovmskb (IntrinsicsX86.td:2541)
    x86_mmx_pmulh_w,                           // llvm.x86.mmx.pmulh.w (IntrinsicsX86.td:2321)
    x86_mmx_pmulhu_w,                          // llvm.x86.mmx.pmulhu.w (IntrinsicsX86.td:2327)
    x86_mmx_pmull_w,                           // llvm.x86.mmx.pmull.w (IntrinsicsX86.td:2324)
    x86_mmx_pmulu_dq,                          // llvm.x86.mmx.pmulu.dq (IntrinsicsX86.td:2330)
    x86_mmx_por,                               // llvm.x86.mmx.por (IntrinsicsX86.td:2344)
    x86_mmx_psad_bw,                           // llvm.x86.mmx.psad.bw (IntrinsicsX86.td:2376)
    x86_mmx_psll_d,                            // llvm.x86.mmx.psll.d (IntrinsicsX86.td:2387)
    x86_mmx_psll_q,                            // llvm.x86.mmx.psll.q (IntrinsicsX86.td:2390)
    x86_mmx_psll_w,                            // llvm.x86.mmx.psll.w (IntrinsicsX86.td:2384)
    x86_mmx_pslli_d,                           // llvm.x86.mmx.pslli.d (IntrinsicsX86.td:2415)
    x86_mmx_pslli_q,                           // llvm.x86.mmx.pslli.q (IntrinsicsX86.td:2418)
    x86_mmx_pslli_w,                           // llvm.x86.mmx.pslli.w (IntrinsicsX86.td:2412)
    x86_mmx_psra_d,                            // llvm.x86.mmx.psra.d (IntrinsicsX86.td:2407)
    x86_mmx_psra_w,                            // llvm.x86.mmx.psra.w (IntrinsicsX86.td:2404)
    x86_mmx_psrai_d,                           // llvm.x86.mmx.psrai.d (IntrinsicsX86.td:2435)
    x86_mmx_psrai_w,                           // llvm.x86.mmx.psrai.w (IntrinsicsX86.td:2432)
    x86_mmx_psrl_d,                            // llvm.x86.mmx.psrl.d (IntrinsicsX86.td:2397)
    x86_mmx_psrl_q,                            // llvm.x86.mmx.psrl.q (IntrinsicsX86.td:2400)
    x86_mmx_psrl_w,                            // llvm.x86.mmx.psrl.w (IntrinsicsX86.td:2394)
    x86_mmx_psrli_d,                           // llvm.x86.mmx.psrli.d (IntrinsicsX86.td:2425)
    x86_mmx_psrli_q,                           // llvm.x86.mmx.psrli.q (IntrinsicsX86.td:2428)
    x86_mmx_psrli_w,                           // llvm.x86.mmx.psrli.w (IntrinsicsX86.td:2422)
    x86_mmx_psub_b,                            // llvm.x86.mmx.psub.b (IntrinsicsX86.td:2293)
    x86_mmx_psub_d,                            // llvm.x86.mmx.psub.d (IntrinsicsX86.td:2299)
    x86_mmx_psub_q,                            // llvm.x86.mmx.psub.q (IntrinsicsX86.td:2302)
    x86_mmx_psub_w,                            // llvm.x86.mmx.psub.w (IntrinsicsX86.td:2296)
    x86_mmx_psubs_b,                           // llvm.x86.mmx.psubs.b (IntrinsicsX86.td:2306)
    x86_mmx_psubs_w,                           // llvm.x86.mmx.psubs.w (IntrinsicsX86.td:2309)
    x86_mmx_psubus_b,                          // llvm.x86.mmx.psubus.b (IntrinsicsX86.td:2313)
    x86_mmx_psubus_w,                          // llvm.x86.mmx.psubus.w (IntrinsicsX86.td:2316)
    x86_mmx_punpckhbw,                         // llvm.x86.mmx.punpckhbw (IntrinsicsX86.td:2493)
    x86_mmx_punpckhdq,                         // llvm.x86.mmx.punpckhdq (IntrinsicsX86.td:2499)
    x86_mmx_punpckhwd,                         // llvm.x86.mmx.punpckhwd (IntrinsicsX86.td:2496)
    x86_mmx_punpcklbw,                         // llvm.x86.mmx.punpcklbw (IntrinsicsX86.td:2502)
    x86_mmx_punpckldq,                         // llvm.x86.mmx.punpckldq (IntrinsicsX86.td:2508)
    x86_mmx_punpcklwd,                         // llvm.x86.mmx.punpcklwd (IntrinsicsX86.td:2505)
    x86_mmx_pxor,                              // llvm.x86.mmx.pxor (IntrinsicsX86.td:2347)
    x86_monitorx,                              // llvm.x86.monitorx (IntrinsicsX86.td:5232)
    x86_movdir64b,                             // llvm.x86.movdir64b (IntrinsicsX86.td:5287)
    x86_movrsdi,                               // llvm.x86.movrsdi (IntrinsicsX86.td:7339)
    x86_movrshi,                               // llvm.x86.movrshi (IntrinsicsX86.td:7333)
    x86_movrsqi,                               // llvm.x86.movrsqi (IntrinsicsX86.td:7330)
    x86_movrssi,                               // llvm.x86.movrssi (IntrinsicsX86.td:7336)
    x86_mwaitx,                                // llvm.x86.mwaitx (IntrinsicsX86.td:5235)
    x86_pclmulqdq,                             // llvm.x86.pclmulqdq (IntrinsicsX86.td:708)
    x86_pclmulqdq_256,                         // llvm.x86.pclmulqdq.256 (IntrinsicsX86.td:712)
    x86_pclmulqdq_512,                         // llvm.x86.pclmulqdq.512 (IntrinsicsX86.td:716)
    x86_prefetchrs,                            // llvm.x86.prefetchrs (IntrinsicsX86.td:7342)
    x86_ptwrite32,                             // llvm.x86.ptwrite32 (IntrinsicsX86.td:5295)
    x86_ptwrite64,                             // llvm.x86.ptwrite64 (IntrinsicsX86.td:5297)
    x86_rdfsbase_32,                           // llvm.x86.rdfsbase.32 (IntrinsicsX86.td:2596)
    x86_rdfsbase_64,                           // llvm.x86.rdfsbase.64 (IntrinsicsX86.td:2600)
    x86_rdgsbase_32,                           // llvm.x86.rdgsbase.32 (IntrinsicsX86.td:2598)
    x86_rdgsbase_64,                           // llvm.x86.rdgsbase.64 (IntrinsicsX86.td:2602)
    x86_rdpid,                                 // llvm.x86.rdpid (IntrinsicsX86.td:61)
    x86_rdpkru,                                // llvm.x86.rdpkru (IntrinsicsX86.td:2673)
    x86_rdpmc,                                 // llvm.x86.rdpmc (IntrinsicsX86.td:55)
    x86_rdpru,                                 // llvm.x86.rdpru (IntrinsicsX86.td:99)
    x86_rdrand_16,                             // llvm.x86.rdrand.16 (IntrinsicsX86.td:2726)
    x86_rdrand_32,                             // llvm.x86.rdrand.32 (IntrinsicsX86.td:2727)
    x86_rdrand_64,                             // llvm.x86.rdrand.64 (IntrinsicsX86.td:2728)
    x86_rdseed_16,                             // llvm.x86.rdseed.16 (IntrinsicsX86.td:2729)
    x86_rdseed_32,                             // llvm.x86.rdseed.32 (IntrinsicsX86.td:2730)
    x86_rdseed_64,                             // llvm.x86.rdseed.64 (IntrinsicsX86.td:2731)
    x86_rdsspd,                                // llvm.x86.rdsspd (IntrinsicsX86.td:110)
    x86_rdsspq,                                // llvm.x86.rdsspq (IntrinsicsX86.td:112)
    x86_rdtsc,                                 // llvm.x86.rdtsc (IntrinsicsX86.td:47)
    x86_rdtscp,                                // llvm.x86.rdtscp (IntrinsicsX86.td:49)
    x86_rstorssp,                              // llvm.x86.rstorssp (IntrinsicsX86.td:116)
    x86_saveprevssp,                           // llvm.x86.saveprevssp (IntrinsicsX86.td:114)
    x86_seh_ehguard,                           // llvm.x86.seh.ehguard (IntrinsicsX86.td:28)
    x86_seh_ehregnode,                         // llvm.x86.seh.ehregnode (IntrinsicsX86.td:25)
    x86_seh_lsda,                              // llvm.x86.seh.lsda (IntrinsicsX86.td:22)
    x86_senduipi,                              // llvm.x86.senduipi (IntrinsicsX86.td:5866)
    x86_serialize,                             // llvm.x86.serialize (IntrinsicsX86.td:5364)
    x86_setssbsy,                              // llvm.x86.setssbsy (IntrinsicsX86.td:126)
    x86_sha1msg1,                              // llvm.x86.sha1msg1 (IntrinsicsX86.td:5198)
    x86_sha1msg2,                              // llvm.x86.sha1msg2 (IntrinsicsX86.td:5201)
    x86_sha1nexte,                             // llvm.x86.sha1nexte (IntrinsicsX86.td:5195)
    x86_sha1rnds4,                             // llvm.x86.sha1rnds4 (IntrinsicsX86.td:5192)
    x86_sha256msg1,                            // llvm.x86.sha256msg1 (IntrinsicsX86.td:5207)
    x86_sha256msg2,                            // llvm.x86.sha256msg2 (IntrinsicsX86.td:5210)
    x86_sha256rnds2,                           // llvm.x86.sha256rnds2 (IntrinsicsX86.td:5204)
    x86_slwpcb,                                // llvm.x86.slwpcb (IntrinsicsX86.td:2232)
    x86_sse_cmp_ps,                            // llvm.x86.sse.cmp.ps (IntrinsicsX86.td:171)
    x86_sse_cmp_ss,                            // llvm.x86.sse.cmp.ss (IntrinsicsX86.td:165)
    x86_sse_comieq_ss,                         // llvm.x86.sse.comieq.ss (IntrinsicsX86.td:175)
    x86_sse_comige_ss,                         // llvm.x86.sse.comige.ss (IntrinsicsX86.td:187)
    x86_sse_comigt_ss,                         // llvm.x86.sse.comigt.ss (IntrinsicsX86.td:184)
    x86_sse_comile_ss,                         // llvm.x86.sse.comile.ss (IntrinsicsX86.td:181)
    x86_sse_comilt_ss,                         // llvm.x86.sse.comilt.ss (IntrinsicsX86.td:178)
    x86_sse_comineq_ss,                        // llvm.x86.sse.comineq.ss (IntrinsicsX86.td:190)
    x86_sse_cvtpd2pi,                          // llvm.x86.sse.cvtpd2pi (IntrinsicsX86.td:429)
    x86_sse_cvtpi2pd,                          // llvm.x86.sse.cvtpi2pd (IntrinsicsX86.td:433)
    x86_sse_cvtpi2ps,                          // llvm.x86.sse.cvtpi2ps (IntrinsicsX86.td:229)
    x86_sse_cvtps2pi,                          // llvm.x86.sse.cvtps2pi (IntrinsicsX86.td:225)
    x86_sse_cvtss2si,                          // llvm.x86.sse.cvtss2si (IntrinsicsX86.td:216)
    x86_sse_cvtss2si64,                        // llvm.x86.sse.cvtss2si64 (IntrinsicsX86.td:218)
    x86_sse_cvttpd2pi,                         // llvm.x86.sse.cvttpd2pi (IntrinsicsX86.td:431)
    x86_sse_cvttps2pi,                         // llvm.x86.sse.cvttps2pi (IntrinsicsX86.td:227)
    x86_sse_cvttss2si,                         // llvm.x86.sse.cvttss2si (IntrinsicsX86.td:220)
    x86_sse_cvttss2si64,                       // llvm.x86.sse.cvttss2si64 (IntrinsicsX86.td:222)
    x86_sse_ldmxcsr,                           // llvm.x86.sse.ldmxcsr (IntrinsicsX86.td:247)
    x86_sse_max_ps,                            // llvm.x86.sse.max.ps (IntrinsicsX86.td:158)
    x86_sse_max_ss,                            // llvm.x86.sse.max.ss (IntrinsicsX86.td:155)
    x86_sse_min_ps,                            // llvm.x86.sse.min.ps (IntrinsicsX86.td:152)
    x86_sse_min_ss,                            // llvm.x86.sse.min.ss (IntrinsicsX86.td:149)
    x86_sse_movmsk_ps,                         // llvm.x86.sse.movmsk.ps (IntrinsicsX86.td:257)
    x86_sse_pshuf_w,                           // llvm.x86.sse.pshuf.w (IntrinsicsX86.td:583)
    x86_sse_rcp_ps,                            // llvm.x86.sse.rcp.ps (IntrinsicsX86.td:140)
    x86_sse_rcp_ss,                            // llvm.x86.sse.rcp.ss (IntrinsicsX86.td:137)
    x86_sse_rsqrt_ps,                          // llvm.x86.sse.rsqrt.ps (IntrinsicsX86.td:146)
    x86_sse_rsqrt_ss,                          // llvm.x86.sse.rsqrt.ss (IntrinsicsX86.td:143)
    x86_sse_sfence,                            // llvm.x86.sse.sfence (IntrinsicsX86.td:236)
    x86_sse_stmxcsr,                           // llvm.x86.sse.stmxcsr (IntrinsicsX86.td:242)
    x86_sse_ucomieq_ss,                        // llvm.x86.sse.ucomieq.ss (IntrinsicsX86.td:193)
    x86_sse_ucomige_ss,                        // llvm.x86.sse.ucomige.ss (IntrinsicsX86.td:205)
    x86_sse_ucomigt_ss,                        // llvm.x86.sse.ucomigt.ss (IntrinsicsX86.td:202)
    x86_sse_ucomile_ss,                        // llvm.x86.sse.ucomile.ss (IntrinsicsX86.td:199)
    x86_sse_ucomilt_ss,                        // llvm.x86.sse.ucomilt.ss (IntrinsicsX86.td:196)
    x86_sse_ucomineq_ss,                       // llvm.x86.sse.ucomineq.ss (IntrinsicsX86.td:208)
    x86_sse2_clflush,                          // llvm.x86.sse2.clflush (IntrinsicsX86.td:455)
    x86_sse2_cmp_pd,                           // llvm.x86.sse2.cmp.pd (IntrinsicsX86.td:288)
    x86_sse2_cmp_sd,                           // llvm.x86.sse2.cmp.sd (IntrinsicsX86.td:282)
    x86_sse2_comieq_sd,                        // llvm.x86.sse2.comieq.sd (IntrinsicsX86.td:292)
    x86_sse2_comige_sd,                        // llvm.x86.sse2.comige.sd (IntrinsicsX86.td:304)
    x86_sse2_comigt_sd,                        // llvm.x86.sse2.comigt.sd (IntrinsicsX86.td:301)
    x86_sse2_comile_sd,                        // llvm.x86.sse2.comile.sd (IntrinsicsX86.td:298)
    x86_sse2_comilt_sd,                        // llvm.x86.sse2.comilt.sd (IntrinsicsX86.td:295)
    x86_sse2_comineq_sd,                       // llvm.x86.sse2.comineq.sd (IntrinsicsX86.td:307)
    x86_sse2_cvtpd2dq,                         // llvm.x86.sse2.cvtpd2dq (IntrinsicsX86.td:408)
    x86_sse2_cvtpd2ps,                         // llvm.x86.sse2.cvtpd2ps (IntrinsicsX86.td:412)
    x86_sse2_cvtps2dq,                         // llvm.x86.sse2.cvtps2dq (IntrinsicsX86.td:414)
    x86_sse2_cvtsd2si,                         // llvm.x86.sse2.cvtsd2si (IntrinsicsX86.td:418)
    x86_sse2_cvtsd2si64,                       // llvm.x86.sse2.cvtsd2si64 (IntrinsicsX86.td:420)
    x86_sse2_cvtsd2ss,                         // llvm.x86.sse2.cvtsd2ss (IntrinsicsX86.td:426)
    x86_sse2_cvttpd2dq,                        // llvm.x86.sse2.cvttpd2dq (IntrinsicsX86.td:410)
    x86_sse2_cvttps2dq,                        // llvm.x86.sse2.cvttps2dq (IntrinsicsX86.td:416)
    x86_sse2_cvttsd2si,                        // llvm.x86.sse2.cvttsd2si (IntrinsicsX86.td:422)
    x86_sse2_cvttsd2si64,                      // llvm.x86.sse2.cvttsd2si64 (IntrinsicsX86.td:424)
    x86_sse2_lfence,                           // llvm.x86.sse2.lfence (IntrinsicsX86.td:457)
    x86_sse2_maskmov_dqu,                      // llvm.x86.sse2.maskmov.dqu (IntrinsicsX86.td:452)
    x86_sse2_max_pd,                           // llvm.x86.sse2.max.pd (IntrinsicsX86.td:275)
    x86_sse2_max_sd,                           // llvm.x86.sse2.max.sd (IntrinsicsX86.td:272)
    x86_sse2_mfence,                           // llvm.x86.sse2.mfence (IntrinsicsX86.td:459)
    x86_sse2_min_pd,                           // llvm.x86.sse2.min.pd (IntrinsicsX86.td:269)
    x86_sse2_min_sd,                           // llvm.x86.sse2.min.sd (IntrinsicsX86.td:266)
    x86_sse2_movmsk_pd,                        // llvm.x86.sse2.movmsk.pd (IntrinsicsX86.td:448)
    x86_sse2_packssdw_128,                     // llvm.x86.sse2.packssdw.128 (IntrinsicsX86.td:442)
    x86_sse2_packsswb_128,                     // llvm.x86.sse2.packsswb.128 (IntrinsicsX86.td:439)
    x86_sse2_packuswb_128,                     // llvm.x86.sse2.packuswb.128 (IntrinsicsX86.td:445)
    x86_sse2_pause,                            // llvm.x86.sse2.pause (IntrinsicsX86.td:461)
    x86_sse2_pavg_b,                           // llvm.x86.sse2.pavg.b (IntrinsicsX86.td:341)
    x86_sse2_pavg_w,                           // llvm.x86.sse2.pavg.w (IntrinsicsX86.td:344)
    x86_sse2_pmadd_wd,                         // llvm.x86.sse2.pmadd.wd (IntrinsicsX86.td:338)
    x86_sse2_pmovmskb_128,                     // llvm.x86.sse2.pmovmskb.128 (IntrinsicsX86.td:450)
    x86_sse2_pmulh_w,                          // llvm.x86.sse2.pmulh.w (IntrinsicsX86.td:335)
    x86_sse2_pmulhu_w,                         // llvm.x86.sse2.pmulhu.w (IntrinsicsX86.td:332)
    x86_sse2_psad_bw,                          // llvm.x86.sse2.psad.bw (IntrinsicsX86.td:347)
    x86_sse2_psll_d,                           // llvm.x86.sse2.psll.d (IntrinsicsX86.td:357)
    x86_sse2_psll_q,                           // llvm.x86.sse2.psll.q (IntrinsicsX86.td:360)
    x86_sse2_psll_w,                           // llvm.x86.sse2.psll.w (IntrinsicsX86.td:354)
    x86_sse2_pslli_d,                          // llvm.x86.sse2.pslli.d (IntrinsicsX86.td:383)
    x86_sse2_pslli_q,                          // llvm.x86.sse2.pslli.q (IntrinsicsX86.td:386)
    x86_sse2_pslli_w,                          // llvm.x86.sse2.pslli.w (IntrinsicsX86.td:380)
    x86_sse2_psra_d,                           // llvm.x86.sse2.psra.d (IntrinsicsX86.td:375)
    x86_sse2_psra_w,                           // llvm.x86.sse2.psra.w (IntrinsicsX86.td:372)
    x86_sse2_psrai_d,                          // llvm.x86.sse2.psrai.d (IntrinsicsX86.td:401)
    x86_sse2_psrai_w,                          // llvm.x86.sse2.psrai.w (IntrinsicsX86.td:398)
    x86_sse2_psrl_d,                           // llvm.x86.sse2.psrl.d (IntrinsicsX86.td:366)
    x86_sse2_psrl_q,                           // llvm.x86.sse2.psrl.q (IntrinsicsX86.td:369)
    x86_sse2_psrl_w,                           // llvm.x86.sse2.psrl.w (IntrinsicsX86.td:363)
    x86_sse2_psrli_d,                          // llvm.x86.sse2.psrli.d (IntrinsicsX86.td:392)
    x86_sse2_psrli_q,                          // llvm.x86.sse2.psrli.q (IntrinsicsX86.td:395)
    x86_sse2_psrli_w,                          // llvm.x86.sse2.psrli.w (IntrinsicsX86.td:389)
    x86_sse2_ucomieq_sd,                       // llvm.x86.sse2.ucomieq.sd (IntrinsicsX86.td:310)
    x86_sse2_ucomige_sd,                       // llvm.x86.sse2.ucomige.sd (IntrinsicsX86.td:322)
    x86_sse2_ucomigt_sd,                       // llvm.x86.sse2.ucomigt.sd (IntrinsicsX86.td:319)
    x86_sse2_ucomile_sd,                       // llvm.x86.sse2.ucomile.sd (IntrinsicsX86.td:316)
    x86_sse2_ucomilt_sd,                       // llvm.x86.sse2.ucomilt.sd (IntrinsicsX86.td:313)
    x86_sse2_ucomineq_sd,                      // llvm.x86.sse2.ucomineq.sd (IntrinsicsX86.td:325)
    x86_sse3_addsub_pd,                        // llvm.x86.sse3.addsub.pd (IntrinsicsX86.td:473)
    x86_sse3_addsub_ps,                        // llvm.x86.sse3.addsub.ps (IntrinsicsX86.td:470)
    x86_sse3_hadd_pd,                          // llvm.x86.sse3.hadd.pd (IntrinsicsX86.td:483)
    x86_sse3_hadd_ps,                          // llvm.x86.sse3.hadd.ps (IntrinsicsX86.td:480)
    x86_sse3_hsub_pd,                          // llvm.x86.sse3.hsub.pd (IntrinsicsX86.td:489)
    x86_sse3_hsub_ps,                          // llvm.x86.sse3.hsub.ps (IntrinsicsX86.td:486)
    x86_sse3_ldu_dq,                           // llvm.x86.sse3.ldu.dq (IntrinsicsX86.td:496)
    x86_sse3_monitor,                          // llvm.x86.sse3.monitor (IntrinsicsX86.td:502)
    x86_sse3_mwait,                            // llvm.x86.sse3.mwait (IntrinsicsX86.td:505)
    x86_sse41_blendvpd,                        // llvm.x86.sse41.blendvpd (IntrinsicsX86.td:743)
    x86_sse41_blendvps,                        // llvm.x86.sse41.blendvps (IntrinsicsX86.td:747)
    x86_sse41_dppd,                            // llvm.x86.sse41.dppd (IntrinsicsX86.td:755)
    x86_sse41_dpps,                            // llvm.x86.sse41.dpps (IntrinsicsX86.td:759)
    x86_sse41_insertps,                        // llvm.x86.sse41.insertps (IntrinsicsX86.td:731)
    x86_sse41_mpsadbw,                         // llvm.x86.sse41.mpsadbw (IntrinsicsX86.td:767)
    x86_sse41_packusdw,                        // llvm.x86.sse41.packusdw (IntrinsicsX86.td:724)
    x86_sse41_pblendvb,                        // llvm.x86.sse41.pblendvb (IntrinsicsX86.td:739)
    x86_sse41_phminposuw,                      // llvm.x86.sse41.phminposuw (IntrinsicsX86.td:647)
    x86_sse41_ptestc,                          // llvm.x86.sse41.ptestc (IntrinsicsX86.td:778)
    x86_sse41_ptestnzc,                        // llvm.x86.sse41.ptestnzc (IntrinsicsX86.td:781)
    x86_sse41_ptestz,                          // llvm.x86.sse41.ptestz (IntrinsicsX86.td:775)
    x86_sse41_round_pd,                        // llvm.x86.sse41.round.pd (IntrinsicsX86.td:640)
    x86_sse41_round_ps,                        // llvm.x86.sse41.round.ps (IntrinsicsX86.td:633)
    x86_sse41_round_sd,                        // llvm.x86.sse41.round.sd (IntrinsicsX86.td:636)
    x86_sse41_round_ss,                        // llvm.x86.sse41.round.ss (IntrinsicsX86.td:629)
    x86_sse42_crc32_32_16,                     // llvm.x86.sse42.crc32.32.16 (IntrinsicsX86.td:795)
    x86_sse42_crc32_32_32,                     // llvm.x86.sse42.crc32.32.32 (IntrinsicsX86.td:798)
    x86_sse42_crc32_32_8,                      // llvm.x86.sse42.crc32.32.8 (IntrinsicsX86.td:792)
    x86_sse42_crc32_64_64,                     // llvm.x86.sse42.crc32.64.64 (IntrinsicsX86.td:801)
    x86_sse42_pcmpestri128,                    // llvm.x86.sse42.pcmpestri128 (IntrinsicsX86.td:841)
    x86_sse42_pcmpestria128,                   // llvm.x86.sse42.pcmpestria128 (IntrinsicsX86.td:846)
    x86_sse42_pcmpestric128,                   // llvm.x86.sse42.pcmpestric128 (IntrinsicsX86.td:851)
    x86_sse42_pcmpestrio128,                   // llvm.x86.sse42.pcmpestrio128 (IntrinsicsX86.td:856)
    x86_sse42_pcmpestris128,                   // llvm.x86.sse42.pcmpestris128 (IntrinsicsX86.td:861)
    x86_sse42_pcmpestriz128,                   // llvm.x86.sse42.pcmpestriz128 (IntrinsicsX86.td:866)
    x86_sse42_pcmpestrm128,                    // llvm.x86.sse42.pcmpestrm128 (IntrinsicsX86.td:836)
    x86_sse42_pcmpistri128,                    // llvm.x86.sse42.pcmpistri128 (IntrinsicsX86.td:812)
    x86_sse42_pcmpistria128,                   // llvm.x86.sse42.pcmpistria128 (IntrinsicsX86.td:816)
    x86_sse42_pcmpistric128,                   // llvm.x86.sse42.pcmpistric128 (IntrinsicsX86.td:820)
    x86_sse42_pcmpistrio128,                   // llvm.x86.sse42.pcmpistrio128 (IntrinsicsX86.td:824)
    x86_sse42_pcmpistris128,                   // llvm.x86.sse42.pcmpistris128 (IntrinsicsX86.td:828)
    x86_sse42_pcmpistriz128,                   // llvm.x86.sse42.pcmpistriz128 (IntrinsicsX86.td:832)
    x86_sse42_pcmpistrm128,                    // llvm.x86.sse42.pcmpistrm128 (IntrinsicsX86.td:808)
    x86_sse4a_extrq,                           // llvm.x86.sse4a.extrq (IntrinsicsX86.td:882)
    x86_sse4a_extrqi,                          // llvm.x86.sse4a.extrqi (IntrinsicsX86.td:877)
    x86_sse4a_insertq,                         // llvm.x86.sse4a.insertq (IntrinsicsX86.td:891)
    x86_sse4a_insertqi,                        // llvm.x86.sse4a.insertqi (IntrinsicsX86.td:886)
    x86_ssse3_pabs_b,                          // llvm.x86.ssse3.pabs.b (IntrinsicsX86.td:614)
    x86_ssse3_pabs_d,                          // llvm.x86.ssse3.pabs.d (IntrinsicsX86.td:620)
    x86_ssse3_pabs_w,                          // llvm.x86.ssse3.pabs.w (IntrinsicsX86.td:617)
    x86_ssse3_phadd_d,                         // llvm.x86.ssse3.phadd.d (IntrinsicsX86.td:522)
    x86_ssse3_phadd_d_128,                     // llvm.x86.ssse3.phadd.d.128 (IntrinsicsX86.td:525)
    x86_ssse3_phadd_sw,                        // llvm.x86.ssse3.phadd.sw (IntrinsicsX86.td:529)
    x86_ssse3_phadd_sw_128,                    // llvm.x86.ssse3.phadd.sw.128 (IntrinsicsX86.td:532)
    x86_ssse3_phadd_w,                         // llvm.x86.ssse3.phadd.w (IntrinsicsX86.td:515)
    x86_ssse3_phadd_w_128,                     // llvm.x86.ssse3.phadd.w.128 (IntrinsicsX86.td:518)
    x86_ssse3_phsub_d,                         // llvm.x86.ssse3.phsub.d (IntrinsicsX86.td:543)
    x86_ssse3_phsub_d_128,                     // llvm.x86.ssse3.phsub.d.128 (IntrinsicsX86.td:546)
    x86_ssse3_phsub_sw,                        // llvm.x86.ssse3.phsub.sw (IntrinsicsX86.td:550)
    x86_ssse3_phsub_sw_128,                    // llvm.x86.ssse3.phsub.sw.128 (IntrinsicsX86.td:553)
    x86_ssse3_phsub_w,                         // llvm.x86.ssse3.phsub.w (IntrinsicsX86.td:536)
    x86_ssse3_phsub_w_128,                     // llvm.x86.ssse3.phsub.w.128 (IntrinsicsX86.td:539)
    x86_ssse3_pmadd_ub_sw,                     // llvm.x86.ssse3.pmadd.ub.sw (IntrinsicsX86.td:557)
    x86_ssse3_pmadd_ub_sw_128,                 // llvm.x86.ssse3.pmadd.ub.sw.128 (IntrinsicsX86.td:560)
    x86_ssse3_pmul_hr_sw,                      // llvm.x86.ssse3.pmul.hr.sw (IntrinsicsX86.td:567)
    x86_ssse3_pmul_hr_sw_128,                  // llvm.x86.ssse3.pmul.hr.sw.128 (IntrinsicsX86.td:570)
    x86_ssse3_pshuf_b,                         // llvm.x86.ssse3.pshuf.b (IntrinsicsX86.td:577)
    x86_ssse3_pshuf_b_128,                     // llvm.x86.ssse3.pshuf.b.128 (IntrinsicsX86.td:580)
    x86_ssse3_psign_b,                         // llvm.x86.ssse3.psign.b (IntrinsicsX86.td:590)
    x86_ssse3_psign_b_128,                     // llvm.x86.ssse3.psign.b.128 (IntrinsicsX86.td:593)
    x86_ssse3_psign_d,                         // llvm.x86.ssse3.psign.d (IntrinsicsX86.td:604)
    x86_ssse3_psign_d_128,                     // llvm.x86.ssse3.psign.d.128 (IntrinsicsX86.td:607)
    x86_ssse3_psign_w,                         // llvm.x86.ssse3.psign.w (IntrinsicsX86.td:597)
    x86_ssse3_psign_w_128,                     // llvm.x86.ssse3.psign.w.128 (IntrinsicsX86.td:600)
    x86_sttilecfg,                             // llvm.x86.sttilecfg (IntrinsicsX86.td:5436)
    x86_stui,                                  // llvm.x86.stui (IntrinsicsX86.td:5862)
    x86_subborrow_32,                          // llvm.x86.subborrow.32 (IntrinsicsX86.td:2746)
    x86_subborrow_64,                          // llvm.x86.subborrow.64 (IntrinsicsX86.td:2750)
    x86_tbm_bextri_u32,                        // llvm.x86.tbm.bextri.u32 (IntrinsicsX86.td:2710)
    x86_tbm_bextri_u64,                        // llvm.x86.tbm.bextri.u64 (IntrinsicsX86.td:2713)
    x86_tcmmimfp16ps,                          // llvm.x86.tcmmimfp16ps (IntrinsicsX86.td:5483)
    x86_tcmmimfp16ps_internal,                 // llvm.x86.tcmmimfp16ps.internal (IntrinsicsX86.td:5623)
    x86_tcmmrlfp16ps,                          // llvm.x86.tcmmrlfp16ps (IntrinsicsX86.td:5487)
    x86_tcmmrlfp16ps_internal,                 // llvm.x86.tcmmrlfp16ps.internal (IntrinsicsX86.td:5629)
    x86_tcvtrowd2ps,                           // llvm.x86.tcvtrowd2ps (IntrinsicsX86.td:5511)
    x86_tcvtrowd2ps_internal,                  // llvm.x86.tcvtrowd2ps.internal (IntrinsicsX86.td:5636)
    x86_tcvtrowd2psi,                          // llvm.x86.tcvtrowd2psi (IntrinsicsX86.td:5529)
    x86_tcvtrowps2bf16h,                       // llvm.x86.tcvtrowps2bf16h (IntrinsicsX86.td:5514)
    x86_tcvtrowps2bf16h_internal,              // llvm.x86.tcvtrowps2bf16h.internal (IntrinsicsX86.td:5641)
    x86_tcvtrowps2bf16hi,                      // llvm.x86.tcvtrowps2bf16hi (IntrinsicsX86.td:5532)
    x86_tcvtrowps2bf16l,                       // llvm.x86.tcvtrowps2bf16l (IntrinsicsX86.td:5517)
    x86_tcvtrowps2bf16l_internal,              // llvm.x86.tcvtrowps2bf16l.internal (IntrinsicsX86.td:5646)
    x86_tcvtrowps2bf16li,                      // llvm.x86.tcvtrowps2bf16li (IntrinsicsX86.td:5535)
    x86_tcvtrowps2phh,                         // llvm.x86.tcvtrowps2phh (IntrinsicsX86.td:5520)
    x86_tcvtrowps2phh_internal,                // llvm.x86.tcvtrowps2phh.internal (IntrinsicsX86.td:5651)
    x86_tcvtrowps2phhi,                        // llvm.x86.tcvtrowps2phhi (IntrinsicsX86.td:5538)
    x86_tcvtrowps2phl,                         // llvm.x86.tcvtrowps2phl (IntrinsicsX86.td:5523)
    x86_tcvtrowps2phl_internal,                // llvm.x86.tcvtrowps2phl.internal (IntrinsicsX86.td:5656)
    x86_tcvtrowps2phli,                        // llvm.x86.tcvtrowps2phli (IntrinsicsX86.td:5541)
    x86_tdpbf16ps,                             // llvm.x86.tdpbf16ps (IntrinsicsX86.td:5473)
    x86_tdpbf16ps_internal,                    // llvm.x86.tdpbf16ps.internal (IntrinsicsX86.td:5604)
    x86_tdpbf8ps,                              // llvm.x86.tdpbf8ps (IntrinsicsX86.td:5493)
    x86_tdpbf8ps_internal,                     // llvm.x86.tdpbf8ps.internal (IntrinsicsX86.td:5677)
    x86_tdpbhf8ps,                             // llvm.x86.tdpbhf8ps (IntrinsicsX86.td:5497)
    x86_tdpbhf8ps_internal,                    // llvm.x86.tdpbhf8ps.internal (IntrinsicsX86.td:5683)
    x86_tdpbssd,                               // llvm.x86.tdpbssd (IntrinsicsX86.td:5457)
    x86_tdpbssd_internal,                      // llvm.x86.tdpbssd.internal (IntrinsicsX86.td:5572)
    x86_tdpbsud,                               // llvm.x86.tdpbsud (IntrinsicsX86.td:5461)
    x86_tdpbsud_internal,                      // llvm.x86.tdpbsud.internal (IntrinsicsX86.td:5578)
    x86_tdpbusd,                               // llvm.x86.tdpbusd (IntrinsicsX86.td:5465)
    x86_tdpbusd_internal,                      // llvm.x86.tdpbusd.internal (IntrinsicsX86.td:5584)
    x86_tdpbuud,                               // llvm.x86.tdpbuud (IntrinsicsX86.td:5469)
    x86_tdpbuud_internal,                      // llvm.x86.tdpbuud.internal (IntrinsicsX86.td:5590)
    x86_tdpfp16ps,                             // llvm.x86.tdpfp16ps (IntrinsicsX86.td:5478)
    x86_tdpfp16ps_internal,                    // llvm.x86.tdpfp16ps.internal (IntrinsicsX86.td:5610)
    x86_tdphbf8ps,                             // llvm.x86.tdphbf8ps (IntrinsicsX86.td:5501)
    x86_tdphbf8ps_internal,                    // llvm.x86.tdphbf8ps.internal (IntrinsicsX86.td:5689)
    x86_tdphf8ps,                              // llvm.x86.tdphf8ps (IntrinsicsX86.td:5505)
    x86_tdphf8ps_internal,                     // llvm.x86.tdphf8ps.internal (IntrinsicsX86.td:5695)
    x86_testui,                                // llvm.x86.testui (IntrinsicsX86.td:5864)
    x86_tileloadd64,                           // llvm.x86.tileloadd64 (IntrinsicsX86.td:5442)
    x86_tileloadd64_internal,                  // llvm.x86.tileloadd64.internal (IntrinsicsX86.td:5552)
    x86_tileloaddrs64,                         // llvm.x86.tileloaddrs64 (IntrinsicsX86.td:5451)
    x86_tileloaddrs64_internal,                // llvm.x86.tileloaddrs64.internal (IntrinsicsX86.td:5562)
    x86_tileloaddrst164,                       // llvm.x86.tileloaddrst164 (IntrinsicsX86.td:5454)
    x86_tileloaddrst164_internal,              // llvm.x86.tileloaddrst164.internal (IntrinsicsX86.td:5567)
    x86_tileloaddt164,                         // llvm.x86.tileloaddt164 (IntrinsicsX86.td:5445)
    x86_tileloaddt164_internal,                // llvm.x86.tileloaddt164.internal (IntrinsicsX86.td:5557)
    x86_tilemovrow,                            // llvm.x86.tilemovrow (IntrinsicsX86.td:5526)
    x86_tilemovrow_internal,                   // llvm.x86.tilemovrow.internal (IntrinsicsX86.td:5661)
    x86_tilemovrowi,                           // llvm.x86.tilemovrowi (IntrinsicsX86.td:5544)
    x86_tilerelease,                           // llvm.x86.tilerelease (IntrinsicsX86.td:5438)
    x86_tilestored64,                          // llvm.x86.tilestored64 (IntrinsicsX86.td:5448)
    x86_tilestored64_internal,                 // llvm.x86.tilestored64.internal (IntrinsicsX86.td:5596)
    x86_tilezero,                              // llvm.x86.tilezero (IntrinsicsX86.td:5440)
    x86_tilezero_internal,                     // llvm.x86.tilezero.internal (IntrinsicsX86.td:5600)
    x86_tmmultf32ps,                           // llvm.x86.tmmultf32ps (IntrinsicsX86.td:5667)
    x86_tmmultf32ps_internal,                  // llvm.x86.tmmultf32ps.internal (IntrinsicsX86.td:5671)
    x86_tpause,                                // llvm.x86.tpause (IntrinsicsX86.td:5275)
    x86_umonitor,                              // llvm.x86.umonitor (IntrinsicsX86.td:5271)
    x86_umwait,                                // llvm.x86.umwait (IntrinsicsX86.td:5273)
    x86_urdmsr,                                // llvm.x86.urdmsr (IntrinsicsX86.td:5871)
    x86_uwrmsr,                                // llvm.x86.uwrmsr (IntrinsicsX86.td:5874)
    x86_vbcstnebf162ps128,                     // llvm.x86.vbcstnebf162ps128 (IntrinsicsX86.td:5719)
    x86_vbcstnebf162ps256,                     // llvm.x86.vbcstnebf162ps256 (IntrinsicsX86.td:5723)
    x86_vbcstnesh2ps128,                       // llvm.x86.vbcstnesh2ps128 (IntrinsicsX86.td:5727)
    x86_vbcstnesh2ps256,                       // llvm.x86.vbcstnesh2ps256 (IntrinsicsX86.td:5731)
    x86_vcvtneebf162ps128,                     // llvm.x86.vcvtneebf162ps128 (IntrinsicsX86.td:5735)
    x86_vcvtneebf162ps256,                     // llvm.x86.vcvtneebf162ps256 (IntrinsicsX86.td:5739)
    x86_vcvtneeph2ps128,                       // llvm.x86.vcvtneeph2ps128 (IntrinsicsX86.td:5743)
    x86_vcvtneeph2ps256,                       // llvm.x86.vcvtneeph2ps256 (IntrinsicsX86.td:5747)
    x86_vcvtneobf162ps128,                     // llvm.x86.vcvtneobf162ps128 (IntrinsicsX86.td:5751)
    x86_vcvtneobf162ps256,                     // llvm.x86.vcvtneobf162ps256 (IntrinsicsX86.td:5755)
    x86_vcvtneoph2ps128,                       // llvm.x86.vcvtneoph2ps128 (IntrinsicsX86.td:5759)
    x86_vcvtneoph2ps256,                       // llvm.x86.vcvtneoph2ps256 (IntrinsicsX86.td:5763)
    x86_vcvtneps2bf16128,                      // llvm.x86.vcvtneps2bf16128 (IntrinsicsX86.td:5767)
    x86_vcvtneps2bf16256,                      // llvm.x86.vcvtneps2bf16256 (IntrinsicsX86.td:5770)
    x86_vcvtps2ph_128,                         // llvm.x86.vcvtps2ph.128 (IntrinsicsX86.td:2682)
    x86_vcvtps2ph_256,                         // llvm.x86.vcvtps2ph.256 (IntrinsicsX86.td:2685)
    x86_vgf2p8affineinvqb_128,                 // llvm.x86.vgf2p8affineinvqb.128 (IntrinsicsX86.td:1095)
    x86_vgf2p8affineinvqb_256,                 // llvm.x86.vgf2p8affineinvqb.256 (IntrinsicsX86.td:1100)
    x86_vgf2p8affineinvqb_512,                 // llvm.x86.vgf2p8affineinvqb.512 (IntrinsicsX86.td:1105)
    x86_vgf2p8affineqb_128,                    // llvm.x86.vgf2p8affineqb.128 (IntrinsicsX86.td:1111)
    x86_vgf2p8affineqb_256,                    // llvm.x86.vgf2p8affineqb.256 (IntrinsicsX86.td:1116)
    x86_vgf2p8affineqb_512,                    // llvm.x86.vgf2p8affineqb.512 (IntrinsicsX86.td:1121)
    x86_vgf2p8mulb_128,                        // llvm.x86.vgf2p8mulb.128 (IntrinsicsX86.td:1127)
    x86_vgf2p8mulb_256,                        // llvm.x86.vgf2p8mulb.256 (IntrinsicsX86.td:1131)
    x86_vgf2p8mulb_512,                        // llvm.x86.vgf2p8mulb.512 (IntrinsicsX86.td:1135)
    x86_vsha512msg1,                           // llvm.x86.vsha512msg1 (IntrinsicsX86.td:5218)
    x86_vsha512msg2,                           // llvm.x86.vsha512msg2 (IntrinsicsX86.td:5221)
    x86_vsha512rnds2,                          // llvm.x86.vsha512rnds2 (IntrinsicsX86.td:5224)
    x86_vsm3msg1,                              // llvm.x86.vsm3msg1 (IntrinsicsX86.td:5777)
    x86_vsm3msg2,                              // llvm.x86.vsm3msg2 (IntrinsicsX86.td:5782)
    x86_vsm3rnds2,                             // llvm.x86.vsm3rnds2 (IntrinsicsX86.td:5787)
    x86_vsm4key4128,                           // llvm.x86.vsm4key4128 (IntrinsicsX86.td:5796)
    x86_vsm4key4256,                           // llvm.x86.vsm4key4256 (IntrinsicsX86.td:5801)
    x86_vsm4key4512,                           // llvm.x86.vsm4key4512 (IntrinsicsX86.td:5806)
    x86_vsm4rnds4128,                          // llvm.x86.vsm4rnds4128 (IntrinsicsX86.td:5811)
    x86_vsm4rnds4256,                          // llvm.x86.vsm4rnds4256 (IntrinsicsX86.td:5816)
    x86_vsm4rnds4512,                          // llvm.x86.vsm4rnds4512 (IntrinsicsX86.td:5821)
    x86_wbinvd,                                // llvm.x86.wbinvd (IntrinsicsX86.td:5252)
    x86_wbnoinvd,                              // llvm.x86.wbnoinvd (IntrinsicsX86.td:5256)
    x86_wrfsbase_32,                           // llvm.x86.wrfsbase.32 (IntrinsicsX86.td:2604)
    x86_wrfsbase_64,                           // llvm.x86.wrfsbase.64 (IntrinsicsX86.td:2608)
    x86_wrgsbase_32,                           // llvm.x86.wrgsbase.32 (IntrinsicsX86.td:2606)
    x86_wrgsbase_64,                           // llvm.x86.wrgsbase.64 (IntrinsicsX86.td:2610)
    x86_wrpkru,                                // llvm.x86.wrpkru (IntrinsicsX86.td:2675)
    x86_wrssd,                                 // llvm.x86.wrssd (IntrinsicsX86.td:118)
    x86_wrssq,                                 // llvm.x86.wrssq (IntrinsicsX86.td:120)
    x86_wrussd,                                // llvm.x86.wrussd (IntrinsicsX86.td:122)
    x86_wrussq,                                // llvm.x86.wrussq (IntrinsicsX86.td:124)
    x86_xabort,                                // llvm.x86.xabort (IntrinsicsX86.td:2764)
    x86_xbegin,                                // llvm.x86.xbegin (IntrinsicsX86.td:2760)
    x86_xend,                                  // llvm.x86.xend (IntrinsicsX86.td:2762)
    x86_xgetbv,                                // llvm.x86.xgetbv (IntrinsicsX86.td:2654)
    x86_xop_vfrcz_pd,                          // llvm.x86.xop.vfrcz.pd (IntrinsicsX86.td:2069)
    x86_xop_vfrcz_pd_256,                      // llvm.x86.xop.vfrcz.pd.256 (IntrinsicsX86.td:2077)
    x86_xop_vfrcz_ps,                          // llvm.x86.xop.vfrcz.ps (IntrinsicsX86.td:2071)
    x86_xop_vfrcz_ps_256,                      // llvm.x86.xop.vfrcz.ps.256 (IntrinsicsX86.td:2079)
    x86_xop_vfrcz_sd,                          // llvm.x86.xop.vfrcz.sd (IntrinsicsX86.td:2073)
    x86_xop_vfrcz_ss,                          // llvm.x86.xop.vfrcz.ss (IntrinsicsX86.td:2075)
    x86_xop_vpermil2pd,                        // llvm.x86.xop.vpermil2pd (IntrinsicsX86.td:2048)
    x86_xop_vpermil2pd_256,                    // llvm.x86.xop.vpermil2pd.256 (IntrinsicsX86.td:2053)
    x86_xop_vpermil2ps,                        // llvm.x86.xop.vpermil2ps (IntrinsicsX86.td:2059)
    x86_xop_vpermil2ps_256,                    // llvm.x86.xop.vpermil2ps.256 (IntrinsicsX86.td:2063)
    x86_xop_vphaddbd,                          // llvm.x86.xop.vphaddbd (IntrinsicsX86.td:2082)
    x86_xop_vphaddbq,                          // llvm.x86.xop.vphaddbq (IntrinsicsX86.td:2085)
    x86_xop_vphaddbw,                          // llvm.x86.xop.vphaddbw (IntrinsicsX86.td:2088)
    x86_xop_vphadddq,                          // llvm.x86.xop.vphadddq (IntrinsicsX86.td:2091)
    x86_xop_vphaddubd,                         // llvm.x86.xop.vphaddubd (IntrinsicsX86.td:2094)
    x86_xop_vphaddubq,                         // llvm.x86.xop.vphaddubq (IntrinsicsX86.td:2097)
    x86_xop_vphaddubw,                         // llvm.x86.xop.vphaddubw (IntrinsicsX86.td:2100)
    x86_xop_vphaddudq,                         // llvm.x86.xop.vphaddudq (IntrinsicsX86.td:2103)
    x86_xop_vphadduwd,                         // llvm.x86.xop.vphadduwd (IntrinsicsX86.td:2106)
    x86_xop_vphadduwq,                         // llvm.x86.xop.vphadduwq (IntrinsicsX86.td:2109)
    x86_xop_vphaddwd,                          // llvm.x86.xop.vphaddwd (IntrinsicsX86.td:2112)
    x86_xop_vphaddwq,                          // llvm.x86.xop.vphaddwq (IntrinsicsX86.td:2115)
    x86_xop_vphsubbw,                          // llvm.x86.xop.vphsubbw (IntrinsicsX86.td:2118)
    x86_xop_vphsubdq,                          // llvm.x86.xop.vphsubdq (IntrinsicsX86.td:2121)
    x86_xop_vphsubwd,                          // llvm.x86.xop.vphsubwd (IntrinsicsX86.td:2124)
    x86_xop_vpmacsdd,                          // llvm.x86.xop.vpmacsdd (IntrinsicsX86.td:2127)
    x86_xop_vpmacsdqh,                         // llvm.x86.xop.vpmacsdqh (IntrinsicsX86.td:2132)
    x86_xop_vpmacsdql,                         // llvm.x86.xop.vpmacsdql (IntrinsicsX86.td:2137)
    x86_xop_vpmacssdd,                         // llvm.x86.xop.vpmacssdd (IntrinsicsX86.td:2142)
    x86_xop_vpmacssdqh,                        // llvm.x86.xop.vpmacssdqh (IntrinsicsX86.td:2147)
    x86_xop_vpmacssdql,                        // llvm.x86.xop.vpmacssdql (IntrinsicsX86.td:2152)
    x86_xop_vpmacsswd,                         // llvm.x86.xop.vpmacsswd (IntrinsicsX86.td:2157)
    x86_xop_vpmacssww,                         // llvm.x86.xop.vpmacssww (IntrinsicsX86.td:2162)
    x86_xop_vpmacswd,                          // llvm.x86.xop.vpmacswd (IntrinsicsX86.td:2167)
    x86_xop_vpmacsww,                          // llvm.x86.xop.vpmacsww (IntrinsicsX86.td:2172)
    x86_xop_vpmadcsswd,                        // llvm.x86.xop.vpmadcsswd (IntrinsicsX86.td:2177)
    x86_xop_vpmadcswd,                         // llvm.x86.xop.vpmadcswd (IntrinsicsX86.td:2182)
    x86_xop_vpperm,                            // llvm.x86.xop.vpperm (IntrinsicsX86.td:2187)
    x86_xop_vpshab,                            // llvm.x86.xop.vpshab (IntrinsicsX86.td:2192)
    x86_xop_vpshad,                            // llvm.x86.xop.vpshad (IntrinsicsX86.td:2196)
    x86_xop_vpshaq,                            // llvm.x86.xop.vpshaq (IntrinsicsX86.td:2200)
    x86_xop_vpshaw,                            // llvm.x86.xop.vpshaw (IntrinsicsX86.td:2204)
    x86_xop_vpshlb,                            // llvm.x86.xop.vpshlb (IntrinsicsX86.td:2208)
    x86_xop_vpshld,                            // llvm.x86.xop.vpshld (IntrinsicsX86.td:2212)
    x86_xop_vpshlq,                            // llvm.x86.xop.vpshlq (IntrinsicsX86.td:2216)
    x86_xop_vpshlw,                            // llvm.x86.xop.vpshlw (IntrinsicsX86.td:2220)
    x86_xresldtrk,                             // llvm.x86.xresldtrk (IntrinsicsX86.td:5374)
    x86_xrstor,                                // llvm.x86.xrstor (IntrinsicsX86.td:2634)
    x86_xrstor64,                              // llvm.x86.xrstor64 (IntrinsicsX86.td:2636)
    x86_xrstors,                               // llvm.x86.xrstors (IntrinsicsX86.td:2642)
    x86_xrstors64,                             // llvm.x86.xrstors64 (IntrinsicsX86.td:2644)
    x86_xsave,                                 // llvm.x86.xsave (IntrinsicsX86.td:2630)
    x86_xsave64,                               // llvm.x86.xsave64 (IntrinsicsX86.td:2632)
    x86_xsavec,                                // llvm.x86.xsavec (IntrinsicsX86.td:2646)
    x86_xsavec64,                              // llvm.x86.xsavec64 (IntrinsicsX86.td:2648)
    x86_xsaveopt,                              // llvm.x86.xsaveopt (IntrinsicsX86.td:2638)
    x86_xsaveopt64,                            // llvm.x86.xsaveopt64 (IntrinsicsX86.td:2640)
    x86_xsaves,                                // llvm.x86.xsaves (IntrinsicsX86.td:2650)
    x86_xsaves64,                              // llvm.x86.xsaves64 (IntrinsicsX86.td:2652)
    x86_xsetbv,                                // llvm.x86.xsetbv (IntrinsicsX86.td:2656)
    x86_xsusldtrk,                             // llvm.x86.xsusldtrk (IntrinsicsX86.td:5372)
    x86_xtest,                                 // llvm.x86.xtest (IntrinsicsX86.td:2766)
}; // enum
} // namespace llvm::Intrinsic
#endif

